commit 431b2c01a1103b63d026c3d8c7c286e4f4d9c918
Author: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Date:   Mon May 9 09:16:33 2022 +0200

    Linux 5.17.6
    
    Link: https://lore.kernel.org/r/20220504153110.096069935@linuxfoundation.org
    Tested-by: Linux Kernel Functional Testing <lkft@linaro.org>
    Tested-by: Florian Fainelli <f.fainelli@gmail.com>
    Tested-by: Jon Hunter <jonathanh@nvidia.com>
    Tested-by: Ron Economos <re@w6rz.net>
    Tested-by: Guenter Roeck <linux@roeck-us.net>
    Tested-by: Fenil Jain<fkjainco@gmail.com>
    Tested-by: Jiri Slaby <jirislaby@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 42af65b705a516f98773dacee076d1ac167919af
Author: Alexey Kardashevskiy <aik@ozlabs.ru>
Date:   Wed Mar 9 17:18:22 2022 +1100

    powerpc/64: Add UADDR64 relocation support
    
    commit d799769188529abc6cbf035a10087a51f7832b6b upstream.
    
    When ld detects unaligned relocations, it emits R_PPC64_UADDR64
    relocations instead of R_PPC64_RELATIVE. Currently R_PPC64_UADDR64 are
    detected by arch/powerpc/tools/relocs_check.sh and expected not to work.
    Below is a simple chunk to trigger this behaviour (this disables
    optimization for the demonstration purposes only, this also happens with
    -O1/-O2 when CONFIG_PRINTK_INDEX=y, for example):
    
      \#pragma GCC push_options
      \#pragma GCC optimize ("O0")
      struct entry {
              const char *file;
              int line;
      } __attribute__((packed));
      static const struct entry e1 = { .file = __FILE__, .line = __LINE__ };
      static const struct entry e2 = { .file = __FILE__, .line = __LINE__ };
      ...
      prom_printf("e1=%s %lx %lx\n", e1.file, (unsigned long) e1.file, mfmsr());
      prom_printf("e2=%s %lx\n", e2.file, (unsigned long) e2.file);
      \#pragma GCC pop_options
    
    This adds support for UADDR64 for 64bit. This reuses __dynamic_symtab
    from the 32bit code which supports more relocation types already.
    
    Because RELACOUNT includes only R_PPC64_RELATIVE, this replaces it with
    RELASZ which is the size of all relocation records.
    
    Signed-off-by: Alexey Kardashevskiy <aik@ozlabs.ru>
    Signed-off-by: Michael Ellerman <mpe@ellerman.id.au>
    Cc: Nathan Chancellor <nathan@kernel.org>
    Link: https://lore.kernel.org/r/20220309061822.168173-1-aik@ozlabs.ru
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit d17f64c295124e198a707f0e1e40ee298d919271
Author: Peter Zijlstra <peterz@infradead.org>
Date:   Sun Apr 17 17:03:40 2022 +0200

    objtool: Fix type of reloc::addend
    
    commit c087c6e7b551b7f208c0b852304f044954cf2bb3 upstream.
    
    Elf{32,64}_Rela::r_addend is of type: Elf{32,64}_Sword, that means
    that our reloc::addend needs to be long or face tuncation issues when
    we do elf_rebuild_reloc_section():
    
      - 107:  48 b8 00 00 00 00 00 00 00 00   movabs $0x0,%rax        109: R_X86_64_64        level4_kernel_pgt+0x80000067
      + 107:  48 b8 00 00 00 00 00 00 00 00   movabs $0x0,%rax        109: R_X86_64_64        level4_kernel_pgt-0x7fffff99
    
    Fixes: 627fce14809b ("objtool: Add ORC unwind table generation")
    Signed-off-by: Peter Zijlstra (Intel) <peterz@infradead.org>
    Acked-by: Josh Poimboeuf <jpoimboe@redhat.com>
    Link: https://lkml.kernel.org/r/20220419203807.596871927@infradead.org
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 60d2b0b1018a274fc3af1a90d46af4f2094f7e13
Author: Peter Zijlstra <peterz@infradead.org>
Date:   Sun Apr 17 17:03:36 2022 +0200

    objtool: Fix code relocs vs weak symbols
    
    commit 4abff6d48dbcea8200c7ea35ba70c242d128ebf3 upstream.
    
    Occasionally objtool driven code patching (think .static_call_sites
    .retpoline_sites etc..) goes sideways and it tries to patch an
    instruction that doesn't match.
    
    Much head-scatching and cursing later the problem is as outlined below
    and affects every section that objtool generates for us, very much
    including the ORC data. The below uses .static_call_sites because it's
    convenient for demonstration purposes, but as mentioned the ORC
    sections, .retpoline_sites and __mount_loc are all similarly affected.
    
    Consider:
    
    foo-weak.c:
    
      extern void __SCT__foo(void);
    
      __attribute__((weak)) void foo(void)
      {
              return __SCT__foo();
      }
    
    foo.c:
    
      extern void __SCT__foo(void);
      extern void my_foo(void);
    
      void foo(void)
      {
              my_foo();
              return __SCT__foo();
      }
    
    These generate the obvious code
    (gcc -O2 -fcf-protection=none -fno-asynchronous-unwind-tables -c foo*.c):
    
    foo-weak.o:
    0000000000000000 <foo>:
       0:   e9 00 00 00 00          jmpq   5 <foo+0x5>      1: R_X86_64_PLT32       __SCT__foo-0x4
    
    foo.o:
    0000000000000000 <foo>:
       0:   48 83 ec 08             sub    $0x8,%rsp
       4:   e8 00 00 00 00          callq  9 <foo+0x9>      5: R_X86_64_PLT32       my_foo-0x4
       9:   48 83 c4 08             add    $0x8,%rsp
       d:   e9 00 00 00 00          jmpq   12 <foo+0x12>    e: R_X86_64_PLT32       __SCT__foo-0x4
    
    Now, when we link these two files together, you get something like
    (ld -r -o foos.o foo-weak.o foo.o):
    
    foos.o:
    0000000000000000 <foo-0x10>:
       0:   e9 00 00 00 00          jmpq   5 <foo-0xb>      1: R_X86_64_PLT32       __SCT__foo-0x4
       5:   66 2e 0f 1f 84 00 00 00 00 00   nopw   %cs:0x0(%rax,%rax,1)
       f:   90                      nop
    
    0000000000000010 <foo>:
      10:   48 83 ec 08             sub    $0x8,%rsp
      14:   e8 00 00 00 00          callq  19 <foo+0x9>     15: R_X86_64_PLT32      my_foo-0x4
      19:   48 83 c4 08             add    $0x8,%rsp
      1d:   e9 00 00 00 00          jmpq   22 <foo+0x12>    1e: R_X86_64_PLT32      __SCT__foo-0x4
    
    Noting that ld preserves the weak function text, but strips the symbol
    off of it (hence objdump doing that funny negative offset thing). This
    does lead to 'interesting' unused code issues with objtool when ran on
    linked objects, but that seems to be working (fingers crossed).
    
    So far so good.. Now lets consider the objtool static_call output
    section (readelf output, old binutils):
    
    foo-weak.o:
    
    Relocation section '.rela.static_call_sites' at offset 0x2c8 contains 1 entry:
        Offset             Info             Type               Symbol's Value  Symbol's Name + Addend
    0000000000000000  0000000200000002 R_X86_64_PC32          0000000000000000 .text + 0
    0000000000000004  0000000d00000002 R_X86_64_PC32          0000000000000000 __SCT__foo + 1
    
    foo.o:
    
    Relocation section '.rela.static_call_sites' at offset 0x310 contains 2 entries:
        Offset             Info             Type               Symbol's Value  Symbol's Name + Addend
    0000000000000000  0000000200000002 R_X86_64_PC32          0000000000000000 .text + d
    0000000000000004  0000000d00000002 R_X86_64_PC32          0000000000000000 __SCT__foo + 1
    
    foos.o:
    
    Relocation section '.rela.static_call_sites' at offset 0x430 contains 4 entries:
        Offset             Info             Type               Symbol's Value  Symbol's Name + Addend
    0000000000000000  0000000100000002 R_X86_64_PC32          0000000000000000 .text + 0
    0000000000000004  0000000d00000002 R_X86_64_PC32          0000000000000000 __SCT__foo + 1
    0000000000000008  0000000100000002 R_X86_64_PC32          0000000000000000 .text + 1d
    000000000000000c  0000000d00000002 R_X86_64_PC32          0000000000000000 __SCT__foo + 1
    
    So we have two patch sites, one in the dead code of the weak foo and one
    in the real foo. All is well.
    
    *HOWEVER*, when the toolchain strips unused section symbols it
    generates things like this (using new enough binutils):
    
    foo-weak.o:
    
    Relocation section '.rela.static_call_sites' at offset 0x2c8 contains 1 entry:
        Offset             Info             Type               Symbol's Value  Symbol's Name + Addend
    0000000000000000  0000000200000002 R_X86_64_PC32          0000000000000000 foo + 0
    0000000000000004  0000000d00000002 R_X86_64_PC32          0000000000000000 __SCT__foo + 1
    
    foo.o:
    
    Relocation section '.rela.static_call_sites' at offset 0x310 contains 2 entries:
        Offset             Info             Type               Symbol's Value  Symbol's Name + Addend
    0000000000000000  0000000200000002 R_X86_64_PC32          0000000000000000 foo + d
    0000000000000004  0000000d00000002 R_X86_64_PC32          0000000000000000 __SCT__foo + 1
    
    foos.o:
    
    Relocation section '.rela.static_call_sites' at offset 0x430 contains 4 entries:
        Offset             Info             Type               Symbol's Value  Symbol's Name + Addend
    0000000000000000  0000000100000002 R_X86_64_PC32          0000000000000000 foo + 0
    0000000000000004  0000000d00000002 R_X86_64_PC32          0000000000000000 __SCT__foo + 1
    0000000000000008  0000000100000002 R_X86_64_PC32          0000000000000000 foo + d
    000000000000000c  0000000d00000002 R_X86_64_PC32          0000000000000000 __SCT__foo + 1
    
    And now we can see how that foos.o .static_call_sites goes side-ways, we
    now have _two_ patch sites in foo. One for the weak symbol at foo+0
    (which is no longer a static_call site!) and one at foo+d which is in
    fact the right location.
    
    This seems to happen when objtool cannot find a section symbol, in which
    case it falls back to any other symbol to key off of, however in this
    case that goes terribly wrong!
    
    As such, teach objtool to create a section symbol when there isn't
    one.
    
    Fixes: 44f6a7c0755d ("objtool: Fix seg fault with Clang non-section symbols")
    Signed-off-by: Peter Zijlstra (Intel) <peterz@infradead.org>
    Acked-by: Josh Poimboeuf <jpoimboe@redhat.com>
    Link: https://lkml.kernel.org/r/20220419203807.655552918@infradead.org
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit e578ba015ce8a495ecbb03597c8b30c40841b6bb
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Mon Apr 25 03:47:26 2022 -0700

    tty: n_gsm: fix sometimes uninitialized warning in gsm_dlci_modem_output()
    
    commit 19317433057dc1f2ca9a975e4e6b547282c2a5ef upstream.
    
    'size' may be used uninitialized in gsm_dlci_modem_output() if called with
    an adaption that is neither 1 nor 2. The function is currently only called
    by gsm_modem_upd_via_data() and only for adaption 2.
    Properly handle every invalid case by returning -EINVAL to silence the
    compiler warning and avoid future regressions.
    
    Fixes: c19ffe00fed6 ("tty: n_gsm: fix invalid use of MSC in advanced option")
    Cc: stable@vger.kernel.org
    Reported-by: kernel test robot <lkp@intel.com>
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220425104726.7986-1-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit a5e357c8e7c252ba7421d6c0323012d08251603a
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Fri Apr 22 00:10:25 2022 -0700

    tty: n_gsm: fix software flow control handling
    
    commit f4f7d63287217ba25e5c80f5faae5e4f7118790e upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. Chapter 5.4.8.1 states that XON/XOFF characters
    shall be used instead of Fcon/Fcoff command in advanced option mode to
    handle flow control. Chapter 5.4.8.2 describes how XON/XOFF characters
    shall be handled. Basic option mode only used Fcon/Fcoff commands and no
    XON/XOFF characters. These are treated as data bytes here.
    The current implementation uses the gsm_mux field 'constipated' to handle
    flow control from the remote peer and the gsm_dlci field 'constipated' to
    handle flow control from each DLCI. The later is unrelated to this patch.
    The gsm_mux field is correctly set for Fcon/Fcoff commands in
    gsm_control_message(). However, the same is not true for XON/XOFF
    characters in gsm1_receive().
    Disable software flow control handling in the tty to allow explicit
    handling by n_gsm.
    Add the missing handling in advanced option mode for gsm_mux in
    gsm1_receive() to comply with the standard.
    
    This patch depends on the following commit:
    Commit 8838b2af23ca ("tty: n_gsm: fix SW flow control encoding/handling")
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220422071025.5490-3-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 4ee8705e30a4a85afb9c8a2449ab4e51be2bf8cc
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Fri Apr 22 00:10:24 2022 -0700

    tty: n_gsm: fix invalid use of MSC in advanced option
    
    commit c19ffe00fed6bb423d81406d2a7e5793074c7d83 upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. Chapter 5.4.6.3.7 states that the Modem Status
    Command (MSC) shall only be used if the basic option was chosen.
    The current implementation uses MSC frames even if advanced option was
    chosen to inform the peer about modem line state updates. A standard
    conform peer may choose to discard these frames in advanced option mode.
    Furthermore, gsmtty_modem_update() is not part of the 'tty_operations'
    functions despite its name.
    Rename gsmtty_modem_update() to gsm_modem_update() to clarify this. Split
    its function into gsm_modem_upd_via_data() and gsm_modem_upd_via_msc()
    depending on the encoding and adaption. Introduce gsm_dlci_modem_output()
    as adaption of gsm_dlci_data_output() to encode and queue empty frames in
    advanced option mode. Use it in gsm_modem_upd_via_data().
    gsm_modem_upd_via_msc() is based on the initial gsmtty_modem_update()
    function which used only MSC frames to update modem states.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220422071025.5490-2-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit ef88588d00d3ce1b80e15183aed32f592d423103
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Fri Apr 22 00:10:23 2022 -0700

    tty: n_gsm: fix broken virtual tty handling
    
    commit a8c5b8255f8a9acd58a4b15ff1c14cd6effd114b upstream.
    
    Dynamic virtual tty registration was introduced to allow the user to handle
    these cases with uevent rules. The following commits relate to this:
    Commit 5b87686e3203 ("tty: n_gsm: Modify gsmtty driver register method when config requester")
    Commit 0b91b5332368 ("tty: n_gsm: Save dlci address open status when config requester")
    Commit 46292622ad73 ("tty: n_gsm: clean up indenting in gsm_queue()")
    
    However, the following behavior can be seen with this implementation:
    - n_gsm ldisc is activated via ioctl
    - all configuration parameters are set to their default value (initiator=0)
    - the mux gets activated and attached and gsmtty0 is being registered in
      in gsm_dlci_open() after DLCI 0 was established (DLCI 0 is the control
      channel)
    - the user configures n_gsm via ioctl GSMIOC_SETCONF as initiator
    - this re-attaches the n_gsm mux
    - no new gsmtty devices are registered in gsmld_attach_gsm() because the
      mux is already active
    - the initiator side registered only the control channel as gsmtty0
      (which should never happen) and no user channel tty
    
    The commits above make it impossible to operate the initiator side as no
    user channel tty is or will be available.
    On the other hand, this behavior will make it also impossible to allow DLCI
    parameter negotiation on responder side in the future. The responder side
    first needs to provide a device for the application before the application
    can set its parameters of the associated DLCI via ioctl.
    Note that the user application is still able to detect a link establishment
    without relaying to uevent by waiting for DTR open on responder side. This
    is the same behavior as on a physical serial interface. And on initiator
    side a tty hangup can be detected if a link establishment request failed.
    
    Revert the commits above completely to always register all user channels
    and no control channel after mux attachment. No other changes are made.
    
    Fixes: 5b87686e3203 ("tty: n_gsm: Modify gsmtty driver register method when config requester")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220422071025.5490-1-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit e83b4e1540469babeffcfd44a605cf8a61542598
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Wed Apr 20 03:13:44 2022 -0700

    tty: n_gsm: fix missing update of modem controls after DLCI open
    
    commit 48473802506d2d6151f59e0e764932b33b53cb3b upstream.
    
    Currently the peer is not informed about the initial state of the modem
    control lines after a new DLCI has been opened.
    Fix this by sending the initial modem control line states after DLCI open.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220420101346.3315-1-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 4eae80de03a144ee239b447c0fced2a82b871cf4
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:25 2022 -0700

    tty: n_gsm: fix incorrect UA handling
    
    commit ff9166c623704337bd6fe66fce2838d9768a6634 upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. Chapter 5.4.4.2 states that any received unnumbered
    acknowledgment (UA) with its poll/final (PF) bit set to 0 shall be
    discarded. Currently, all UA frame are handled in the same way regardless
    of the PF bit. This does not comply with the standard.
    Remove the UA case in gsm_queue() to process only UA frames with PF bit set
    to 1 to abide the standard.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-20-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 9cd2e69c866ecaff82a266bf6bc5f705674c0567
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:22 2022 -0700

    tty: n_gsm: fix reset fifo race condition
    
    commit 73029a4d7161f8b6c0934553145ef574d2d0c645 upstream.
    
    gsmtty_write() and gsm_dlci_data_output() properly guard the fifo access.
    However, gsm_dlci_close() and gsmtty_flush_buffer() modifies the fifo but
    do not guard this.
    Add a guard here to prevent race conditions on parallel writes to the fifo.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-17-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 59fa17f0e5a2f2fd667609bfe20f2ead713b7268
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:19 2022 -0700

    tty: n_gsm: fix missing tty wakeup in convergence layer type 2
    
    commit 1adf6fee58ca25fb6720b8d34c919dcf5425cc9c upstream.
    
    gsm_control_modem() informs the virtual tty that more data can be written
    after receiving a control signal octet via modem status command (MSC).
    However, gsm_dlci_data() fails to do the same after receiving a control
    signal octet from the convergence layer type 2 header.
    Add tty_wakeup() in gsm_dlci_data() for convergence layer type 2 to fix
    this.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-14-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 8180a7176682a32eb7b6c82287011da2a4b344e0
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:18 2022 -0700

    tty: n_gsm: fix wrong signal octets encoding in MSC
    
    commit 317f86af7f5d19f286ed2d181cbaef4a188c7f19 upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. The value of the modem status command (MSC) frame
    contains an address field, control signal and optional break signal octet.
    The address field is encoded as described in chapter 5.2.1.2 with only one
    octet (may be extended to more in future versions of the standard). Whereas
    the control signal and break signal octet are always one byte each. This is
    strange at first glance as it makes the EA bit redundant. However, the same
    two octets are also encoded as header in convergence layer type 2 as
    described in chapter 5.5.2. No header length field is given and the only
    way to test if there is an optional break signal octet is via the EA flag
    which extends the control signal octet with a break signal octet. Now it
    becomes obvious how the EA bit for those two octets shall be encoded in the
    MSC frame. The current implementation treats the signal octet different for
    MSC frame and convergence layer type 2 header even though the standard
    describes it for both in the same way.
    Use the EA bit to encode the signal octets not only in the convergence
    layer type 2 header but also in the MSC frame in the same way with either
    1 or 2 bytes in case of an optional break signal. Adjust the receiving path
    accordingly in gsm_control_modem().
    
    Fixes: 3ac06b905655 ("tty: n_gsm: Fix for modems with brk in modem status control")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-13-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 8d0f44207667c7b80ffdb0d3e7a945f9f8866c9b
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:17 2022 -0700

    tty: n_gsm: fix wrong command frame length field encoding
    
    commit 398867f59f956985f4c324f173eff7b946e14bd8 upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. Chapter 5.4.6.1 states that each command frame shall
    be made up from type, length and value. Looking for example in chapter
    5.4.6.3.5 at the description for the encoding of a flow control on command
    it becomes obvious, that the type and length field is always present
    whereas the value may be zero bytes long. The current implementation omits
    the length field if the value is not present. This is wrong.
    Correct this by always sending the length in gsm_control_transmit().
    So far only the modem status command (MSC) has included a value and encoded
    its length directly. Therefore, also change gsmtty_modem_update().
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-12-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit f4da6c6929858baf078a45c68c44a316eea8ae8a
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:16 2022 -0700

    tty: n_gsm: fix wrong command retry handling
    
    commit d0bcdffcad5a22f202e3bf37190c0dd8c080ea92 upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. Chapter 5.7.3 states that the valid range for the
    maximum number of retransmissions (N2) is from 0 to 255 (both including).
    gsm_config() fails to limit this range correctly. Furthermore,
    gsm_control_retransmit() handles this number incorrectly by performing
    N2 - 1 retransmission attempts. Setting N2 to zero results in more than 255
    retransmission attempts.
    Fix the range check in gsm_config() and the value handling in
    gsm_control_send() and gsm_control_retransmit() to comply with 3GPP 27.010.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-11-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 65e53227183507f274204ae7eec635393a16f418
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:15 2022 -0700

    tty: n_gsm: fix missing explicit ldisc flush
    
    commit 17eac652028501df7ea296b1d9b9c134db262b7d upstream.
    
    In gsm_cleanup_mux() the muxer is closed down and all queues are removed.
    However, removing the queues is done without explicit control of the
    underlying buffers. Flush those before freeing up our queues to ensure
    that all outgoing queues are cleared consistently. Otherwise, a new mux
    connection establishment attempt may time out while the underlying tty is
    still busy sending out the remaining data from the previous connection.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-10-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 5c2ac89f540bbfad7ae5156e3356bdf47731e52a
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:14 2022 -0700

    tty: n_gsm: fix wrong DLCI release order
    
    commit deefc58bafb4841df7f0a0d85d89a1c819db9743 upstream.
    
    The current DLCI release order starts with the control channel followed by
    the user channels. Reverse this order to keep the control channel open
    until all user channels have been released.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-9-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit e11311d3f81223f5850b3d0dc5b7def27e1d0b9d
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:13 2022 -0700

    tty: n_gsm: fix insufficient txframe size
    
    commit 535bf600de75a859698892ee873521a48d289ec1 upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. Chapter 5.7.2 states that the maximum frame size
    (N1) refers to the length of the information field (i.e. user payload).
    However, 'txframe' stores the whole frame including frame header, checksum
    and start/end flags. We also need to consider the byte stuffing overhead.
    Define constant for the protocol overhead and adjust the 'txframe' size
    calculation accordingly to reserve enough space for a complete mux frame
    including byte stuffing for advanced option mode. Note that no byte
    stuffing is applied to the start and end flag.
    Also use MAX_MTU instead of MAX_MRU as this buffer is used for data
    transmission.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-8-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 6da4fe00bcde3038076d501e122e0fd20626dab0
Author: Florian Westphal <fw@strlen.de>
Date:   Thu Apr 28 09:39:21 2022 +0200

    netfilter: nft_socket: only do sk lookups when indev is available
    
    commit 743b83f15d4069ea57c3e40996bf4a1077e0cdc1 upstream.
    
    Check if the incoming interface is available and NFT_BREAK
    in case neither skb->sk nor input device are set.
    
    Because nf_sk_lookup_slow*() assume packet headers are in the
    'in' direction, use in postrouting is not going to yield a meaningful
    result.  Same is true for the forward chain, so restrict the use
    to prerouting, input and output.
    
    Use in output work if a socket is already attached to the skb.
    
    Fixes: 554ced0a6e29 ("netfilter: nf_tables: add support for native socket matching")
    Reported-and-tested-by: Topi Miettinen <toiwoton@gmail.com>
    Signed-off-by: Florian Westphal <fw@strlen.de>
    Signed-off-by: Pablo Neira Ayuso <pablo@netfilter.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit df8185cd25af0f25e73dadbf098673c80ea48816
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:12 2022 -0700

    tty: n_gsm: fix malformed counter for out of frame data
    
    commit a24b4b2f660b7ddf3f484b37600bba382cb28a9d upstream.
    
    The gsm_mux field 'malformed' represents the number of malformed frames
    received. However, gsm1_receive() also increases this counter for any out
    of frame byte.
    Fix this by ignoring out of frame data for the malformed counter.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-7-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit c680214239f1d8ef89cf4384d788fd5f17f64c31
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:11 2022 -0700

    tty: n_gsm: fix frame reception handling
    
    commit 7a0e4b1733b635026a87c023f6d703faf0095e39 upstream.
    
    The frame checksum (FCS) is currently handled in gsm_queue() after
    reception of a frame. However, this breaks layering. A workaround with
    'received_fcs' was implemented so far.
    Furthermore, frames are handled as such even if no end flag was received.
    Move FCS calculation from gsm_queue() to gsm0_receive() and gsm1_receive().
    Also delay gsm_queue() call there until a full frame was received to fix
    both points.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-6-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit b245d45626943f0317da695d05a4a51eb3106559
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:10 2022 -0700

    tty: n_gsm: fix wrong signal octet encoding in convergence layer type 2
    
    commit 06d5afd4d640eea67f5623e76cd5fc03359b7f3c upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. Chapter 5.5.2 describes that the signal octet in
    convergence layer type 2 can be either one or two bytes. The length is
    encoded in the EA bit. This is set 1 for the last byte in the sequence.
    gsmtty_modem_update() handles this correctly but gsm_dlci_data_output()
    fails to set EA to 1. There is no case in which we encode two signal octets
    as there is no case in which we send out a break signal.
    Therefore, always set the EA bit to 1 for the signal octet to fix this.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-5-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 472d5c305ad007193cd5bd94121308280904e659
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:09 2022 -0700

    tty: n_gsm: fix mux cleanup after unregister tty device
    
    commit 284260f278b706364fb4c88a7b56ba5298d5973c upstream.
    
    Internally, we manage the alive state of the mux channels and mux itself
    with the field member 'dead'. This makes it possible to notify the user
    if the accessed underlying link is already gone. On the other hand,
    however, removing the virtual ttys before terminating the channels may
    result in peer messages being received without any internal target. Move
    the mux cleanup procedure from gsmld_detach_gsm() to gsmld_close() to fix
    this by keeping the virtual ttys open until the mux has been cleaned up.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-4-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 68cacd91fae8b1abecb7da0a4a10dbf0d9c0c0f6
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:08 2022 -0700

    tty: n_gsm: fix decoupled mux resource
    
    commit 1ec92e9742774bf42614fceea3bf6b50c9409225 upstream.
    
    The active mux instances are managed in the gsm_mux array and via mux_get()
    and mux_put() functions separately. This gives a very loose coupling
    between the actual instance and the gsm_mux array which manages it. It also
    results in unnecessary lockings which makes it prone to failures. And it
    creates a race condition if more than the maximum number of mux instances
    are requested while the user changes the parameters of an active instance.
    The user may loose ownership of the current mux instance in this case.
    Fix this by moving the gsm_mux array handling to the mux allocation and
    deallocation functions.
    
    Fixes: e1eaea46bb40 ("tty: n_gsm line discipline")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-3-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 74ef1629c5ab5c89ac241d434dbb3ec150df695a
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:07 2022 -0700

    tty: n_gsm: fix restart handling via CLD command
    
    commit aa371e96f05dcb36a88298f5cb70aa7234d5e8b8 upstream.
    
    n_gsm is based on the 3GPP 07.010 and its newer version is the 3GPP 27.010.
    See https://portal.3gpp.org/desktopmodules/Specifications/SpecificationDetails.aspx?specificationId=1516
    The changes from 07.010 to 27.010 are non-functional. Therefore, I refer to
    the newer 27.010 here. Chapter 5.8.2 states that both sides will revert to
    the non-multiplexed mode via a close-down message (CLD). The usual program
    flow is as following:
    - start multiplex mode by sending AT+CMUX to the mobile
    - establish the control channel (DLCI 0)
    - establish user channels (DLCI >0)
    - terminate user channels
    - send close-down message (CLD)
    - revert to AT protocol (i.e. leave multiplexed mode)
    
    The AT protocol is out of scope of the n_gsm driver. However,
    gsm_disconnect() sends CLD if gsm_config() detects that the requested
    parameters require the mux protocol to restart. The next immediate action
    is to start the mux protocol by opening DLCI 0 again. Any responder side
    which handles CLD commands correctly forces us to fail at this point
    because AT+CMUX needs to be sent to the mobile to start the mux again.
    Therefore, remove the CLD command in this phase and keep both sides in
    multiplexed mode.
    Remove the gsm_disconnect() function as it become unnecessary and merge the
    remaining parts into gsm_cleanup_mux() to handle the termination order and
    locking correctly.
    
    Fixes: 71e077915396 ("tty: n_gsm: do not send/receive in ldisc close path")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-2-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 50736d3a4ca6878c3c0c82812bdcee9f28469b2c
Author: Daniel Starke <daniel.starke@siemens.com>
Date:   Thu Apr 14 02:42:06 2022 -0700

    tty: n_gsm: fix missing mux reset on config change at responder
    
    commit 11451693e4081d32ef65147c6ca08cd0094ae252 upstream.
    
    Currently, only the initiator resets the mux protocol if the user requests
    new parameters that are incompatible to those of the current connection.
    The responder also needs to reset the multiplexer if the new parameter set
    requires this. Otherwise, we end up with an inconsistent parameter set
    between initiator and responder.
    Revert the old behavior to inform the peer upon an incompatible parameter
    set change from the user on the responder side by re-establishing the mux
    protocol in such case.
    
    Fixes: 509067bbd264 ("tty: n_gsm: Delete gsm_disconnect when config requester")
    Cc: stable@vger.kernel.org
    Signed-off-by: Daniel Starke <daniel.starke@siemens.com>
    Link: https://lore.kernel.org/r/20220414094225.4527-1-daniel.starke@siemens.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 30eddc3fa32649ad2b1521942e19bc60f4b33b08
Author: Namhyung Kim <namhyung@kernel.org>
Date:   Fri Apr 15 17:40:48 2022 -0700

    perf symbol: Remove arch__symbols__fixup_end()
    
    commit a5d20d42a2f2dc2b2f9e9361912062732414090d upstream.
    
    Now the generic code can handle kallsyms fixup properly so no need to
    keep the arch-functions anymore.
    
    Fixes: 3cf6a32f3f2a4594 ("perf symbols: Fix symbol size calculation condition")
    Signed-off-by: Namhyung Kim <namhyung@kernel.org>
    Acked-by: Ian Rogers <irogers@google.com>
    Cc: Heiko Carstens <hca@linux.ibm.com>
    Cc: Ingo Molnar <mingo@kernel.org>
    Cc: Jiri Olsa <jolsa@kernel.org>
    Cc: John Garry <john.garry@huawei.com>
    Cc: Leo Yan <leo.yan@linaro.org>
    Cc: Mark Rutland <mark.rutland@arm.com>
    Cc: Masami Hiramatsu <mhiramat@kernel.org>
    Cc: Mathieu Poirier <mathieu.poirier@linaro.org>
    Cc: Michael Ellerman <mpe@ellerman.id.au>
    Cc: Michael Petlan <mpetlan@redhat.com>
    Cc: Peter Zijlstra <peterz@infradead.org>
    Cc: Song Liu <songliubraving@fb.com>
    Cc: Will Deacon <will@kernel.org>
    Cc: linux-s390@vger.kernel.org
    Cc: linuxppc-dev@lists.ozlabs.org
    Link: https://lore.kernel.org/r/20220416004048.1514900-4-namhyung@kernel.org
    Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit cee5e9c3098addf1895a3544090d1f27dcd0e2bc
Author: Namhyung Kim <namhyung@kernel.org>
Date:   Fri Apr 15 17:40:47 2022 -0700

    perf symbol: Update symbols__fixup_end()
    
    commit 8799ebce84d672aae1dc3170510f6a3e66f96b11 upstream.
    
    Now arch-specific functions all do the same thing.  When it fixes the
    symbol address it needs to check the boundary between the kernel image
    and modules.  For the last symbol in the previous region, it cannot
    know the exact size as it's discarded already.  Thus it just uses a
    small page size (4096) and rounds it up like the last symbol.
    
    Fixes: 3cf6a32f3f2a4594 ("perf symbols: Fix symbol size calculation condition")
    Signed-off-by: Namhyung Kim <namhyung@kernel.org>
    Acked-by: Ian Rogers <irogers@google.com>
    Cc: Heiko Carstens <hca@linux.ibm.com>
    Cc: Ingo Molnar <mingo@kernel.org>
    Cc: Jiri Olsa <jolsa@kernel.org>
    Cc: John Garry <john.garry@huawei.com>
    Cc: Leo Yan <leo.yan@linaro.org>
    Cc: Mark Rutland <mark.rutland@arm.com>
    Cc: Masami Hiramatsu <mhiramat@kernel.org>
    Cc: Mathieu Poirier <mathieu.poirier@linaro.org>
    Cc: Michael Ellerman <mpe@ellerman.id.au>
    Cc: Michael Petlan <mpetlan@redhat.com>
    Cc: Peter Zijlstra <peterz@infradead.org>
    Cc: Song Liu <songliubraving@fb.com>
    Cc: Will Deacon <will@kernel.org>
    Cc: linux-s390@vger.kernel.org
    Cc: linuxppc-dev@lists.ozlabs.org
    Link: https://lore.kernel.org/r/20220416004048.1514900-3-namhyung@kernel.org
    Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 7fc597431d9e851dc1e713a160f7f58a3d402074
Author: Namhyung Kim <namhyung@kernel.org>
Date:   Fri Apr 15 17:40:46 2022 -0700

    perf symbol: Pass is_kallsyms to symbols__fixup_end()
    
    commit 838425f2defe5262906b698752d28fd2fca1aac2 upstream.
    
    The symbol fixup is necessary for symbols in kallsyms since they don't
    have size info.  So we use the next symbol's address to calculate the
    size.  Now it's also used for user binaries because sometimes they miss
    size for hand-written asm functions.
    
    There's a arch-specific function to handle kallsyms differently but
    currently it cannot distinguish kallsyms from others.  Pass this
    information explicitly to handle it properly.  Note that those arch
    functions will be moved to the generic function so I didn't added it to
    the arch-functions.
    
    Fixes: 3cf6a32f3f2a4594 ("perf symbols: Fix symbol size calculation condition")
    Signed-off-by: Namhyung Kim <namhyung@kernel.org>
    Acked-by: Ian Rogers <irogers@google.com>
    Cc: Heiko Carstens <hca@linux.ibm.com>
    Cc: Ingo Molnar <mingo@kernel.org>
    Cc: Jiri Olsa <jolsa@kernel.org>
    Cc: John Garry <john.garry@huawei.com>
    Cc: Leo Yan <leo.yan@linaro.org>
    Cc: Mark Rutland <mark.rutland@arm.com>
    Cc: Masami Hiramatsu <mhiramat@kernel.org>
    Cc: Mathieu Poirier <mathieu.poirier@linaro.org>
    Cc: Michael Ellerman <mpe@ellerman.id.au>
    Cc: Michael Petlan <mpetlan@redhat.com>
    Cc: Peter Zijlstra <peterz@infradead.org>
    Cc: Song Liu <songliubraving@fb.com>
    Cc: Will Deacon <will@kernel.org>
    Cc: linux-s390@vger.kernel.org
    Cc: linuxppc-dev@lists.ozlabs.org
    Link: https://lore.kernel.org/r/20220416004048.1514900-2-namhyung@kernel.org
    Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 6cbfdb3e89ee8ddbee2ee30d85930cf606271a40
Author: Tim Harvey <tharvey@gateworks.com>
Date:   Tue Apr 5 12:35:09 2022 -0700

    ARM: dts: imx8mm-venice-gw{71xx,72xx,73xx}: fix OTG controller OC mode
    
    commit 4c79865f3e8a2db93ec1e844509edfebe5a6ae56 upstream.
    
    The GW71xx, GW72xx and GW73xx boards have USB1 routed to a USB OTG
    connectors and USB2 routed to a USB hub.
    
    The OTG connector has a over-currently protection with an active-low
    pin and the USB1 to HUB connection has no over-current protection (as
    the HUB itself implements this for its downstream ports).
    
    Add proper dt nodes to specify the over-current pin polarity for USB1
    and disable over-current protection for USB2.
    
    Fixes: 6f30b27c5ef5 ("arm64: dts: imx8mm: Add Gateworks i.MX 8M Mini Development Kits")
    Cc: stable@vger.kernel.org
    Signed-off-by: Tim Harvey <tharvey@gateworks.com>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 635aaa4c2d589ef9bc1a66110b0199cd146bb6fe
Author: Eugen Hristev <eugen.hristev@microchip.com>
Date:   Mon Mar 7 13:38:27 2022 +0200

    ARM: dts: at91: sama7g5ek: enable pull-up on flexcom3 console lines
    
    commit 3f7ce6d7091765ed6c67c5d78aa364b9d17e3aab upstream.
    
    Flexcom3 is used as board console serial. There are no pull-ups on these
    lines on the board. This means that if a cable is not connected (that has
    pull-ups included), stray characters could appear on the console as the
    floating pins voltage levels are interpreted as incoming characters.
    To avoid this problem, enable the internal pull-ups on these lines.
    
    Fixes: 7540629e2fc7 ("ARM: dts: at91: add sama7g5 SoC DT and sama7g5-ek")
    Cc: stable@vger.kernel.org # v5.15+
    Signed-off-by: Eugen Hristev <eugen.hristev@microchip.com>
    Reviewed-by: Tudor Ambarus <tudor.ambarus@microchip.com>
    Signed-off-by: Nicolas Ferre <nicolas.ferre@microchip.com>
    Link: https://lore.kernel.org/r/20220307113827.2419331-1-eugen.hristev@microchip.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 05c7d65249c439e20e9c59654b6dd1dc4b6733ad
Author: Filipe Manana <fdmanana@suse.com>
Date:   Tue Apr 19 14:23:57 2022 +0100

    btrfs: fix assertion failure during scrub due to block group reallocation
    
    commit a692e13d87cb6d0193387aac55cfcc947077c20b upstream.
    
    During a scrub, or device replace, we can race with block group removal
    and allocation and trigger the following assertion failure:
    
    [7526.385524] assertion failed: cache->start == chunk_offset, in fs/btrfs/scrub.c:3817
    [7526.387351] ------------[ cut here ]------------
    [7526.387373] kernel BUG at fs/btrfs/ctree.h:3599!
    [7526.388001] invalid opcode: 0000 [#1] PREEMPT SMP DEBUG_PAGEALLOC PTI
    [7526.388970] CPU: 2 PID: 1158150 Comm: btrfs Not tainted 5.17.0-rc8-btrfs-next-114 #4
    [7526.390279] Hardware name: QEMU Standard PC (i440FX + PIIX, 1996), BIOS rel-1.14.0-0-g155821a1990b-prebuilt.qemu.org 04/01/2014
    [7526.392430] RIP: 0010:assertfail.constprop.0+0x18/0x1a [btrfs]
    [7526.393520] Code: f3 48 c7 c7 20 (...)
    [7526.396926] RSP: 0018:ffffb9154176bc40 EFLAGS: 00010246
    [7526.397690] RAX: 0000000000000048 RBX: ffffa0db8a910000 RCX: 0000000000000000
    [7526.398732] RDX: 0000000000000000 RSI: ffffffff9d7239a2 RDI: 00000000ffffffff
    [7526.399766] RBP: ffffa0db8a911e10 R08: ffffffffa71a3ca0 R09: 0000000000000001
    [7526.400793] R10: 0000000000000001 R11: 0000000000000000 R12: ffffa0db4b170800
    [7526.401839] R13: 00000003494b0000 R14: ffffa0db7c55b488 R15: ffffa0db8b19a000
    [7526.402874] FS:  00007f6c99c40640(0000) GS:ffffa0de6d200000(0000) knlGS:0000000000000000
    [7526.404038] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
    [7526.405040] CR2: 00007f31b0882160 CR3: 000000014b38c004 CR4: 0000000000370ee0
    [7526.406112] DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
    [7526.407148] DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
    [7526.408169] Call Trace:
    [7526.408529]  <TASK>
    [7526.408839]  scrub_enumerate_chunks.cold+0x11/0x79 [btrfs]
    [7526.409690]  ? do_wait_intr_irq+0xb0/0xb0
    [7526.410276]  btrfs_scrub_dev+0x226/0x620 [btrfs]
    [7526.410995]  ? preempt_count_add+0x49/0xa0
    [7526.411592]  btrfs_ioctl+0x1ab5/0x36d0 [btrfs]
    [7526.412278]  ? __fget_files+0xc9/0x1b0
    [7526.412825]  ? kvm_sched_clock_read+0x14/0x40
    [7526.413459]  ? lock_release+0x155/0x4a0
    [7526.414022]  ? __x64_sys_ioctl+0x83/0xb0
    [7526.414601]  __x64_sys_ioctl+0x83/0xb0
    [7526.415150]  do_syscall_64+0x3b/0xc0
    [7526.415675]  entry_SYSCALL_64_after_hwframe+0x44/0xae
    [7526.416408] RIP: 0033:0x7f6c99d34397
    [7526.416931] Code: 3c 1c e8 1c ff (...)
    [7526.419641] RSP: 002b:00007f6c99c3fca8 EFLAGS: 00000246 ORIG_RAX: 0000000000000010
    [7526.420735] RAX: ffffffffffffffda RBX: 00005624e1e007b0 RCX: 00007f6c99d34397
    [7526.421779] RDX: 00005624e1e007b0 RSI: 00000000c400941b RDI: 0000000000000003
    [7526.422820] RBP: 0000000000000000 R08: 00007f6c99c40640 R09: 0000000000000000
    [7526.423906] R10: 00007f6c99c40640 R11: 0000000000000246 R12: 00007fff746755de
    [7526.424924] R13: 00007fff746755df R14: 0000000000000000 R15: 00007f6c99c40640
    [7526.425950]  </TASK>
    
    That assertion is relatively new, introduced with commit d04fbe19aefd2
    ("btrfs: scrub: cleanup the argument list of scrub_chunk()").
    
    The block group we get at scrub_enumerate_chunks() can actually have a
    start address that is smaller then the chunk offset we extracted from a
    device extent item we got from the commit root of the device tree.
    This is very rare, but it can happen due to a race with block group
    removal and allocation. For example, the following steps show how this
    can happen:
    
    1) We are at transaction T, and we have the following blocks groups,
       sorted by their logical start address:
    
       [ bg A, start address A, length 1G (data) ]
       [ bg B, start address B, length 1G (data) ]
       (...)
       [ bg W, start address W, length 1G (data) ]
    
         --> logical address space hole of 256M,
             there used to be a 256M metadata block group here
    
       [ bg Y, start address Y, length 256M (metadata) ]
    
          --> Y matches W's end offset + 256M
    
       Block group Y is the block group with the highest logical address in
       the whole filesystem;
    
    2) Block group Y is deleted and its extent mapping is removed by the call
       to remove_extent_mapping() made from btrfs_remove_block_group().
    
       So after this point, the last element of the mapping red black tree,
       its rightmost node, is the mapping for block group W;
    
    3) While still at transaction T, a new data block group is allocated,
       with a length of 1G. When creating the block group we do a call to
       find_next_chunk(), which returns the logical start address for the
       new block group. This calls returns X, which corresponds to the
       end offset of the last block group, the rightmost node in the mapping
       red black tree (fs_info->mapping_tree), plus one.
    
       So we get a new block group that starts at logical address X and with
       a length of 1G. It spans over the whole logical range of the old block
       group Y, that was previously removed in the same transaction.
    
       However the device extent allocated to block group X is not the same
       device extent that was used by block group Y, and it also does not
       overlap that extent, which must be always the case because we allocate
       extents by searching through the commit root of the device tree
       (otherwise it could corrupt a filesystem after a power failure or
       an unclean shutdown in general), so the extent allocator is behaving
       as expected;
    
    4) We have a task running scrub, currently at scrub_enumerate_chunks().
       There it searches for device extent items in the device tree, using
       its commit root. It finds a device extent item that was used by
       block group Y, and it extracts the value Y from that item into the
       local variable 'chunk_offset', using btrfs_dev_extent_chunk_offset();
    
       It then calls btrfs_lookup_block_group() to find block group for
       the logical address Y - since there's currently no block group that
       starts at that logical address, it returns block group X, because
       its range contains Y.
    
       This results in triggering the assertion:
    
          ASSERT(cache->start == chunk_offset);
    
       right before calling scrub_chunk(), as cache->start is X and
       chunk_offset is Y.
    
    This is more likely to happen of filesystems not larger than 50G, because
    for these filesystems we use a 256M size for metadata block groups and
    a 1G size for data block groups, while for filesystems larger than 50G,
    we use a 1G size for both data and metadata block groups (except for
    zoned filesystems). It could also happen on any filesystem size due to
    the fact that system block groups are always smaller (32M) than both
    data and metadata block groups, but these are not frequently deleted, so
    much less likely to trigger the race.
    
    So make scrub skip any block group with a start offset that is less than
    the value we expect, as that means it's a new block group that was created
    in the current transaction. It's pointless to continue and try to scrub
    its extents, because scrub searches for extents using the commit root, so
    it won't find any. For a device replace, skip it as well for the same
    reasons, and we don't need to worry about the possibility of extents of
    the new block group not being to the new device, because we have the write
    duplication setup done through btrfs_map_block().
    
    Fixes: d04fbe19aefd ("btrfs: scrub: cleanup the argument list of scrub_chunk()")
    CC: stable@vger.kernel.org # 5.17
    Signed-off-by: Filipe Manana <fdmanana@suse.com>
    Signed-off-by: David Sterba <dsterba@suse.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 35958fde4fbf40715cd98d01f5f549b5e0654bdf
Author: Naohiro Aota <naohiro.aota@wdc.com>
Date:   Mon Apr 18 16:15:03 2022 +0900

    btrfs: zoned: use dedicated lock for data relocation
    
    commit 5f0addf7b89085f8e0a2593faa419d6111612b9b upstream.
    
    Currently, we use btrfs_inode_{lock,unlock}() to grant an exclusive
    writeback of the relocation data inode in
    btrfs_zoned_data_reloc_{lock,unlock}(). However, that can cause a deadlock
    in the following path.
    
    Thread A takes btrfs_inode_lock() and waits for metadata reservation by
    e.g, waiting for writeback:
    
    prealloc_file_extent_cluster()
      - btrfs_inode_lock(&inode->vfs_inode, 0);
      - btrfs_prealloc_file_range()
      ...
        - btrfs_replace_file_extents()
          - btrfs_start_transaction
          ...
            - btrfs_reserve_metadata_bytes()
    
    Thread B (e.g, doing a writeback work) needs to wait for the inode lock to
    continue writeback process:
    
    do_writepages
      - btrfs_writepages
        - extent_writpages
          - btrfs_zoned_data_reloc_lock(BTRFS_I(inode));
            - btrfs_inode_lock()
    
    The deadlock is caused by relying on the vfs_inode's lock. By using it, we
    introduced unnecessary exclusion of writeback and
    btrfs_prealloc_file_range(). Also, the lock at this point is useless as we
    don't have any dirty pages in the inode yet.
    
    Introduce fs_info->zoned_data_reloc_io_lock and use it for the exclusive
    writeback.
    
    Fixes: 35156d852762 ("btrfs: zoned: only allow one process to add pages to a relocation inode")
    CC: stable@vger.kernel.org # 5.16.x: 869f4cdc73f9: btrfs: zoned: encapsulate inode locking for zoned relocation
    CC: stable@vger.kernel.org # 5.16.x
    CC: stable@vger.kernel.org # 5.17
    Cc: Johannes Thumshirn <johannes.thumshirn@wdc.com>
    Reviewed-by: Johannes Thumshirn <johannes.thumshirn@wdc.com>
    Signed-off-by: Naohiro Aota <naohiro.aota@wdc.com>
    Signed-off-by: David Sterba <dsterba@suse.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 05d8c48a3aeb91b08932b93fda9ff41b0d318aa5
Author: Filipe Manana <fdmanana@suse.com>
Date:   Wed Apr 6 17:07:54 2022 +0100

    btrfs: fix leaked plug after failure syncing log on zoned filesystems
    
    commit 50ff57888d0b13440e7f4cde05dc339ee8d0f1f8 upstream.
    
    On a zoned filesystem, if we fail to allocate the root node for the log
    root tree while syncing the log, we end up returning without finishing
    the IO plug we started before, resulting in leaking resources as we
    have started writeback for extent buffers of a log tree before. That
    allocation failure, which typically is either -ENOMEM or -ENOSPC, is not
    fatal and the fsync can safely fallback to a full transaction commit.
    
    So release the IO plug if we fail to allocate the extent buffer for the
    root of the log root tree when syncing the log on a zoned filesystem.
    
    Fixes: 3ddebf27fcd3a9 ("btrfs: zoned: reorder log node allocation on zoned filesystem")
    CC: stable@vger.kernel.org # 5.15+
    Reviewed-by: Johannes Thumshirn <johannes.thumshirn@wdc.com>
    Signed-off-by: Filipe Manana <fdmanana@suse.com>
    Reviewed-by: David Sterba <dsterba@suse.com>
    Signed-off-by: David Sterba <dsterba@suse.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 7a20454bd813a2cba9fa1915702c4f59d8b0b7da
Author: Christoph Hellwig <hch@lst.de>
Date:   Thu Mar 24 17:06:28 2022 +0100

    btrfs: fix direct I/O writes for split bios on zoned devices
    
    commit 0fdf977d4576ee0decd612e22f6a837a239573cc upstream.
    
    When a bio is split in btrfs_submit_direct, dip->file_offset contains
    the file offset for the first bio.  But this means the start value used
    in btrfs_end_dio_bio to record the write location for zone devices is
    incorrect for subsequent bios.
    
    CC: stable@vger.kernel.org # 5.16+
    Reviewed-by: Johannes Thumshirn <johannes.thumshirn@wdc.com>
    Reviewed-by: Naohiro Aota <naohiro.aota@wdc.com>
    Reviewed-by: Qu Wenruo <wqu@suse.com>
    Reviewed-by: Sweet Tea Dorminy <sweettea-kernel@dorminy.me>
    Signed-off-by: Christoph Hellwig <hch@lst.de>
    Signed-off-by: David Sterba <dsterba@suse.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit c7c7abde8f38a01568601ed9933d37f12afd91eb
Author: Christoph Hellwig <hch@lst.de>
Date:   Thu Mar 24 17:06:27 2022 +0100

    btrfs: fix direct I/O read repair for split bios
    
    commit 00d825258bcc09c0e1b99aa7f9ad7d2c2fad41fa upstream.
    
    When a bio is split in btrfs_submit_direct, dip->file_offset contains
    the file offset for the first bio.  But this means the start value used
    in btrfs_check_read_dio_bio is incorrect for subsequent bios.  Add
    a file_offset field to struct btrfs_bio to pass along the correct offset.
    
    Given that check_data_csum only uses start of an error message this
    means problems with this miscalculation will only show up when I/O fails
    or checksums mismatch.
    
    The logic was removed in f4f39fc5dc30 ("btrfs: remove btrfs_bio::logical
    member") but we need it due to the bio splitting.
    
    CC: stable@vger.kernel.org # 5.16+
    Reviewed-by: Johannes Thumshirn <johannes.thumshirn@wdc.com>
    Reviewed-by: Naohiro Aota <naohiro.aota@wdc.com>
    Reviewed-by: Qu Wenruo <wqu@suse.com>
    Reviewed-by: Sweet Tea Dorminy <sweettea-kernel@dorminy.me>
    Signed-off-by: Christoph Hellwig <hch@lst.de>
    Signed-off-by: David Sterba <dsterba@suse.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit abcffdd9d5ef83a07d418651f59a6f34a3b3c8cf
Author: Kees Cook <keescook@chromium.org>
Date:   Thu Apr 21 09:55:04 2022 -0700

    thermal: int340x: Fix attr.show callback prototype
    
    commit d0f6cfb2bd165b0aa307750e07e03420859bd554 upstream.
    
    Control Flow Integrity (CFI) instrumentation of the kernel noticed that
    the caller, dev_attr_show(), and the callback, odvp_show(), did not have
    matching function prototypes, which would cause a CFI exception to be
    raised. Correct the prototype by using struct device_attribute instead
    of struct kobj_attribute.
    
    Reported-and-tested-by: Joao Moreira <joao@overdrivepizza.com>
    Link: https://lore.kernel.org/lkml/067ce8bd4c3968054509831fa2347f4f@overdrivepizza.com/
    Fixes: 006f006f1e5c ("thermal/int340x_thermal: Export OEM vendor variables")
    Cc: 5.8+ <stable@vger.kernel.org> # 5.8+
    Signed-off-by: Kees Cook <keescook@chromium.org>
    Signed-off-by: Rafael J. Wysocki <rafael.j.wysocki@intel.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit b3b0ca1c324982fcc005063af045439670e16aa3
Author: Ville Syrjälä <ville.syrjala@linux.intel.com>
Date:   Thu Apr 21 16:36:34 2022 +0300

    ACPI: processor: idle: Avoid falling back to C3 type C-states
    
    commit fc45e55ebc58dbf622cb89ddbf797589c7a5510b upstream.
    
    The "safe state" index is used by acpi_idle_enter_bm() to avoid
    entering a C-state that may require bus mastering to be disabled
    on entry in the cases when this is not going to happen.  For this
    reason, it should not be set to point to C3 type of C-states, because
    they may require bus mastering to be disabled on entry in principle.
    
    This was broken by commit d6b88ce2eb9d ("ACPI: processor idle: Allow
    playing dead in C3 state") which inadvertently allowed the "safe
    state" index to point to C3 type of C-states.
    
    This results in a machine that won't boot past the point when it first
    enters C3. Restore the correct behaviour (either demote to C1/C2, or
    use C3 but also set ARB_DIS=1).
    
    I hit this on a Fujitsu Siemens Lifebook S6010 (P3) machine.
    
    Fixes: d6b88ce2eb9d ("ACPI: processor idle: Allow playing dead in C3 state")
    Cc: 5.16+ <stable@vger.kernel.org> # 5.16+
    Signed-off-by: Ville Syrjälä <ville.syrjala@linux.intel.com>
    Tested-by: Woody Suwalski <wsuwalski@gmail.com>
    [ rjw: Subject and changelog adjustments ]
    Signed-off-by: Rafael J. Wysocki <rafael.j.wysocki@intel.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit e1bfb602164bfd85d679731c50979906c1797bfc
Author: Dinh Nguyen <dinguyen@kernel.org>
Date:   Wed Apr 20 10:23:45 2022 -0500

    net: ethernet: stmmac: fix write to sgmii_adapter_base
    
    commit 5fd1fe4807f91ea0cca043114d929faa11bd4190 upstream.
    
    I made a mistake with the commit a6aaa0032424 ("net: ethernet: stmmac:
    fix altr_tse_pcs function when using a fixed-link"). I should have
    tested against both scenario of having a SGMII interface and one
    without.
    
    Without the SGMII PCS TSE adpater, the sgmii_adapter_base address is
    NULL, thus a write to this address will fail.
    
    Cc: stable@vger.kernel.org
    Fixes: a6aaa0032424 ("net: ethernet: stmmac: fix altr_tse_pcs function when using a fixed-link")
    Signed-off-by: Dinh Nguyen <dinguyen@kernel.org>
    Link: https://lore.kernel.org/r/20220420152345.27415-1-dinguyen@kernel.org
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 7c8e9b0a4b55b3bce8837ca1a5718ecf085ccae8
Author: Imre Deak <imre.deak@intel.com>
Date:   Thu Apr 21 19:22:21 2022 +0300

    drm/i915: Fix SEL_FETCH_PLANE_*(PIPE_B+) register addresses
    
    commit 4ae4dd2e26fdfebf0b8c6af6c325383eadfefdb4 upstream.
    
    Fix typo in the _SEL_FETCH_PLANE_BASE_1_B register base address.
    
    Fixes: a5523e2ff074a5 ("drm/i915: Add PSR2 selective fetch registers")
    References: https://gitlab.freedesktop.org/drm/intel/-/issues/5400
    Cc: José Roberto de Souza <jose.souza@intel.com>
    Cc: <stable@vger.kernel.org> # v5.9+
    Signed-off-by: Imre Deak <imre.deak@intel.com>
    Reviewed-by: José Roberto de Souza <jose.souza@intel.com>
    Link: https://patchwork.freedesktop.org/patch/msgid/20220421162221.2261895-1-imre.deak@intel.com
    (cherry picked from commit af2cbc6ef967f61711a3c40fca5366ea0bc7fecc)
    Signed-off-by: Joonas Lahtinen <joonas.lahtinen@linux.intel.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 34357b1bc3e087d0648d71e998599e9006e8f1d3
Author: Jouni Högander <jouni.hogander@intel.com>
Date:   Wed Apr 13 11:28:26 2022 +0300

    drm/i915: Check EDID for HDR static metadata when choosing blc
    
    commit c05d8332f5d23fa3b521911cbe55a2b67fb21248 upstream.
    
    We have now seen panel (XMG Core 15 e21 laptop) advertizing support
    for Intel proprietary eDP backlight control via DPCD registers, but
    actually working only with legacy pwm control.
    
    This patch adds panel EDID check for possible HDR static metadata and
    Intel proprietary eDP backlight control is used only if that exists.
    Missing HDR static metadata is ignored if user specifically asks for
    Intel proprietary eDP backlight control via enable_dpcd_backlight
    parameter.
    
    v2 :
    - Ignore missing HDR static metadata if Intel proprietary eDP
      backlight control is forced via i915.enable_dpcd_backlight
    - Printout info message if panel is missing HDR static metadata and
      support for Intel proprietary eDP backlight control is detected
    
    Fixes: 4a8d79901d5b ("drm/i915/dp: Enable Intel's HDR backlight interface (only SDR for now)")
    Closes: https://gitlab.freedesktop.org/drm/intel/-/issues/5284
    Cc: Lyude Paul <lyude@redhat.com>
    Cc: Mika Kahola <mika.kahola@intel.com>
    Cc: Jani Nikula <jani.nikula@intel.com>
    Cc: Filippo Falezza <filippo.falezza@outlook.it>
    Cc: stable@vger.kernel.org
    Signed-off-by: Jouni Högander <jouni.hogander@intel.com>
    Signed-off-by: Ville Syrjälä <ville.syrjala@linux.intel.com>
    Link: https://patchwork.freedesktop.org/patch/msgid/20220413082826.120634-1-jouni.hogander@intel.com
    Reviewed-by: Lyude Paul <lyude@redhat.com>
    (cherry picked from commit b4b157577cb1de13bee8bebc3576f1de6799a921)
    Signed-off-by: Joonas Lahtinen <joonas.lahtinen@linux.intel.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit c5945e7ca00637d64d65f1aef33403452ccd9704
Author: Alex Deucher <alexander.deucher@amd.com>
Date:   Tue Dec 28 17:26:24 2021 -0500

    drm/amdgpu: don't runtime suspend if there are displays attached (v3)
    
    commit f95af4a9236695caed24fe6401256bb974e8f2a7 upstream.
    
    We normally runtime suspend when there are displays attached if they
    are in the DPMS off state, however, if something wakes the GPU
    we send a hotplug event on resume (in case any displays were connected
    while the GPU was in suspend) which can cause userspace to light
    up the displays again soon after they were turned off.
    
    Prior to
    commit 087451f372bf76 ("drm/amdgpu: use generic fb helpers instead of setting up AMD own's."),
    the driver took a runtime pm reference when the fbdev emulation was
    enabled because we didn't implement proper shadowing support for
    vram access when the device was off so the device never runtime
    suspended when there was a console bound.  Once that commit landed,
    we now utilize the core fb helper implementation which properly
    handles the emulation, so runtime pm now suspends in cases where it did
    not before.  Ultimately, we need to sort out why runtime suspend in not
    working in this case for some users, but this should restore similar
    behavior to before.
    
    v2: move check into runtime_suspend
    v3: wake ups -> wakeups in comment, retain pm_runtime behavior in
        runtime_idle callback
    
    Fixes: 087451f372bf76 ("drm/amdgpu: use generic fb helpers instead of setting up AMD own's.")
    Link: https://lore.kernel.org/r/20220403132322.51c90903@darkstar.example.org/
    Tested-by: Michele Ballabio <ballabio.m@gmail.com>
    Reviewed-by: Evan Quan <evan.quan@amd.com>
    Signed-off-by: Alex Deucher <alexander.deucher@amd.com>
    Cc: stable@vger.kernel.org
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 57a02313d93011a20d4a097c5c0a5927e191054a
Author: Martin Willi <martin@strongswan.org>
Date:   Tue Apr 19 15:47:00 2022 +0200

    netfilter: Update ip6_route_me_harder to consider L3 domain
    
    commit 8ddffdb9442a9d60b4a6e679ac48d7d21403a674 upstream.
    
    The commit referenced below fixed packet re-routing if Netfilter mangles
    a routing key property of a packet and the packet is routed in a VRF L3
    domain. The fix, however, addressed IPv4 re-routing, only.
    
    This commit applies the same behavior for IPv6. While at it, untangle
    the nested ternary operator to make the code more readable.
    
    Fixes: 6d8b49c3a3a3 ("netfilter: Update ip_route_me_harder to consider L3 domain")
    Cc: stable@vger.kernel.org
    Signed-off-by: Martin Willi <martin@strongswan.org>
    Reviewed-by: David Ahern <dsahern@kernel.org>
    Signed-off-by: Pablo Neira Ayuso <pablo@netfilter.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 63244a07d4afb68c0d403ec527a36fc406fa8f50
Author: Md Sadre Alam <quic_mdalam@quicinc.com>
Date:   Mon Apr 18 13:18:27 2022 +0530

    mtd: rawnand: qcom: fix memory corruption that causes panic
    
    commit ba7542eb2dd5dfc75c457198b88986642e602065 upstream.
    
    This patch fixes a memory corruption that occurred in the
    nand_scan() path for Hynix nand device.
    
    On boot, for Hynix nand device will panic at a weird place:
    | Unable to handle kernel NULL pointer dereference at virtual
      address 00000070
    | [00000070] *pgd=00000000
    | Internal error: Oops: 5 [#1] PREEMPT SMP ARM
    | Modules linked in:
    | CPU: 0 PID: 1 Comm: swapper/0 Not tainted 5.17.0-01473-g13ae1769cfb0
      #38
    | Hardware name: Generic DT based system
    | PC is at nandc_set_reg+0x8/0x1c
    | LR is at qcom_nandc_command+0x20c/0x5d0
    | pc : [<c088b74c>]    lr : [<c088d9c8>]    psr: 00000113
    | sp : c14adc50  ip : c14ee208  fp : c0cc970c
    | r10: 000000a3  r9 : 00000000  r8 : 00000040
    | r7 : c16f6a00  r6 : 00000090  r5 : 00000004  r4 :c14ee040
    | r3 : 00000000  r2 : 0000000b  r1 : 00000000  r0 :c14ee040
    | Flags: nzcv  IRQs on  FIQs on  Mode SVC_32  ISA ARM Segment none
    | Control: 10c5387d  Table: 8020406a  DAC: 00000051
    | Register r0 information: slab kmalloc-2k start c14ee000 pointer offset
      64 size 2048
    | Process swapper/0 (pid: 1, stack limit = 0x(ptrval))
    | nandc_set_reg from qcom_nandc_command+0x20c/0x5d0
    | qcom_nandc_command from nand_readid_op+0x198/0x1e8
    | nand_readid_op from hynix_nand_has_valid_jedecid+0x30/0x78
    | hynix_nand_has_valid_jedecid from hynix_nand_init+0xb8/0x454
    | hynix_nand_init from nand_scan_with_ids+0xa30/0x14a8
    | nand_scan_with_ids from qcom_nandc_probe+0x648/0x7b0
    | qcom_nandc_probe from platform_probe+0x58/0xac
    
    The problem is that the nand_scan()'s qcom_nand_attach_chip callback
    is updating the nandc->max_cwperpage from 1 to 4 or 8 based on page size.
    This causes the sg_init_table of clear_bam_transaction() in the driver's
    qcom_nandc_command() to memset much more than what was initially
    allocated by alloc_bam_transaction().
    
    This patch will update nandc->max_cwperpage 1 to 4 or 8 based on page
    size in qcom_nand_attach_chip call back after freeing the previously
    allocated memory for bam txn as per nandc->max_cwperpage = 1 and then
    again allocating bam txn as per nandc->max_cwperpage = 4 or 8 based on
    page size in qcom_nand_attach_chip call back itself.
    
    Cc: stable@vger.kernel.org
    Fixes: 6a3cec64f18c ("mtd: rawnand: qcom: convert driver to nand_scan()")
    Reported-by: Konrad Dybcio <konrad.dybcio@somainline.org>
    Reviewed-by: Manivannan Sadhasivam <manivannan.sadhasivam@linaro.org>
    Co-developed-by: Sricharan R <quic_srichara@quicinc.com>
    Signed-off-by: Sricharan R <quic_srichara@quicinc.com>
    Signed-off-by: Md Sadre Alam <quic_mdalam@quicinc.com>
    Signed-off-by: Miquel Raynal <miquel.raynal@bootlin.com>
    Link: https://lore.kernel.org/linux-mtd/1650268107-5363-1-git-send-email-quic_mdalam@quicinc.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 802282dc66f08b002a1dce655cb9782df6e6ac36
Author: Zqiang <qiang1.zhang@intel.com>
Date:   Wed Apr 27 12:41:56 2022 -0700

    kasan: prevent cpu_quarantine corruption when CPU offline and cache shrink occur at same time
    
    commit 31fa985b4196f8a66f027672e9bf2b81fea0417c upstream.
    
    kasan_quarantine_remove_cache() is called in kmem_cache_shrink()/
    destroy().  The kasan_quarantine_remove_cache() call is protected by
    cpuslock in kmem_cache_destroy() to ensure serialization with
    kasan_cpu_offline().
    
    However the kasan_quarantine_remove_cache() call is not protected by
    cpuslock in kmem_cache_shrink().  When a CPU is going offline and cache
    shrink occurs at same time, the cpu_quarantine may be corrupted by
    interrupt (per_cpu_remove_cache operation).
    
    So add a cpu_quarantine offline flags check in per_cpu_remove_cache().
    
    [akpm@linux-foundation.org: add comment, per Zqiang]
    
    Link: https://lkml.kernel.org/r/20220414025925.2423818-1-qiang1.zhang@intel.com
    Signed-off-by: Zqiang <qiang1.zhang@intel.com>
    Reviewed-by: Dmitry Vyukov <dvyukov@google.com>
    Cc: Andrey Ryabinin <ryabinin.a.a@gmail.com>
    Cc: Alexander Potapenko <glider@google.com>
    Cc: Andrey Konovalov <andreyknvl@gmail.com>
    Cc: <stable@vger.kernel.org>
    Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
    Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 3ebe57cf3edcd25d97175d0eda0df83b2c3f0367
Author: Damien Le Moal <damien.lemoal@opensource.wdc.com>
Date:   Tue Apr 12 20:52:35 2022 +0900

    zonefs: Clear inode information flags on inode creation
    
    commit 694852ead287a3433126e7ebda397b242dc99624 upstream.
    
    Ensure that the i_flags field of struct zonefs_inode_info is cleared to
    0 when initializing a zone file inode, avoiding seeing the flag
    ZONEFS_ZONE_OPEN being incorrectly set.
    
    Fixes: b5c00e975779 ("zonefs: open/close zone on file open/close")
    Cc: <stable@vger.kernel.org>
    Signed-off-by: Damien Le Moal <damien.lemoal@opensource.wdc.com>
    Reviewed-by: Johannes Thumshirn <johannes.thumshirn@wdc.com>
    Reviewed-by: Chaitanya Kulkarni <kch@nvidia.com>
    Reviewed-by: Hans Holmberg <hans.holmberg@wdc.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit e63193b76999c3e5af592a5f79d6c54d14496e79
Author: Damien Le Moal <damien.lemoal@opensource.wdc.com>
Date:   Tue Apr 12 17:41:37 2022 +0900

    zonefs: Fix management of open zones
    
    commit 1da18a296f5ba4f99429e62a7cf4fdbefa598902 upstream.
    
    The mount option "explicit_open" manages the device open zone
    resources to ensure that if an application opens a sequential file for
    writing, the file zone can always be written by explicitly opening
    the zone and accounting for that state with the s_open_zones counter.
    
    However, if some zones are already open when mounting, the device open
    zone resource usage status will be larger than the initial s_open_zones
    value of 0. Ensure that this inconsistency does not happen by closing
    any sequential zone that is open when mounting.
    
    Furthermore, with ZNS drives, closing an explicitly open zone that has
    not been written will change the zone state to "closed", that is, the
    zone will remain in an active state. Since this can then cause failures
    of explicit open operations on other zones if the drive active zone
    resources are exceeded, we need to make sure that the zone is not
    active anymore by resetting it instead of closing it. To address this,
    zonefs_zone_mgmt() is modified to change a REQ_OP_ZONE_CLOSE request
    into a REQ_OP_ZONE_RESET for sequential zones that have not been
    written.
    
    Fixes: b5c00e975779 ("zonefs: open/close zone on file open/close")
    Cc: <stable@vger.kernel.org>
    Signed-off-by: Damien Le Moal <damien.lemoal@opensource.wdc.com>
    Reviewed-by: Johannes Thumshirn <johannes.thumshirn@wdc.com>
    Reviewed-by: Hans Holmberg <hans.holmberg@wdc.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 290ca230b81b0de657c38284aadcdf60db034f74
Author: Tejun Heo <tj@kernel.org>
Date:   Wed Apr 27 09:49:12 2022 -1000

    Revert "block: inherit request start time from bio for BLK_CGROUP"
    
    commit 4cddeacad6d4b23493a108d0705e7d2ab89ba5a3 upstream.
    
    This reverts commit 0006707723233cb2a9a23ca19fc3d0864835704c. It has a
    couple problems:
    
    * bio_issue_time() is stored in bio->bi_issue truncated to 51 bits. This
      overflows in slightly over 26 days. Setting rq->io_start_time_ns with it
      means that io duration calculation would yield >26days after 26 days of
      uptime. This, for example, confuses kyber making it cause high IO
      latencies.
    
    * rq->io_start_time_ns should record the time that the IO is issued to the
      device so that on-device latency can be measured. However,
      bio_issue_time() is set before the bio goes through the rq-qos controllers
      (wbt, iolatency, iocost), so when the bio gets throttled in any of the
      mechanisms, the measured latencies make no sense - on-device latencies end
      up higher than request-alloc-to-completion latencies.
    
    We'll need a smarter way to avoid calling ktime_get_ns() repeatedly
    back-to-back. For now, let's revert the commit.
    
    Signed-off-by: Tejun Heo <tj@kernel.org>
    Cc: stable@vger.kernel.org # v5.16+
    Link: https://lore.kernel.org/r/YmmeOLfo5lzc+8yI@slm.duckdns.org
    Signed-off-by: Jens Axboe <axboe@kernel.dk>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 14defb873c1dc4cef1e7e7951f47f019821734fc
Author: Ville Syrjälä <ville.syrjala@linux.intel.com>
Date:   Wed Apr 20 16:44:17 2022 +0300

    Revert "ACPI: processor: idle: fix lockup regression on 32-bit ThinkPad T40"
    
    commit 20e582e16af24b074e583f9551fad557882a3c9d upstream.
    
    This reverts commit bfe55a1f7fd6bfede16078bf04c6250fbca11588.
    
    This was presumably misdiagnosed as an inability to use C3 at
    all when I suspect the real problem is just misconfiguration of
    C3 vs. ARB_DIS.
    
    Signed-off-by: Ville Syrjälä <ville.syrjala@linux.intel.com>
    Cc: 5.16+ <stable@vger.kernel.org> # 5.16+
    Tested-by: Woody Suwalski <wsuwalski@gmail.com>
    Signed-off-by: Rafael J. Wysocki <rafael.j.wysocki@intel.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 229deb36d1eee86daee46273cdd024098b8954b9
Author: Jan Kara <jack@suse.cz>
Date:   Thu Apr 7 16:07:38 2022 +0200

    bfq: Fix warning in bfqq_request_over_limit()
    
    commit 09df6a75fffa68169c5ef9bef990cd7ba94f3eef upstream.
    
    People are occasionally reporting a warning bfqq_request_over_limit()
    triggering reporting that BFQ's idea of cgroup hierarchy (and its depth)
    does not match what generic blkcg code thinks. This can actually happen
    when bfqq gets moved between BFQ groups while bfqq_request_over_limit()
    is running. Make sure the code is safe against BFQ queue being moved to
    a different BFQ group.
    
    Fixes: 76f1df88bbc2 ("bfq: Limit number of requests consumed by each cgroup")
    CC: stable@vger.kernel.org
    Link: https://lore.kernel.org/all/CAJCQCtTw_2C7ZSz7as5Gvq=OmnDiio=HRkQekqWpKot84sQhFA@mail.gmail.com/
    Reported-by: Chris Murphy <lists@colorremedies.com>
    Reported-by: "yukuai (C)" <yukuai3@huawei.com>
    Signed-off-by: Jan Kara <jack@suse.cz>
    Link: https://lore.kernel.org/r/20220407140738.9723-1-jack@suse.cz
    Signed-off-by: Jens Axboe <axboe@kernel.dk>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 373c331da4ab83d98c745accd6c1743c7f604f77
Author: Sidhartha Kumar <sidhartha.kumar@oracle.com>
Date:   Thu Apr 21 16:35:52 2022 -0700

    selftest/vm: verify remap destination address in mremap_test
    
    [ Upstream commit 18d609daa546c919fd36b62a7b510c18de4b4af8 ]
    
    Because mremap does not have a MAP_FIXED_NOREPLACE flag, it can destroy
    existing mappings.  This causes a segfault when regions such as text are
    remapped and the permissions are changed.
    
    Verify the requested mremap destination address does not overlap any
    existing mappings by using mmap's MAP_FIXED_NOREPLACE flag.  Keep
    incrementing the destination address until a valid mapping is found or
    fail the current test once the max address is reached.
    
    Link: https://lkml.kernel.org/r/20220420215721.4868-2-sidhartha.kumar@oracle.com
    Signed-off-by: Sidhartha Kumar <sidhartha.kumar@oracle.com>
    Reviewed-by: Shuah Khan <skhan@linuxfoundation.org>
    Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
    Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 2d93e9af7a96db716257353c1b2d2be5e628398b
Author: Sidhartha Kumar <sidhartha.kumar@oracle.com>
Date:   Thu Apr 21 16:35:49 2022 -0700

    selftest/vm: verify mmap addr in mremap_test
    
    [ Upstream commit 9c85a9bae267f6b5e5e374d0d023bbbe9db096d3 ]
    
    Avoid calling mmap with requested addresses that are less than the
    system's mmap_min_addr.  When run as root, mmap returns EACCES when
    trying to map addresses < mmap_min_addr.  This is not one of the error
    codes for the condition to retry the mmap in the test.
    
    Rather than arbitrarily retrying on EACCES, don't attempt an mmap until
    addr > vm.mmap_min_addr.
    
    Add a munmap call after an alignment check as the mappings are retained
    after the retry and can reach the vm.max_map_count sysctl.
    
    Link: https://lkml.kernel.org/r/20220420215721.4868-1-sidhartha.kumar@oracle.com
    Signed-off-by: Sidhartha Kumar <sidhartha.kumar@oracle.com>
    Reviewed-by: Shuah Khan <skhan@linuxfoundation.org>
    Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
    Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 1ec94e879f185dc3611af8861899cae03af90127
Author: Gongjun Song <gongjun.song@intel.com>
Date:   Thu Apr 21 11:35:46 2022 -0500

    ALSA: hda: intel-dsp-config: Add RaptorLake PCI IDs
    
    [ Upstream commit b07908ab26ceab51165c13714277c19252e62594 ]
    
    Add RaptorLake-P PCI IDs
    
    Reviewed-by: Kai Vehmanen <kai.vehmanen@linux.intel.com>
    Signed-off-by: Gongjun Song <gongjun.song@intel.com>
    Signed-off-by: Pierre-Louis Bossart <pierre-louis.bossart@linux.intel.com>
    Link: https://lore.kernel.org/r/20220421163546.319604-1-pierre-louis.bossart@linux.intel.com
    Signed-off-by: Takashi Iwai <tiwai@suse.de>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 568e5b2a529baf8bbff060378b8612824e3349e0
Author: Alexey Kardashevskiy <aik@ozlabs.ru>
Date:   Thu Apr 21 12:57:56 2022 +1000

    powerpc/perf: Fix 32bit compile
    
    [ Upstream commit bb82c574691daf8f7fa9a160264d15c5804cb769 ]
    
    The "read_bhrb" global symbol is only called under CONFIG_PPC64 of
    arch/powerpc/perf/core-book3s.c but it is compiled for both 32 and 64 bit
    anyway (and LLVM fails to link this on 32bit).
    
    This fixes it by moving bhrb.o to obj64 targets.
    
    Signed-off-by: Alexey Kardashevskiy <aik@ozlabs.ru>
    Signed-off-by: Michael Ellerman <mpe@ellerman.id.au>
    Link: https://lore.kernel.org/r/20220421025756.571995-1-aik@ozlabs.ru
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit fe0a666fc5ec1a1c20290cfe8a845df467236d7b
Author: Duoming Zhou <duoming@zju.edu.cn>
Date:   Sun Apr 17 20:55:19 2022 +0800

    drivers: net: hippi: Fix deadlock in rr_close()
    
    [ Upstream commit bc6de2878429e85c1f1afaa566f7b5abb2243eef ]
    
    There is a deadlock in rr_close(), which is shown below:
    
       (Thread 1)                |      (Thread 2)
                                 | rr_open()
    rr_close()                   |  add_timer()
     spin_lock_irqsave() //(1)   |  (wait a time)
     ...                         | rr_timer()
     del_timer_sync()            |  spin_lock_irqsave() //(2)
     (wait timer to stop)        |  ...
    
    We hold rrpriv->lock in position (1) of thread 1 and
    use del_timer_sync() to wait timer to stop, but timer handler
    also need rrpriv->lock in position (2) of thread 2.
    As a result, rr_close() will block forever.
    
    This patch extracts del_timer_sync() from the protection of
    spin_lock_irqsave(), which could let timer handler to obtain
    the needed lock.
    
    Signed-off-by: Duoming Zhou <duoming@zju.edu.cn>
    Link: https://lore.kernel.org/r/20220417125519.82618-1-duoming@zju.edu.cn
    Signed-off-by: Paolo Abeni <pabeni@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 05847bfad5c15bcdd5dbbc12473eff251fa38ca4
Author: Ronnie Sahlberg <lsahlber@redhat.com>
Date:   Thu Apr 21 11:15:36 2022 +1000

    cifs: destage any unwritten data to the server before calling copychunk_write
    
    [ Upstream commit f5d0f921ea362636e4a2efb7c38d1ead373a8700 ]
    
    because the copychunk_write might cover a region of the file that has not yet
    been sent to the server and thus fail.
    
    A simple way to reproduce this is:
    truncate -s 0 /mnt/testfile; strace -f -o x -ttT xfs_io -i -f -c 'pwrite 0k 128k' -c 'fcollapse 16k 24k' /mnt/testfile
    
    the issue is that the 'pwrite 0k 128k' becomes rearranged on the wire with
    the 'fcollapse 16k 24k' due to write-back caching.
    
    fcollapse is implemented in cifs.ko as a SMB2 IOCTL(COPYCHUNK_WRITE) call
    and it will fail serverside since the file is still 0b in size serverside
    until the writes have been destaged.
    To avoid this we must ensure that we destage any unwritten data to the
    server before calling COPYCHUNK_WRITE.
    
    Bugzilla: https://bugzilla.redhat.com/show_bug.cgi?id=1997373
    Reported-by: Xiaoli Feng <xifeng@redhat.com>
    Signed-off-by: Ronnie Sahlberg <lsahlber@redhat.com>
    Signed-off-by: Steve French <stfrench@microsoft.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 96e4f140d0833c740ac2119ccbae9ca32a2d5f1b
Author: Mikulas Patocka <mpatocka@redhat.com>
Date:   Tue Apr 19 09:56:23 2022 -0400

    x86: __memcpy_flushcache: fix wrong alignment if size > 2^32
    
    [ Upstream commit a6823e4e360fe975bd3da4ab156df7c74c8b07f3 ]
    
    The first "if" condition in __memcpy_flushcache is supposed to align the
    "dest" variable to 8 bytes and copy data up to this alignment.  However,
    this condition may misbehave if "size" is greater than 4GiB.
    
    The statement min_t(unsigned, size, ALIGN(dest, 8) - dest); casts both
    arguments to unsigned int and selects the smaller one.  However, the
    cast truncates high bits in "size" and it results in misbehavior.
    
    For example:
    
            suppose that size == 0x100000001, dest == 0x200000002
            min_t(unsigned, size, ALIGN(dest, 8) - dest) == min_t(0x1, 0xe) == 0x1;
            ...
            dest += 0x1;
    
    so we copy just one byte "and" dest remains unaligned.
    
    This patch fixes the bug by replacing unsigned with size_t.
    
    Signed-off-by: Mikulas Patocka <mpatocka@redhat.com>
    Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 4d9d808b4066b0c571f9076b92b0d1bb1eff85c7
Author: suresh kumar <suresh2514@gmail.com>
Date:   Sat Apr 16 16:44:10 2022 +0530

    bonding: do not discard lowest hash bit for non layer3+4 hashing
    
    [ Upstream commit 49aefd131739df552f83c566d0665744c30b1d70 ]
    
    Commit b5f862180d70 was introduced to discard lowest hash bit for layer3+4 hashing
    but it also removes last bit from non layer3+4 hashing
    
    Below script shows layer2+3 hashing will result in same slave to be used with above commit.
    $ cat hash.py
    #/usr/bin/python3.6
    
    h_dests=[0xa0, 0xa1]
    h_source=0xe3
    hproto=0x8
    saddr=0x1e7aa8c0
    daddr=0x17aa8c0
    
    for h_dest in h_dests:
        hash = (h_dest ^ h_source ^ hproto ^ saddr ^ daddr)
        hash ^= hash >> 16
        hash ^= hash >> 8
        print(hash)
    
    print("with last bit removed")
    for h_dest in h_dests:
        hash = (h_dest ^ h_source ^ hproto ^ saddr ^ daddr)
        hash ^= hash >> 16
        hash ^= hash >> 8
        hash = hash >> 1
        print(hash)
    
    Output:
    $ python3.6 hash.py
    522133332
    522133333   <-------------- will result in both slaves being used
    
    with last bit removed
    261066666
    261066666   <-------------- only single slave used
    
    Signed-off-by: suresh kumar <suresh2514@gmail.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 8c697fbd2a249d94973664937464438a177bf9bf
Author: Hongyu Jin <hongyu.jin@unisoc.com>
Date:   Fri Apr 1 19:55:27 2022 +0800

    erofs: fix use-after-free of on-stack io[]
    
    [ Upstream commit 60b30050116c0351b90154044345c1b53ae1f323 ]
    
    The root cause is the race as follows:
    Thread #1                              Thread #2(irq ctx)
    
    z_erofs_runqueue()
      struct z_erofs_decompressqueue io_A[];
      submit bio A
      z_erofs_decompress_kickoff(,,1)
                                           z_erofs_decompressqueue_endio(bio A)
                                           z_erofs_decompress_kickoff(,,-1)
                                           spin_lock_irqsave()
                                           atomic_add_return()
      io_wait_event()       -> pending_bios is already 0
      [end of function]
                                           wake_up_locked(io_A[]) // crash
    
    Referenced backtrace in kernel 5.4:
    
    [   10.129422] Unable to handle kernel paging request at virtual address eb0454a4
    [   10.364157] CPU: 0 PID: 709 Comm: getprop Tainted: G        WC O      5.4.147-ab09225 #1
    [   11.556325] [<c01b33b8>] (__wake_up_common) from [<c01b3300>] (__wake_up_locked+0x40/0x48)
    [   11.565487] [<c01b3300>] (__wake_up_locked) from [<c044c8d0>] (z_erofs_vle_unzip_kickoff+0x6c/0xc0)
    [   11.575438] [<c044c8d0>] (z_erofs_vle_unzip_kickoff) from [<c044c854>] (z_erofs_vle_read_endio+0x16c/0x17c)
    [   11.586082] [<c044c854>] (z_erofs_vle_read_endio) from [<c06a80e8>] (clone_endio+0xb4/0x1d0)
    [   11.595428] [<c06a80e8>] (clone_endio) from [<c04a1280>] (blk_update_request+0x150/0x4dc)
    [   11.604516] [<c04a1280>] (blk_update_request) from [<c06dea28>] (mmc_blk_cqe_complete_rq+0x144/0x15c)
    [   11.614640] [<c06dea28>] (mmc_blk_cqe_complete_rq) from [<c04a5d90>] (blk_done_softirq+0xb0/0xcc)
    [   11.624419] [<c04a5d90>] (blk_done_softirq) from [<c010242c>] (__do_softirq+0x184/0x56c)
    [   11.633419] [<c010242c>] (__do_softirq) from [<c01051e8>] (irq_exit+0xd4/0x138)
    [   11.641640] [<c01051e8>] (irq_exit) from [<c010c314>] (__handle_domain_irq+0x94/0xd0)
    [   11.650381] [<c010c314>] (__handle_domain_irq) from [<c04fde70>] (gic_handle_irq+0x50/0xd4)
    [   11.659641] [<c04fde70>] (gic_handle_irq) from [<c0101b70>] (__irq_svc+0x70/0xb0)
    
    Signed-off-by: Hongyu Jin <hongyu.jin@unisoc.com>
    Reviewed-by: Gao Xiang <hsiangkao@linux.alibaba.com>
    Reviewed-by: Chao Yu <chao@kernel.org>
    Link: https://lore.kernel.org/r/20220401115527.4935-1-hongyu.jin.cn@gmail.com
    Signed-off-by: Gao Xiang <hsiangkao@linux.alibaba.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 65064a66f3722fd2739310ba54ac5a36d0cbd323
Author: Namjae Jeon <linkinjeon@kernel.org>
Date:   Wed Apr 13 10:01:36 2022 +0900

    ksmbd: set fixed sector size to FS_SECTOR_SIZE_INFORMATION
    
    [ Upstream commit 02655a70b7cc0f534531ee65fa72692f4d31a944 ]
    
    Currently ksmbd is using ->f_bsize from vfs_statfs() as sector size.
    If fat/exfat is a local share, ->f_bsize is a cluster size that is too
    large to be used as a sector size. Sector sizes larger than 4K cause
    problem occurs when mounting an iso file through windows client.
    
    The error message can be obtained using Mount-DiskImage command,
     the error is:
    "Mount-DiskImage : The sector size of the physical disk on which the
    virtual disk resides is not supported."
    
    This patch reports fixed 4KB sector size if ->s_blocksize is bigger
    than 4KB.
    
    Signed-off-by: Namjae Jeon <linkinjeon@kernel.org>
    Signed-off-by: Steve French <stfrench@microsoft.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit aaf1d5ebb358f546414965b39da90107a7ca7ce5
Author: Namjae Jeon <linkinjeon@kernel.org>
Date:   Tue Apr 5 12:04:43 2022 +0900

    ksmbd: increment reference count of parent fp
    
    [ Upstream commit 8510a043d334ecdf83d4604782f288db6bf21d60 ]
    
    Add missing increment reference count of parent fp in
    ksmbd_lookup_fd_inode().
    
    Signed-off-by: Namjae Jeon <linkinjeon@kernel.org>
    Reviewed-by: Hyunchul Lee <hyc.lee@gmail.com>
    Signed-off-by: Steve French <stfrench@microsoft.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit db75a47eee09d2b89743744981856eb00a382986
Author: Duoming Zhou <duoming@zju.edu.cn>
Date:   Thu Apr 7 23:44:30 2022 +0800

    arch: xtensa: platforms: Fix deadlock in rs_close()
    
    [ Upstream commit eb5adc70754d26a260f8b42d39db42da0d0af500 ]
    
    There is a deadlock in rs_close(), which is shown
    below:
    
       (Thread 1)              |      (Thread 2)
                               | rs_open()
    rs_close()                 |  mod_timer()
     spin_lock_bh() //(1)      |  (wait a time)
     ...                       | rs_poll()
     del_timer_sync()          |  spin_lock() //(2)
     (wait timer to stop)      |  ...
    
    We hold timer_lock in position (1) of thread 1 and
    use del_timer_sync() to wait timer to stop, but timer handler
    also need timer_lock in position (2) of thread 2.
    As a result, rs_close() will block forever.
    
    This patch deletes the redundant timer_lock in order to
    prevent the deadlock. Because there is no race condition
    between rs_close, rs_open and rs_poll.
    
    Signed-off-by: Duoming Zhou <duoming@zju.edu.cn>
    Message-Id: <20220407154430.22387-1-duoming@zju.edu.cn>
    Signed-off-by: Max Filippov <jcmvbkbc@gmail.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit afe490e48d47df1b3f64012835c1bc2f075a8c8b
Author: Ye Bin <yebin10@huawei.com>
Date:   Tue Mar 22 09:24:19 2022 +0800

    ext4: fix bug_on in start_this_handle during umount filesystem
    
    [ Upstream commit b98535d091795a79336f520b0708457aacf55c67 ]
    
    We got issue as follows:
    ------------[ cut here ]------------
    kernel BUG at fs/jbd2/transaction.c:389!
    invalid opcode: 0000 [#1] PREEMPT SMP KASAN PTI
    CPU: 9 PID: 131 Comm: kworker/9:1 Not tainted 5.17.0-862.14.0.6.x86_64-00001-g23f87daf7d74-dirty #197
    Workqueue: events flush_stashed_error_work
    RIP: 0010:start_this_handle+0x41c/0x1160
    RSP: 0018:ffff888106b47c20 EFLAGS: 00010202
    RAX: ffffed10251b8400 RBX: ffff888128dc204c RCX: ffffffffb52972ac
    RDX: 0000000000000200 RSI: 0000000000000004 RDI: ffff888128dc2050
    RBP: 0000000000000039 R08: 0000000000000001 R09: ffffed10251b840a
    R10: ffff888128dc204f R11: ffffed10251b8409 R12: ffff888116d78000
    R13: 0000000000000000 R14: dffffc0000000000 R15: ffff888128dc2000
    FS:  0000000000000000(0000) GS:ffff88839d680000(0000) knlGS:0000000000000000
    CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
    CR2: 0000000001620068 CR3: 0000000376c0e000 CR4: 00000000000006e0
    DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
    DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
    Call Trace:
     <TASK>
     jbd2__journal_start+0x38a/0x790
     jbd2_journal_start+0x19/0x20
     flush_stashed_error_work+0x110/0x2b3
     process_one_work+0x688/0x1080
     worker_thread+0x8b/0xc50
     kthread+0x26f/0x310
     ret_from_fork+0x22/0x30
     </TASK>
    Modules linked in:
    ---[ end trace 0000000000000000 ]---
    
    Above issue may happen as follows:
          umount            read procfs            error_work
    ext4_put_super
      flush_work(&sbi->s_error_work);
    
                          ext4_mb_seq_groups_show
                            ext4_mb_load_buddy_gfp
                              ext4_mb_init_group
                                ext4_mb_init_cache
                                  ext4_read_block_bitmap_nowait
                                    ext4_validate_block_bitmap
                                      ext4_error
                                        ext4_handle_error
                                          schedule_work(&EXT4_SB(sb)->s_error_work);
    
      ext4_unregister_sysfs(sb);
      jbd2_journal_destroy(sbi->s_journal);
        journal_kill_thread
          journal->j_flags |= JBD2_UNMOUNT;
    
                                              flush_stashed_error_work
                                                jbd2_journal_start
                                                  start_this_handle
                                                    BUG_ON(journal->j_flags & JBD2_UNMOUNT);
    
    To solve this issue, we call 'ext4_unregister_sysfs() before flushing
    s_error_work in ext4_put_super().
    
    Signed-off-by: Ye Bin <yebin10@huawei.com>
    Reviewed-by: Jan Kara <jack@suse.cz>
    Reviewed-by: Ritesh Harjani <riteshh@linux.ibm.com>
    Link: https://lore.kernel.org/r/20220322012419.725457-1-yebin10@huawei.com
    Signed-off-by: Theodore Ts'o <tytso@mit.edu>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 23a7f5c77635a00e9ea039331cf7e7460425506d
Author: Zheyu Ma <zheyuma97@gmail.com>
Date:   Fri Apr 8 19:30:49 2022 -0700

    Input: cypress-sf - register a callback to disable the regulators
    
    [ Upstream commit fd0a4b39870d49ff15f6966470185409e261f20f ]
    
    When the driver fails to probe, we will get the following splat:
    
    [   19.311970] ------------[ cut here ]------------
    [   19.312566] WARNING: CPU: 3 PID: 375 at drivers/regulator/core.c:2257 _regulator_put+0x3ec/0x4e0
    [   19.317591] RIP: 0010:_regulator_put+0x3ec/0x4e0
    [   19.328831] Call Trace:
    [   19.329112]  <TASK>
    [   19.329369]  regulator_bulk_free+0x82/0xe0
    [   19.329860]  devres_release_group+0x319/0x3d0
    [   19.330357]  i2c_device_probe+0x766/0x940
    
    Fix this by adding a callback that will deal with the disabling when the
    driver fails to probe.
    
    Signed-off-by: Zheyu Ma <zheyuma97@gmail.com>
    Link: https://lore.kernel.org/r/20220409022629.3493557-1-zheyuma97@gmail.com
    Signed-off-by: Dmitry Torokhov <dmitry.torokhov@gmail.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit f76187f023430d710109ac53975103b0a34adc13
Author: Zheyu Ma <zheyuma97@gmail.com>
Date:   Tue Apr 5 20:10:38 2022 +0800

    ASoC: wm8731: Disable the regulator when probing fails
    
    [ Upstream commit 92ccbf17eeacf510cf1eed9c252d9332ca24f02d ]
    
    When the driver fails during probing, the driver should disable the
    regulator, not just handle it in wm8731_hw_init().
    
    The following log reveals it:
    
    [   17.812483] WARNING: CPU: 1 PID: 364 at drivers/regulator/core.c:2257 _regulator_put+0x3ec/0x4e0
    [   17.815958] RIP: 0010:_regulator_put+0x3ec/0x4e0
    [   17.824467] Call Trace:
    [   17.824774]  <TASK>
    [   17.825040]  regulator_bulk_free+0x82/0xe0
    [   17.825514]  devres_release_group+0x319/0x3d0
    [   17.825882]  i2c_device_probe+0x766/0x940
    [   17.829198]  i2c_register_driver+0xb5/0x130
    
    Signed-off-by: Zheyu Ma <zheyuma97@gmail.com>
    Link: https://lore.kernel.org/r/20220405121038.4094051-1-zheyuma97@gmail.com
    Signed-off-by: Mark Brown <broonie@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 753fe5770fffac1471a0234c42d6ba95af744ed2
Author: Chao Song <chao.song@linux.intel.com>
Date:   Wed Apr 6 14:23:41 2022 -0500

    ASoC: Intel: soc-acpi: correct device endpoints for max98373
    
    [ Upstream commit 97326be14df7bacc6ba5c62c0556298c27ea0432 ]
    
    The left speaker of max98373 uses spk_r_endpoint, and right
    speaker uses spk_l_endpoint, this is obviously wrong.
    
    This patch corrects the endpoints for max98373 codec.
    
    Signed-off-by: Chao Song <chao.song@linux.intel.com>
    Signed-off-by: Pierre-Louis Bossart <pierre-louis.bossart@linux.intel.com>
    Link: https://lore.kernel.org/r/20220406192341.271465-1-pierre-louis.bossart@linux.intel.com
    Signed-off-by: Mark Brown <broonie@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit eeda2198a0ba734f4a3cfb8e36c0ee6ba6bf7946
Author: Pierre-Louis Bossart <pierre-louis.bossart@linux.intel.com>
Date:   Wed Apr 6 14:20:05 2022 -0500

    ASoC: rt711/5682: check if bus is active before deferred jack detection
    
    [ Upstream commit 770f3d992a3f7330f801dfeee98429b2885c9fdb ]
    
    This patch takes a defensive programming and paranoid approach in case
    the parent device (SoundWire) is pm_runtime resumed but the rt711
    device is not. In that case, during the attachment and initialization,
    a jack detection workqueue can be scheduled. Since the pm_runtime
    suspend routines will not be invoked, the sequence to cancel all
    deferred work is not executed, and the jack detection could happen
    after the bus stops operating, leading to a timeout.
    
    This patch applies the same solution to rt5682, based on the
    similarities between codec drivers. The race condition with rt5682 was
    not detected experimentally though.
    
    BugLink: https://github.com/thesofproject/linux/issues/3459
    Signed-off-by: Pierre-Louis Bossart <pierre-louis.bossart@linux.intel.com>
    Reviewed-by: Rander Wang <rander.wang@intel.com>
    Reviewed-by: Bard Liao <yung-chuan.liao@linux.intel.com>
    Link: https://lore.kernel.org/r/20220406192005.262996-1-pierre-louis.bossart@linux.intel.com
    Signed-off-by: Mark Brown <broonie@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 7587b742eb5fc14e322469989b11985d3227d3df
Author: Hui Wang <hui.wang@canonical.com>
Date:   Thu Mar 24 16:18:39 2022 +0800

    ASoC: cs35l41: Fix a shift-out-of-bounds warning found by UBSAN
    
    [ Upstream commit 0b3d5d2e358ca6772fc3662fca27acb12a682fbf ]
    
    We enabled UBSAN in the ubuntu kernel, and the cs35l41 driver triggers
    a warning calltrace like below:
    
    cs35l41-hda i2c-CSC3551:00-cs35l41-hda.0: bitoffset= 8, word_offset=23, bit_sum mod 32=0, otp_map[i].size = 24
    cs35l41-hda i2c-CSC3551:00-cs35l41-hda.0: bitoffset= 0, word_offset=24, bit_sum mod 32=24, otp_map[i].size = 0
    ================================================================================
    UBSAN: shift-out-of-bounds in linux-kernel-src/sound/soc/codecs/cs35l41-lib.c:836:8
    shift exponent 64 is too large for 64-bit type 'long unsigned int'
    CPU: 10 PID: 595 Comm: systemd-udevd Not tainted 5.15.0-23-generic #23
    Hardware name: LENOVO \x02MFG_IN_GO/\x02MFG_IN_GO, BIOS N3GET19W (1.00 ) 03/11/2022
    Call Trace:
     <TASK>
     show_stack+0x52/0x58
     dump_stack_lvl+0x4a/0x5f
     dump_stack+0x10/0x12
     ubsan_epilogue+0x9/0x45
     __ubsan_handle_shift_out_of_bounds.cold+0x61/0xef
     ? regmap_unlock_mutex+0xe/0x10
     cs35l41_otp_unpack.cold+0x1c6/0x2b2 [snd_soc_cs35l41_lib]
     cs35l41_hda_probe+0x24f/0x33a [snd_hda_scodec_cs35l41]
     cs35l41_hda_i2c_probe+0x65/0x90 [snd_hda_scodec_cs35l41_i2c]
    
    When both bitoffset and otp_map[i].size are 0, the line 836 will
    result in GENMASK(-1, 0), this triggers the shift-out-of-bounds
    calltrace.
    
    Here add a checking, if both bitoffset and otp_map[i].size are 0,
    do not run GENMASK() and directly set otp_val to 0, this will not
    bring any function change on the driver but could avoid the calltrace.
    
    Signed-off-by: Hui Wang <hui.wang@canonical.com>
    Link: https://lore.kernel.org/r/20220324081839.62009-2-hui.wang@canonical.com
    Signed-off-by: Mark Brown <broonie@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 6aebb47fc46fa3883d4c37103713668ce7cfa120
Author: Christophe JAILLET <christophe.jaillet@wanadoo.fr>
Date:   Thu Mar 31 22:19:44 2022 +0200

    ASoC: soc-pcm: use GFP_KERNEL when the code is sleepable
    
    [ Upstream commit fb6d679fee95d272c0a94912c4e534146823ee89 ]
    
    At the kzalloc() call in dpcm_be_connect(), there is no spin lock involved.
    It's merely protected by card->pcm_mutex, instead.  The spinlock is applied
    at the later call with snd_soc_pcm_stream_lock_irq() only for the list
    manipulations.  (See it's *_irq(), not *_irqsave(); that means the context
    being sleepable at that point.)  So, we can use GFP_KERNEL safely there.
    
    This patch revert commit d8a9c6e1f676 ("ASoC: soc-pcm: use GFP_ATOMIC for
    dpcm structure") which is no longer needed since commit b7898396f4bb
    ("ASoC: soc-pcm: Fix and cleanup DPCM locking").
    
    Signed-off-by: Christophe JAILLET <christophe.jaillet@wanadoo.fr>
    Link: https://lore.kernel.org/r/e740f1930843060e025e3c0f17ec1393cfdafb26.1648757961.git.christophe.jaillet@wanadoo.fr
    Signed-off-by: Mark Brown <broonie@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 77089e6ff273f43c42e99a690ae45ee39a6a62de
Author: Joseph Ravichandran <jravi@mit.edu>
Date:   Thu Apr 28 12:57:52 2022 -0400

    io_uring: fix uninitialized field in rw io_kiocb
    
    [ Upstream commit 32452a3eb8b64e01e2be717f518c0be046975b9d ]
    
    io_rw_init_file does not initialize kiocb->private, so when iocb_bio_iopoll
    reads kiocb->private it can contain uninitialized data.
    
    Fixes: 3e08773c3841 ("block: switch polling to be bio based")
    Signed-off-by: Joseph Ravichandran <jravi@mit.edu>
    Signed-off-by: Jens Axboe <axboe@kernel.dk>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 254ca186d553beb9bf0762cbb5cc604c24d44760
Author: Pengcheng Yang <yangpc@wangsu.com>
Date:   Tue Apr 26 18:03:39 2022 +0800

    tcp: fix F-RTO may not work correctly when receiving DSACK
    
    [ Upstream commit d9157f6806d1499e173770df1f1b234763de5c79 ]
    
    Currently DSACK is regarded as a dupack, which may cause
    F-RTO to incorrectly enter "loss was real" when receiving
    DSACK.
    
    Packetdrill to demonstrate:
    
    // Enable F-RTO and TLP
        0 `sysctl -q net.ipv4.tcp_frto=2`
        0 `sysctl -q net.ipv4.tcp_early_retrans=3`
        0 `sysctl -q net.ipv4.tcp_congestion_control=cubic`
    
    // Establish a connection
       +0 socket(..., SOCK_STREAM, IPPROTO_TCP) = 3
       +0 setsockopt(3, SOL_SOCKET, SO_REUSEADDR, [1], 4) = 0
       +0 bind(3, ..., ...) = 0
       +0 listen(3, 1) = 0
    
    // RTT 10ms, RTO 210ms
      +.1 < S 0:0(0) win 32792 <mss 1000,sackOK,nop,nop,nop,wscale 7>
       +0 > S. 0:0(0) ack 1 <...>
     +.01 < . 1:1(0) ack 1 win 257
       +0 accept(3, ..., ...) = 4
    
    // Send 2 data segments
       +0 write(4, ..., 2000) = 2000
       +0 > P. 1:2001(2000) ack 1
    
    // TLP
    +.022 > P. 1001:2001(1000) ack 1
    
    // Continue to send 8 data segments
       +0 write(4, ..., 10000) = 10000
       +0 > P. 2001:10001(8000) ack 1
    
    // RTO
    +.188 > . 1:1001(1000) ack 1
    
    // The original data is acked and new data is sent(F-RTO step 2.b)
       +0 < . 1:1(0) ack 2001 win 257
       +0 > P. 10001:12001(2000) ack 1
    
    // D-SACK caused by TLP is regarded as a dupack, this results in
    // the incorrect judgment of "loss was real"(F-RTO step 3.a)
    +.022 < . 1:1(0) ack 2001 win 257 <sack 1001:2001,nop,nop>
    
    // Never-retransmitted data(3001:4001) are acked and
    // expect to switch to open state(F-RTO step 3.b)
       +0 < . 1:1(0) ack 4001 win 257
    +0 %{ assert tcpi_ca_state == 0, tcpi_ca_state }%
    
    Fixes: e33099f96d99 ("tcp: implement RFC5682 F-RTO")
    Signed-off-by: Pengcheng Yang <yangpc@wangsu.com>
    Acked-by: Neal Cardwell <ncardwell@google.com>
    Tested-by: Neal Cardwell <ncardwell@google.com>
    Reviewed-by: Eric Dumazet <edumazet@google.com>
    Link: https://lore.kernel.org/r/1650967419-2150-1-git-send-email-yangpc@wangsu.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 681b7db08e4eba8ef19239b5266d5ebb13e1b96e
Author: Dany Madden <drt@linux.ibm.com>
Date:   Wed Apr 27 18:51:46 2022 -0500

    Revert "ibmvnic: Add ethtool private flag for driver-defined queue limits"
    
    [ Upstream commit aeaf59b78712c7a1827c76f086acff4f586e072f ]
    
    This reverts commit 723ad916134784b317b72f3f6cf0f7ba774e5dae
    
    When client requests channel or ring size larger than what the server
    can support the server will cap the request to the supported max. So,
    the client would not be able to successfully request resources that
    exceed the server limit.
    
    Fixes: 723ad9161347 ("ibmvnic: Add ethtool private flag for driver-defined queue limits")
    Signed-off-by: Dany Madden <drt@linux.ibm.com>
    Link: https://lore.kernel.org/r/20220427235146.23189-1-drt@linux.ibm.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit eedd121811345478805b7c8415cd708997ffeef3
Author: Vladimir Oltean <vladimir.oltean@nxp.com>
Date:   Wed Apr 27 23:30:17 2022 +0300

    net: enetc: allow tc-etf offload even with NETIF_F_CSUM_MASK
    
    [ Upstream commit 66a2f5ef68faaf950746747d790a0c95f7ec96d2 ]
    
    The Time-Specified Departure feature is indeed mutually exclusive with
    TX IP checksumming in ENETC, but TX checksumming in itself is broken and
    was removed from this driver in commit 82728b91f124 ("enetc: Remove Tx
    checksumming offload code").
    
    The blamed commit declared NETIF_F_HW_CSUM in dev->features to comply
    with software TSO's expectations, and still did the checksumming in
    software by calling skb_checksum_help(). So there isn't any restriction
    for the Time-Specified Departure feature.
    
    However, enetc_setup_tc_txtime() doesn't understand that, and blindly
    looks for NETIF_F_CSUM_MASK.
    
    Instead of checking for things which can literally never happen in the
    current code base, just remove the check and let the driver offload
    tc-etf qdiscs.
    
    Fixes: acede3c5dad5 ("net: enetc: declare NETIF_F_HW_CSUM and do it in software")
    Signed-off-by: Vladimir Oltean <vladimir.oltean@nxp.com>
    Link: https://lore.kernel.org/r/20220427203017.1291634-1-vladimir.oltean@nxp.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 96d073c3eb6941d3216df27e1c4487d44a093117
Author: Leon Romanovsky <leon@kernel.org>
Date:   Wed Apr 27 10:31:52 2022 -0700

    ixgbe: ensure IPsec VF<->PF compatibility
    
    [ Upstream commit f049efc7f7cd2f3c419f55040928eaefb13b3636 ]
    
    The VF driver can forward any IPsec flags and such makes the function
    is not extendable and prone to backward/forward incompatibility.
    
    If new software runs on VF, it won't know that PF configured something
    completely different as it "knows" only XFRM_OFFLOAD_INBOUND flag.
    
    Fixes: eda0333ac293 ("ixgbe: add VF IPsec management")
    Reviewed-by: Raed Salem <raeds@nvidia.com>
    Signed-off-by: Leon Romanovsky <leonro@nvidia.com>
    Reviewed-by: Shannon Nelson <snelson@pensando.io>
    Tested-by: Konrad Jankowski <konrad0.jankowski@intel.com>
    Signed-off-by: Tony Nguyen <anthony.l.nguyen@intel.com>
    Link: https://lore.kernel.org/r/20220427173152.443102-1-anthony.l.nguyen@intel.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 3561e9a043413857b4e7d886c6b7461cf18f4cb9
Author: Timothy Hayes <timothy.hayes@arm.com>
Date:   Thu Apr 21 17:52:03 2022 +0100

    perf arm-spe: Fix addresses of synthesized SPE events
    
    [ Upstream commit 4e13f6706d5aee1a6b835a44f6cf4971a921dcb8 ]
    
    This patch corrects a bug whereby synthesized events from SPE
    samples are missing virtual addresses.
    
    Fixes: 54f7815efef7fad9 ("perf arm-spe: Fill address info for samples")
    Reviewed-by: Leo Yan <leo.yan@linaro.org>
    Signed-off-by: Timothy Hayes <timothy.hayes@arm.com>
    Cc: Alexander Shishkin <alexander.shishkin@linux.intel.com>
    Cc: bpf@vger.kernel.org
    Cc: Jiri Olsa <jolsa@kernel.org>
    Cc: John Fastabend <john.fastabend@gmail.com>
    Cc: John Garry <john.garry@huawei.com>
    Cc: KP Singh <kpsingh@kernel.org>
    Cc: Leo Yan <leo.yan@linaro.org>
    Cc: linux-arm-kernel@lists.infradead.org
    Cc: Mark Rutland <mark.rutland@arm.com>
    Cc: Martin KaFai Lau <kafai@fb.com>
    Cc: Mathieu Poirier <mathieu.poirier@linaro.org>
    Cc: Namhyung Kim <namhyung@kernel.org>
    Cc: netdev@vger.kernel.org
    Cc: Song Liu <songliubraving@fb.com>
    Cc: Will Deacon <will@kernel.org>
    Cc: Yonghong Song <yhs@fb.com>
    Link: https://lore.kernel.org/r/20220421165205.117662-2-timothy.hayes@arm.com
    Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 81f04c075d76823cf994d925cd68df9b6b71e0a2
Author: Andreas Gruenbacher <agruenba@redhat.com>
Date:   Thu Apr 28 14:51:33 2022 +0200

    gfs2: No short reads or writes upon glock contention
    
    [ Upstream commit 296abc0d91d8b65d42224dd33452ace14491ad08 ]
    
    Commit 00bfe02f4796 ("gfs2: Fix mmap + page fault deadlocks for buffered
    I/O") changed gfs2_file_read_iter() and gfs2_file_buffered_write() to
    allow dropping the inode glock while faulting in user buffers.  When the
    lock was dropped, a short result was returned to indicate that the
    operation was interrupted.
    
    As pointed out by Linus (see the link below), this behavior is broken
    and the operations should always re-acquire the inode glock and resume
    the operation instead.
    
    Link: https://lore.kernel.org/lkml/CAHk-=whaz-g_nOOoo8RRiWNjnv2R+h6_xk2F1J4TuSRxk1MtLw@mail.gmail.com/
    Fixes: 00bfe02f4796 ("gfs2: Fix mmap + page fault deadlocks for buffered I/O")
    Signed-off-by: Andreas Gruenbacher <agruenba@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 29a7b55a2111eed633d8fc16905a77c51a1f2f1d
Author: Andreas Gruenbacher <agruenba@redhat.com>
Date:   Thu Mar 24 23:13:26 2022 +0100

    gfs2: Make sure not to return short direct writes
    
    [ Upstream commit 3bde4c48586074202044456285a97ccdf9048988 ]
    
    When direct writes fail with -ENOTBLK because we're writing into a
    hole (gfs2_iomap_begin()) or because of a page invalidation failure
    (iomap_dio_rw()), we're falling back to buffered writes.  In that case,
    when we lose the inode glock in gfs2_file_buffered_write(), we want to
    re-acquire it instead of returning a short write.
    
    Signed-off-by: Andreas Gruenbacher <agruenba@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a55715f6ce7b693b5c67e3839ebcbdea7ba71138
Author: Andreas Gruenbacher <agruenba@redhat.com>
Date:   Thu Mar 17 14:20:38 2022 +0100

    gfs2: Minor retry logic cleanup
    
    [ Upstream commit 124c458a401a2497f796e4f2d6cafac6edbea8e9 ]
    
    Clean up the retry logic in the read and write functions somewhat.
    
    Signed-off-by: Andreas Gruenbacher <agruenba@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 66d96598f70b627bfd5741823d4fd9cb7d6d4edd
Author: Yang Yingliang <yangyingliang@huawei.com>
Date:   Tue Apr 26 20:52:31 2022 +0800

    net: fec: add missing of_node_put() in fec_enet_init_stop_mode()
    
    [ Upstream commit d2b52ec056d5bddb055c8f21d7489a23548d0838 ]
    
    Put device node in error path in fec_enet_init_stop_mode().
    
    Fixes: 8a448bf832af ("net: ethernet: fec: move GPR register offset and bit into DT")
    Signed-off-by: Yang Yingliang <yangyingliang@huawei.com>
    Link: https://lore.kernel.org/r/20220426125231.375688-1-yangyingliang@huawei.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit b9ba4f5b31fb5614784589e72e1e6ab4825219a5
Author: Manish Chopra <manishc@marvell.com>
Date:   Tue Apr 26 08:39:13 2022 -0700

    bnx2x: fix napi API usage sequence
    
    [ Upstream commit af68656d66eda219b7f55ce8313a1da0312c79e1 ]
    
    While handling PCI errors (AER flow) driver tries to
    disable NAPI [napi_disable()] after NAPI is deleted
    [__netif_napi_del()] which causes unexpected system
    hang/crash.
    
    System message log shows the following:
    =======================================
    [ 3222.537510] EEH: Detected PCI bus error on PHB#384-PE#800000 [ 3222.537511] EEH: This PCI device has failed 2 times in the last hour and will be permanently disabled after 5 failures.
    [ 3222.537512] EEH: Notify device drivers to shutdown [ 3222.537513] EEH: Beginning: 'error_detected(IO frozen)'
    [ 3222.537514] EEH: PE#800000 (PCI 0384:80:00.0): Invoking
    bnx2x->error_detected(IO frozen)
    [ 3222.537516] bnx2x: [bnx2x_io_error_detected:14236(eth14)]IO error detected [ 3222.537650] EEH: PE#800000 (PCI 0384:80:00.0): bnx2x driver reports:
    'need reset'
    [ 3222.537651] EEH: PE#800000 (PCI 0384:80:00.1): Invoking
    bnx2x->error_detected(IO frozen)
    [ 3222.537651] bnx2x: [bnx2x_io_error_detected:14236(eth13)]IO error detected [ 3222.537729] EEH: PE#800000 (PCI 0384:80:00.1): bnx2x driver reports:
    'need reset'
    [ 3222.537729] EEH: Finished:'error_detected(IO frozen)' with aggregate recovery state:'need reset'
    [ 3222.537890] EEH: Collect temporary log [ 3222.583481] EEH: of node=0384:80:00.0 [ 3222.583519] EEH: PCI device/vendor: 168e14e4 [ 3222.583557] EEH: PCI cmd/status register: 00100140 [ 3222.583557] EEH: PCI-E capabilities and status follow:
    [ 3222.583744] EEH: PCI-E 00: 00020010 012c8da2 00095d5e 00455c82 [ 3222.583892] EEH: PCI-E 10: 10820000 00000000 00000000 00000000 [ 3222.583893] EEH: PCI-E 20: 00000000 [ 3222.583893] EEH: PCI-E AER capability register set follows:
    [ 3222.584079] EEH: PCI-E AER 00: 13c10001 00000000 00000000 00062030 [ 3222.584230] EEH: PCI-E AER 10: 00002000 000031c0 000001e0 00000000 [ 3222.584378] EEH: PCI-E AER 20: 00000000 00000000 00000000 00000000 [ 3222.584416] EEH: PCI-E AER 30: 00000000 00000000 [ 3222.584416] EEH: of node=0384:80:00.1 [ 3222.584454] EEH: PCI device/vendor: 168e14e4 [ 3222.584491] EEH: PCI cmd/status register: 00100140 [ 3222.584492] EEH: PCI-E capabilities and status follow:
    [ 3222.584677] EEH: PCI-E 00: 00020010 012c8da2 00095d5e 00455c82 [ 3222.584825] EEH: PCI-E 10: 10820000 00000000 00000000 00000000 [ 3222.584826] EEH: PCI-E 20: 00000000 [ 3222.584826] EEH: PCI-E AER capability register set follows:
    [ 3222.585011] EEH: PCI-E AER 00: 13c10001 00000000 00000000 00062030 [ 3222.585160] EEH: PCI-E AER 10: 00002000 000031c0 000001e0 00000000 [ 3222.585309] EEH: PCI-E AER 20: 00000000 00000000 00000000 00000000 [ 3222.585347] EEH: PCI-E AER 30: 00000000 00000000 [ 3222.586872] RTAS: event: 5, Type: Platform Error (224), Severity: 2 [ 3222.586873] EEH: Reset without hotplug activity [ 3224.762767] EEH: Beginning: 'slot_reset'
    [ 3224.762770] EEH: PE#800000 (PCI 0384:80:00.0): Invoking
    bnx2x->slot_reset()
    [ 3224.762771] bnx2x: [bnx2x_io_slot_reset:14271(eth14)]IO slot reset initializing...
    [ 3224.762887] bnx2x 0384:80:00.0: enabling device (0140 -> 0142) [ 3224.768157] bnx2x: [bnx2x_io_slot_reset:14287(eth14)]IO slot reset
    --> driver unload
    
    Uninterruptible tasks
    =====================
    crash> ps | grep UN
         213      2  11  c000000004c89e00  UN   0.0       0      0  [eehd]
         215      2   0  c000000004c80000  UN   0.0       0      0
    [kworker/0:2]
        2196      1  28  c000000004504f00  UN   0.1   15936  11136  wickedd
        4287      1   9  c00000020d076800  UN   0.0    4032   3008  agetty
        4289      1  20  c00000020d056680  UN   0.0    7232   3840  agetty
       32423      2  26  c00000020038c580  UN   0.0       0      0
    [kworker/26:3]
       32871   4241  27  c0000002609ddd00  UN   0.1   18624  11648  sshd
       32920  10130  16  c00000027284a100  UN   0.1   48512  12608  sendmail
       33092  32987   0  c000000205218b00  UN   0.1   48512  12608  sendmail
       33154   4567  16  c000000260e51780  UN   0.1   48832  12864  pickup
       33209   4241  36  c000000270cb6500  UN   0.1   18624  11712  sshd
       33473  33283   0  c000000205211480  UN   0.1   48512  12672  sendmail
       33531   4241  37  c00000023c902780  UN   0.1   18624  11648  sshd
    
    EEH handler hung while bnx2x sleeping and holding RTNL lock
    ===========================================================
    crash> bt 213
    PID: 213    TASK: c000000004c89e00  CPU: 11  COMMAND: "eehd"
      #0 [c000000004d477e0] __schedule at c000000000c70808
      #1 [c000000004d478b0] schedule at c000000000c70ee0
      #2 [c000000004d478e0] schedule_timeout at c000000000c76dec
      #3 [c000000004d479c0] msleep at c0000000002120cc
      #4 [c000000004d479f0] napi_disable at c000000000a06448
                                            ^^^^^^^^^^^^^^^^
      #5 [c000000004d47a30] bnx2x_netif_stop at c0080000018dba94 [bnx2x]
      #6 [c000000004d47a60] bnx2x_io_slot_reset at c0080000018a551c [bnx2x]
      #7 [c000000004d47b20] eeh_report_reset at c00000000004c9bc
      #8 [c000000004d47b90] eeh_pe_report at c00000000004d1a8
      #9 [c000000004d47c40] eeh_handle_normal_event at c00000000004da64
    
    And the sleeping source code
    ============================
    crash> dis -ls c000000000a06448
    FILE: ../net/core/dev.c
    LINE: 6702
    
       6697  {
       6698          might_sleep();
       6699          set_bit(NAPI_STATE_DISABLE, &n->state);
       6700
       6701          while (test_and_set_bit(NAPI_STATE_SCHED, &n->state))
    * 6702                  msleep(1);
       6703          while (test_and_set_bit(NAPI_STATE_NPSVC, &n->state))
       6704                  msleep(1);
       6705
       6706          hrtimer_cancel(&n->timer);
       6707
       6708          clear_bit(NAPI_STATE_DISABLE, &n->state);
       6709  }
    
    EEH calls into bnx2x twice based on the system log above, first through
    bnx2x_io_error_detected() and then bnx2x_io_slot_reset(), and executes
    the following call chains:
    
    bnx2x_io_error_detected()
      +-> bnx2x_eeh_nic_unload()
           +-> bnx2x_del_all_napi()
                +-> __netif_napi_del()
    
    bnx2x_io_slot_reset()
      +-> bnx2x_netif_stop()
           +-> bnx2x_napi_disable()
                +->napi_disable()
    
    Fix this by correcting the sequence of NAPI APIs usage,
    that is delete the NAPI after disabling it.
    
    Fixes: 7fa6f34081f1 ("bnx2x: AER revised")
    Reported-by: David Christensen <drc@linux.vnet.ibm.com>
    Tested-by: David Christensen <drc@linux.vnet.ibm.com>
    Signed-off-by: Manish Chopra <manishc@marvell.com>
    Signed-off-by: Ariel Elior <aelior@marvell.com>
    Link: https://lore.kernel.org/r/20220426153913.6966-1-manishc@marvell.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 63c15be9dacd54309933c39b3a0b8bfb000308e1
Author: Maxim Mikityanskiy <maximmi@nvidia.com>
Date:   Tue Apr 26 18:49:49 2022 +0300

    tls: Skip tls_append_frag on zero copy size
    
    [ Upstream commit a0df71948e9548de819a6f1da68f5f1742258a52 ]
    
    Calling tls_append_frag when max_open_record_len == record->len might
    add an empty fragment to the TLS record if the call happens to be on the
    page boundary. Normally tls_append_frag coalesces the zero-sized
    fragment to the previous one, but not if it's on page boundary.
    
    If a resync happens then, the mlx5 driver posts dump WQEs in
    tx_post_resync_dump, and the empty fragment may become a data segment
    with byte_count == 0, which will confuse the NIC and lead to a CQE
    error.
    
    This commit fixes the described issue by skipping tls_append_frag on
    zero size to avoid adding empty fragments. The fix is not in the driver,
    because an empty fragment is hardly the desired behavior.
    
    Fixes: e8f69799810c ("net/tls: Add generic NIC offload infrastructure")
    Signed-off-by: Maxim Mikityanskiy <maximmi@nvidia.com>
    Reviewed-by: Tariq Toukan <tariqt@nvidia.com>
    Link: https://lore.kernel.org/r/20220426154949.159055-1-maximmi@nvidia.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit af06f2395f6487404aa5fc8545f2cc25c2da42d4
Author: Miaoqian Lin <linmq006@gmail.com>
Date:   Thu Apr 21 17:03:09 2022 +0800

    drm/amd/display: Fix memory leak in dcn21_clock_source_create
    
    [ Upstream commit 65e54987508b6f0771f56bdfa3ee1926d52785ae ]
    
    When dcn20_clk_src_construct() fails, we need to release clk_src.
    
    Fixes: 6f4e6361c3ff ("drm/amd/display: Add Renoir resource (v2)")
    Signed-off-by: Miaoqian Lin <linmq006@gmail.com>
    Signed-off-by: Alex Deucher <alexander.deucher@amd.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 349bde761e7774849068aa413732f54f24f5ced2
Author: David Yat Sin <david.yatsin@amd.com>
Date:   Mon Apr 18 11:55:58 2022 -0400

    drm/amdkfd: Fix GWS queue count
    
    [ Upstream commit 7c6b6e18c890f30965b0589b0a57645e1dbccfde ]
    
    dqm->gws_queue_count and pdd->qpd.mapped_gws_queue need to be updated
    each time the queue gets evicted.
    
    Fixes: b8020b0304c8 ("drm/amdkfd: Enable over-subscription with >1 GWS queue")
    Signed-off-by: David Yat Sin <david.yatsin@amd.com>
    Reviewed-by: Felix Kuehling <Felix.Kuehling@amd.com>
    Signed-off-by: Alex Deucher <alexander.deucher@amd.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit de5a1c3a82b320d79e544fda1be85a595c223b42
Author: Hans de Goede <hdegoede@redhat.com>
Date:   Wed Apr 27 13:49:56 2022 +0200

    platform/x86: asus-wmi: Fix driver not binding when fan curve control probe fails
    
    [ Upstream commit 9fe1bb29ea0ab231aa916dad4bcf0c435beb5869 ]
    
    Before this commit fan_curve_check_present() was trying to not cause
    the probe to fail on devices without fan curve control by testing for
    known error codes returned by asus_wmi_evaluate_method_buf().
    
    Checking for ENODATA or ENODEV, with the latter being returned by this
    function when an ACPI integer with a value of ASUS_WMI_UNSUPPORTED_METHOD
    is returned. But for other ACPI integer returns this function just returns
    them as is, including the ASUS_WMI_DSTS_UNKNOWN_BIT value of 2.
    
    On the Asus U36SD ASUS_WMI_DSTS_UNKNOWN_BIT gets returned, leading to:
    
      asus-nb-wmi: probe of asus-nb-wmi failed with error 2
    
    Instead of playing whack a mole with error codes here, simply treat all
    errors as there not being any fan curves, fixing the driver no longer
    loading on the Asus U36SD laptop.
    
    Fixes: e3d13da7f77d ("platform/x86: asus-wmi: Fix regression when probing for fan curve control")
    BugLink: https://bugzilla.redhat.com/show_bug.cgi?id=2079125
    Cc: Luke D. Jones <luke@ljones.dev>
    Signed-off-by: Hans de Goede <hdegoede@redhat.com>
    Link: https://lore.kernel.org/r/20220427114956.332919-1-hdegoede@redhat.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 04e49a9506e473fb12f50c375d32cfee8a74cc25
Author: Dan Carpenter <dan.carpenter@oracle.com>
Date:   Wed Apr 13 10:37:44 2022 +0300

    platform/x86: asus-wmi: Potential buffer overflow in asus_wmi_evaluate_method_buf()
    
    [ Upstream commit 4345ece8f0bcc682f1fb3b648922c9be5f7dbe6c ]
    
    This code tests for if the obj->buffer.length is larger than the buffer
    but then it just does the memcpy() anyway.
    
    Fixes: 0f0ac158d28f ("platform/x86: asus-wmi: Add support for custom fan curves")
    Signed-off-by: Dan Carpenter <dan.carpenter@oracle.com>
    Link: https://lore.kernel.org/r/20220413073744.GB8812@kili
    Reviewed-by: Hans de Goede <hdegoede@redhat.com>
    Signed-off-by: Hans de Goede <hdegoede@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 697b486ee6eb5c4f4649ec03fbcae5c0189c80c7
Author: Volodymyr Mytnyk <volodymyr.mytnyk@plvision.eu>
Date:   Wed Apr 27 14:09:00 2022 +0300

    netfilter: conntrack: fix udp offload timeout sysctl
    
    [ Upstream commit 626873c446f7559d5af8b48cefad903ffd85cf4e ]
    
    `nf_flowtable_udp_timeout` sysctl option is available only
    if CONFIG_NFT_FLOW_OFFLOAD enabled. But infra for this flow
    offload UDP timeout was added under CONFIG_NF_FLOW_TABLE
    config option. So, if you have CONFIG_NFT_FLOW_OFFLOAD
    disabled and CONFIG_NF_FLOW_TABLE enabled, the
    `nf_flowtable_udp_timeout` is not present in sysfs.
    Please note, that TCP flow offload timeout sysctl option
    is present even CONFIG_NFT_FLOW_OFFLOAD is disabled.
    
    I suppose it was a typo in commit that adds UDP flow offload
    timeout and CONFIG_NF_FLOW_TABLE should be used instead.
    
    Fixes: 975c57504da1 ("netfilter: conntrack: Introduce udp offload timeout configuration")
    Signed-off-by: Volodymyr Mytnyk <volodymyr.mytnyk@plvision.eu>
    Signed-off-by: Pablo Neira Ayuso <pablo@netfilter.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a5929bc81877b3705c91e6a5fc5f9fc2d7776626
Author: Florian Westphal <fw@strlen.de>
Date:   Mon Apr 25 11:47:11 2022 +0200

    netfilter: nf_conntrack_tcp: re-init for syn packets only
    
    [ Upstream commit c7aab4f17021b636a0ee75bcf28e06fb7c94ab48 ]
    
    Jaco Kroon reported tcp problems that Eric Dumazet and Neal Cardwell
    pinpointed to nf_conntrack tcp_in_window() bug.
    
    tcp trace shows following sequence:
    
    I > R Flags [S], seq 3451342529, win 62580, options [.. tfo [|tcp]>
    R > I Flags [S.], seq 2699962254, ack 3451342530, win 65535, options [..]
    R > I Flags [P.], seq 1:89, ack 1, [..]
    
    Note 3rd ACK is from responder to initiator so following branch is taken:
        } else if (((state->state == TCP_CONNTRACK_SYN_SENT
                   && dir == IP_CT_DIR_ORIGINAL)
                   || (state->state == TCP_CONNTRACK_SYN_RECV
                   && dir == IP_CT_DIR_REPLY))
                   && after(end, sender->td_end)) {
    
    ... because state == TCP_CONNTRACK_SYN_RECV and dir is REPLY.
    This causes the scaling factor to be reset to 0: window scale option
    is only present in syn(ack) packets.  This in turn makes nf_conntrack
    mark valid packets as out-of-window.
    
    This was always broken, it exists even in original commit where
    window tracking was added to ip_conntrack (nf_conntrack predecessor)
    in 2.6.9-rc1 kernel.
    
    Restrict to 'tcph->syn', just like the 3rd condtional added in
    commit 82b72cb94666 ("netfilter: conntrack: re-init state for retransmitted syn-ack").
    
    Upon closer look, those conditionals/branches can be merged:
    
    Because earlier checks prevent syn-ack from showing up in
    original direction, the 'dir' checks in the conditional quoted above are
    redundant, remove them. Return early for pure syn retransmitted in reply
    direction (simultaneous open).
    
    Fixes: 9fb9cbb1082d ("[NETFILTER]: Add nf_conntrack subsystem.")
    Reported-by: Jaco Kroon <jaco@uls.co.za>
    Signed-off-by: Florian Westphal <fw@strlen.de>
    Acked-by: Jozsef Kadlecsik <kadlec@netfilter.org>
    Signed-off-by: Pablo Neira Ayuso <pablo@netfilter.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 283ffcce1ad9a34dcbb2dd6f67ba2a78a7d7626d
Author: Jens Axboe <axboe@kernel.dk>
Date:   Tue Apr 26 19:34:57 2022 -0600

    io_uring: check reserved fields for recv/recvmsg
    
    [ Upstream commit 5a1e99b61b0c81388cde0c808b3e4173907df19f ]
    
    We should check unused fields for non-zero and -EINVAL if they are set,
    making it consistent with other opcodes.
    
    Fixes: aa1fa28fc73e ("io_uring: add support for recvmsg()")
    Signed-off-by: Jens Axboe <axboe@kernel.dk>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 9f2e0c98549ca69e5bc8ab3504ac0b8fbc0aea88
Author: Jens Axboe <axboe@kernel.dk>
Date:   Tue Apr 26 19:34:11 2022 -0600

    io_uring: check reserved fields for send/sendmsg
    
    [ Upstream commit 588faa1ea5eecb351100ee5d187b9be99210f70d ]
    
    We should check unused fields for non-zero and -EINVAL if they are set,
    making it consistent with other opcodes.
    
    Fixes: 0fa03c624d8f ("io_uring: add support for sendmsg()")
    Signed-off-by: Jens Axboe <axboe@kernel.dk>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 94b2a9d788c201b95faf513be325c934ad85cb16
Author: Martin Blumenstingl <martin.blumenstingl@googlemail.com>
Date:   Mon Apr 25 17:20:27 2022 +0200

    net: dsa: lantiq_gswip: Don't set GSWIP_MII_CFG_RMII_CLK
    
    [ Upstream commit 71cffebf6358a7f5031f5b208bbdc1cb4db6e539 ]
    
    Commit 4b5923249b8fa4 ("net: dsa: lantiq_gswip: Configure all remaining
    GSWIP_MII_CFG bits") added all known bits in the GSWIP_MII_CFGp
    register. It helped bring this register into a well-defined state so the
    driver has to rely less on the bootloader to do things right.
    Unfortunately it also sets the GSWIP_MII_CFG_RMII_CLK bit without any
    possibility to configure it. Upon further testing it turns out that all
    boards which are supported by the GSWIP driver in OpenWrt which use an
    RMII PHY have a dedicated oscillator on the board which provides the
    50MHz RMII reference clock.
    
    Don't set the GSWIP_MII_CFG_RMII_CLK bit (but keep the code which always
    clears it) to fix support for the Fritz!Box 7362 SL in OpenWrt. This is
    a board with two Atheros AR8030 RMII PHYs. With the "RMII clock" bit set
    the MAC also generates the RMII reference clock whose signal then
    conflicts with the signal from the oscillator on the board. This results
    in a constant cycle of the PHY detecting link up/down (and as a result
    of that: the two ports using the AR8030 PHYs are not working).
    
    At the time of writing this patch there's no known board where the MAC
    (GSWIP) has to generate the RMII reference clock. If needed this can be
    implemented in future by providing a device-tree flag so the
    GSWIP_MII_CFG_RMII_CLK bit can be toggled per port.
    
    Fixes: 4b5923249b8fa4 ("net: dsa: lantiq_gswip: Configure all remaining GSWIP_MII_CFG bits")
    Tested-by: Jan Hoffmann <jan@3e8.eu>
    Signed-off-by: Martin Blumenstingl <martin.blumenstingl@googlemail.com>
    Acked-by: Hauke Mehrtens <hauke@hauke-m.de>
    Link: https://lore.kernel.org/r/20220425152027.2220750-1-martin.blumenstingl@googlemail.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a236fa3b5a6324659cb21f249a7227088ef460d9
Author: Luiz Augusto von Dentz <luiz.von.dentz@intel.com>
Date:   Fri Apr 22 12:58:16 2022 -0700

    Bluetooth: hci_event: Fix checking for invalid handle on error status
    
    [ Upstream commit c86cc5a3ec70f5644f1fa21610b943d0441bc1f7 ]
    
    Commit d5ebaa7c5f6f6 introduces checks for handle range
    (e.g HCI_CONN_HANDLE_MAX) but controllers like Intel AX200 don't seem
    to respect the valid range int case of error status:
    
    > HCI Event: Connect Complete (0x03) plen 11
            Status: Page Timeout (0x04)
            Handle: 65535
            Address: 94:DB:56:XX:XX:XX (Sony Home Entertainment&
            Sound Products Inc)
            Link type: ACL (0x01)
            Encryption: Disabled (0x00)
    [1644965.827560] Bluetooth: hci0: Ignoring HCI_Connection_Complete for invalid handle
    
    Because of it is impossible to cleanup the connections properly since
    the stack would attempt to cancel the connection which is no longer in
    progress causing the following trace:
    
    < HCI Command: Create Connection Cancel (0x01|0x0008) plen 6
            Address: 94:DB:56:XX:XX:XX (Sony Home Entertainment&
            Sound Products Inc)
    = bluetoothd: src/profile.c:record_cb() Unable to get Hands-Free Voice
            gateway SDP record: Connection timed out
    > HCI Event: Command Complete (0x0e) plen 10
          Create Connection Cancel (0x01|0x0008) ncmd 1
            Status: Unknown Connection Identifier (0x02)
            Address: 94:DB:56:XX:XX:XX (Sony Home Entertainment&
            Sound Products Inc)
    < HCI Command: Create Connection Cancel (0x01|0x0008) plen 6
            Address: 94:DB:56:XX:XX:XX (Sony Home Entertainment&
            Sound Products Inc)
    
    Fixes: d5ebaa7c5f6f6 ("Bluetooth: hci_event: Ignore multiple conn complete events")
    Signed-off-by: Luiz Augusto von Dentz <luiz.von.dentz@intel.com>
    Signed-off-by: Marcel Holtmann <marcel@holtmann.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 5ac2ba875b1164639febd497bf3afdc8bde6b4be
Author: Petr Oros <poros@redhat.com>
Date:   Wed Apr 13 17:37:45 2022 +0200

    ice: wait 5 s for EMP reset after firmware flash
    
    [ Upstream commit b537752e6cbf0e4475c165178ca02241b53ff6ef ]
    
    We need to wait 5 s for EMP reset after firmware flash. Code was extracted
    from OOT driver (ice v1.8.3 downloaded from sourceforge). Without this
    wait, fw_activate let card in inconsistent state and recoverable only
    by second flash/activate. Flash was tested on these fw's:
    From -> To
     3.00 -> 3.10/3.20
     3.10 -> 3.00/3.20
     3.20 -> 3.00/3.10
    
    Reproducer:
    [root@host ~]# devlink dev flash pci/0000:ca:00.0 file E810_XXVDA4_FH_O_SEC_FW_1p6p1p9_NVM_3p10_PLDMoMCTP_0.11_8000AD7B.bin
    Preparing to flash
    [fw.mgmt] Erasing
    [fw.mgmt] Erasing done
    [fw.mgmt] Flashing 100%
    [fw.mgmt] Flashing done 100%
    [fw.undi] Erasing
    [fw.undi] Erasing done
    [fw.undi] Flashing 100%
    [fw.undi] Flashing done 100%
    [fw.netlist] Erasing
    [fw.netlist] Erasing done
    [fw.netlist] Flashing 100%
    [fw.netlist] Flashing done 100%
    Activate new firmware by devlink reload
    [root@host ~]# devlink dev reload pci/0000:ca:00.0 action fw_activate
    reload_actions_performed:
        fw_activate
    [root@host ~]# ip link show ens7f0
    71: ens7f0: <NO-CARRIER,BROADCAST,MULTICAST,UP> mtu 1500 qdisc mq state DOWN mode DEFAULT group default qlen 1000
        link/ether b4:96:91:dc:72:e0 brd ff:ff:ff:ff:ff:ff
        altname enp202s0f0
    
    dmesg after flash:
    [   55.120788] ice: Copyright (c) 2018, Intel Corporation.
    [   55.274734] ice 0000:ca:00.0: Get PHY capabilities failed status = -5, continuing anyway
    [   55.569797] ice 0000:ca:00.0: The DDP package was successfully loaded: ICE OS Default Package version 1.3.28.0
    [   55.603629] ice 0000:ca:00.0: Get PHY capability failed.
    [   55.608951] ice 0000:ca:00.0: ice_init_nvm_phy_type failed: -5
    [   55.647348] ice 0000:ca:00.0: PTP init successful
    [   55.675536] ice 0000:ca:00.0: DCB is enabled in the hardware, max number of TCs supported on this port are 8
    [   55.685365] ice 0000:ca:00.0: FW LLDP is disabled, DCBx/LLDP in SW mode.
    [   55.692179] ice 0000:ca:00.0: Commit DCB Configuration to the hardware
    [   55.701382] ice 0000:ca:00.0: 126.024 Gb/s available PCIe bandwidth, limited by 16.0 GT/s PCIe x8 link at 0000:c9:02.0 (capable of 252.048 Gb/s with 16.0 GT/s PCIe x16 link)
    Reboot doesn’t help, only second flash/activate with OOT or patched
    driver put card back in consistent state.
    
    After patch:
    [root@host ~]# devlink dev flash pci/0000:ca:00.0 file E810_XXVDA4_FH_O_SEC_FW_1p6p1p9_NVM_3p10_PLDMoMCTP_0.11_8000AD7B.bin
    Preparing to flash
    [fw.mgmt] Erasing
    [fw.mgmt] Erasing done
    [fw.mgmt] Flashing 100%
    [fw.mgmt] Flashing done 100%
    [fw.undi] Erasing
    [fw.undi] Erasing done
    [fw.undi] Flashing 100%
    [fw.undi] Flashing done 100%
    [fw.netlist] Erasing
    [fw.netlist] Erasing done
    [fw.netlist] Flashing 100%
    [fw.netlist] Flashing done 100%
    Activate new firmware by devlink reload
    [root@host ~]# devlink dev reload pci/0000:ca:00.0 action fw_activate
    reload_actions_performed:
        fw_activate
    [root@host ~]# ip link show ens7f0
    19: ens7f0: <BROADCAST,MULTICAST,UP,LOWER_UP> mtu 1500 qdisc mq state UP mode DEFAULT group default qlen 1000
        link/ether b4:96:91:dc:72:e0 brd ff:ff:ff:ff:ff:ff
        altname enp202s0f0
    
    Fixes: 399e27dbbd9e94 ("ice: support immediate firmware activation via devlink reload")
    Signed-off-by: Petr Oros <poros@redhat.com>
    Tested-by: Gurucharan <gurucharanx.g@intel.com> (A Contingent worker at Intel)
    Signed-off-by: Tony Nguyen <anthony.l.nguyen@intel.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 5411a69705aaea2cba36eb33e2fc48db5b58bf54
Author: Samuel Holland <samuel@sholland.org>
Date:   Sun Apr 24 11:26:21 2022 -0500

    drm/sun4i: Remove obsolete references to PHYS_OFFSET
    
    [ Upstream commit dc3ae06c5f2170d879ff58696f629d8c3868aec3 ]
    
    commit b4bdc4fbf8d0 ("soc: sunxi: Deal with the MBUS DMA offsets in a
    central place") added a platform device notifier that sets the DMA
    offset for all of the display engine frontend and backend devices.
    
    The code applying the offset to DMA buffer physical addresses was then
    removed from the backend driver in commit 756668ba682e ("drm/sun4i:
    backend: Remove the MBUS quirks"), but the code subtracting PHYS_OFFSET
    was left in the frontend driver.
    
    As a result, the offset was applied twice in the frontend driver. This
    likely went unnoticed because it only affects specific configurations
    (scaling or certain pixel formats) where the frontend is used, on boards
    with both one of these older SoCs and more than 1 GB of DRAM.
    
    In addition, the references to PHYS_OFFSET prevent compiling the driver
    on architectures where PHYS_OFFSET is not defined.
    
    Fixes: b4bdc4fbf8d0 ("soc: sunxi: Deal with the MBUS DMA offsets in a central place")
    Reviewed-by: Jernej Skrabec <jernej.skrabec@gmail.com>
    Signed-off-by: Samuel Holland <samuel@sholland.org>
    Signed-off-by: Maxime Ripard <maxime@cerno.tech>
    Link: https://patchwork.freedesktop.org/patch/msgid/20220424162633.12369-4-samuel@sholland.org
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a2c2bc6894baa674ae00fbdc5bafe1b1b376b805
Author: Nathan Rossi <nathan@nathanrossi.com>
Date:   Mon Apr 25 07:04:54 2022 +0000

    net: dsa: mv88e6xxx: Fix port_hidden_wait to account for port_base_addr
    
    [ Upstream commit 24cbdb910bb62b5be3865275e5682be1a7708c0f ]
    
    The other port_hidden functions rely on the port_read/port_write
    functions to access the hidden control port. These functions apply the
    offset for port_base_addr where applicable. Update port_hidden_wait to
    use the port_wait_bit so that port_base_addr offsets are accounted for
    when waiting for the busy bit to change.
    
    Without the offset the port_hidden_wait function would timeout on
    devices that have a non-zero port_base_addr (e.g. MV88E6141), however
    devices that have a zero port_base_addr would operate correctly (e.g.
    MV88E6390).
    
    Fixes: 609070133aff ("net: dsa: mv88e6xxx: update code operating on hidden registers")
    Signed-off-by: Nathan Rossi <nathan@nathanrossi.com>
    Reviewed-by: Marek Behún <kabel@kernel.org>
    Reviewed-by: Andrew Lunn <andrew@lunn.ch>
    Link: https://lore.kernel.org/r/20220425070454.348584-1-nathan@nathanrossi.com
    Signed-off-by: Paolo Abeni <pabeni@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit be0cfea41f4aa7d952d0d275d24aba0938eff39b
Author: Baruch Siach <baruch.siach@siklu.com>
Date:   Mon Apr 25 09:27:38 2022 +0300

    net: phy: marvell10g: fix return value on error
    
    [ Upstream commit 0ed9704b660b259b54743cad8a84a11148f60f0a ]
    
    Return back the error value that we get from phy_read_mmd().
    
    Fixes: c84786fa8f91 ("net: phy: marvell10g: read copper results from CSSR1")
    Signed-off-by: Baruch Siach <baruch.siach@siklu.com>
    Reviewed-by: Marek Behún <kabel@kernel.org>
    Reviewed-by: Russell King (Oracle) <rmk+kernel@armlinux.org.uk>
    Link: https://lore.kernel.org/r/f47cb031aeae873bb008ba35001607304a171a20.1650868058.git.baruch@tkos.co.il
    Signed-off-by: Paolo Abeni <pabeni@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit b7d15a413848a84a73e00677f164a698aa78b513
Author: Jonathan Lemon <jonathan.lemon@gmail.com>
Date:   Sun Apr 24 09:53:07 2022 -0700

    net: bcmgenet: hide status block before TX timestamping
    
    [ Upstream commit acac0541d1d65e81e599ec399d34d184d2424401 ]
    
    The hardware checksum offloading requires use of a transmit
    status block inserted before the outgoing frame data, this was
    updated in '9a9ba2a4aaaa ("net: bcmgenet: always enable status blocks")'
    
    However, skb_tx_timestamp() assumes that it is passed a raw frame
    and PTP parsing chokes on this status block.
    
    Fix this by calling __skb_pull(), which hides the TSB before calling
    skb_tx_timestamp(), so an outgoing PTP packet is parsed correctly.
    
    As the data in the skb has already been set up for DMA, and the
    dma_unmap_* calls use a separately stored address, there is no
    no effective change in the data transmission.
    
    Signed-off-by: Jonathan Lemon <jonathan.lemon@gmail.com>
    Acked-by: Florian Fainelli <f.fainelli@gmail.com>
    Link: https://lore.kernel.org/r/20220424165307.591145-1-jonathan.lemon@gmail.com
    Fixes: d03825fba459 ("net: bcmgenet: add skb_tx_timestamp call")
    Signed-off-by: Paolo Abeni <pabeni@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 019e80a7f71e8e62efda501081172dc70b5a635a
Author: Lin Ma <linma@zju.edu.cn>
Date:   Fri Apr 22 19:43:40 2022 +0800

    mctp: defer the kfree of object mdev->addrs
    
    [ Upstream commit b561275d633bcd8e0e8055ab86f1a13df75a0269 ]
    
    The function mctp_unregister() reclaims the device's relevant resource
    when a netcard detaches. However, a running routine may be unaware of
    this and cause the use-after-free of the mdev->addrs object.
    
    The race condition can be demonstrated below
    
     cleanup thread               another thread
                              |
    unregister_netdev()       |  mctp_sendmsg()
    ...                       |    ...
      mctp_unregister()       |    rt = mctp_route_lookup()
        ...                   |    mctl_local_output()
        kfree(mdev->addrs)    |      ...
                              |      saddr = rt->dev->addrs[0];
                              |
    
    An attacker can adopt the (recent provided) mtcpserial driver with pty
    to fake the device detaching and use the userfaultfd to increase the
    race success chance (in mctp_sendmsg). The KASan report for such a POC
    is shown below:
    
    [   86.051955] ==================================================================
    [   86.051955] BUG: KASAN: use-after-free in mctp_local_output+0x4e9/0xb7d
    [   86.051955] Read of size 1 at addr ffff888005f298c0 by task poc/295
    [   86.051955]
    [   86.051955] Call Trace:
    [   86.051955]  <TASK>
    [   86.051955]  dump_stack_lvl+0x33/0x42
    [   86.051955]  print_report.cold.13+0xb2/0x6b3
    [   86.051955]  ? preempt_schedule_irq+0x57/0x80
    [   86.051955]  ? mctp_local_output+0x4e9/0xb7d
    [   86.051955]  kasan_report+0xa5/0x120
    [   86.051955]  ? mctp_local_output+0x4e9/0xb7d
    [   86.051955]  mctp_local_output+0x4e9/0xb7d
    [   86.051955]  ? mctp_dev_set_key+0x79/0x79
    [   86.051955]  ? copyin+0x38/0x50
    [   86.051955]  ? _copy_from_iter+0x1b6/0xf20
    [   86.051955]  ? sysvec_apic_timer_interrupt+0x97/0xb0
    [   86.051955]  ? asm_sysvec_apic_timer_interrupt+0x12/0x20
    [   86.051955]  ? mctp_local_output+0x1/0xb7d
    [   86.051955]  mctp_sendmsg+0x64d/0xdb0
    [   86.051955]  ? mctp_sk_close+0x20/0x20
    [   86.051955]  ? __fget_light+0x2fd/0x4f0
    [   86.051955]  ? mctp_sk_close+0x20/0x20
    [   86.051955]  sock_sendmsg+0xdd/0x110
    [   86.051955]  __sys_sendto+0x1cc/0x2a0
    [   86.051955]  ? __ia32_sys_getpeername+0xa0/0xa0
    [   86.051955]  ? new_sync_write+0x335/0x550
    [   86.051955]  ? alloc_file+0x22f/0x500
    [   86.051955]  ? __ip_do_redirect+0x820/0x1820
    [   86.051955]  ? vfs_write+0x44d/0x7b0
    [   86.051955]  ? vfs_write+0x44d/0x7b0
    [   86.051955]  ? fput_many+0x15/0x120
    [   86.051955]  ? ksys_write+0x155/0x1b0
    [   86.051955]  ? __ia32_sys_read+0xa0/0xa0
    [   86.051955]  __x64_sys_sendto+0xd8/0x1b0
    [   86.051955]  ? exit_to_user_mode_prepare+0x2f/0x120
    [   86.051955]  ? syscall_exit_to_user_mode+0x12/0x20
    [   86.051955]  do_syscall_64+0x3a/0x80
    [   86.051955]  entry_SYSCALL_64_after_hwframe+0x44/0xae
    [   86.051955] RIP: 0033:0x7f82118a56b3
    [   86.051955] RSP: 002b:00007ffdb154b110 EFLAGS: 00000293 ORIG_RAX: 000000000000002c
    [   86.051955] RAX: ffffffffffffffda RBX: 0000000000000000 RCX: 00007f82118a56b3
    [   86.051955] RDX: 0000000000000010 RSI: 00007f8211cd4000 RDI: 0000000000000007
    [   86.051955] RBP: 00007ffdb154c1d0 R08: 00007ffdb154b164 R09: 000000000000000c
    [   86.051955] R10: 0000000000000000 R11: 0000000000000293 R12: 000055d779800db0
    [   86.051955] R13: 00007ffdb154c2b0 R14: 0000000000000000 R15: 0000000000000000
    [   86.051955]  </TASK>
    [   86.051955]
    [   86.051955] Allocated by task 295:
    [   86.051955]  kasan_save_stack+0x1c/0x40
    [   86.051955]  __kasan_kmalloc+0x84/0xa0
    [   86.051955]  mctp_rtm_newaddr+0x242/0x610
    [   86.051955]  rtnetlink_rcv_msg+0x2fd/0x8b0
    [   86.051955]  netlink_rcv_skb+0x11c/0x340
    [   86.051955]  netlink_unicast+0x439/0x630
    [   86.051955]  netlink_sendmsg+0x752/0xc00
    [   86.051955]  sock_sendmsg+0xdd/0x110
    [   86.051955]  __sys_sendto+0x1cc/0x2a0
    [   86.051955]  __x64_sys_sendto+0xd8/0x1b0
    [   86.051955]  do_syscall_64+0x3a/0x80
    [   86.051955]  entry_SYSCALL_64_after_hwframe+0x44/0xae
    [   86.051955]
    [   86.051955] Freed by task 301:
    [   86.051955]  kasan_save_stack+0x1c/0x40
    [   86.051955]  kasan_set_track+0x21/0x30
    [   86.051955]  kasan_set_free_info+0x20/0x30
    [   86.051955]  __kasan_slab_free+0x104/0x170
    [   86.051955]  kfree+0x8c/0x290
    [   86.051955]  mctp_dev_notify+0x161/0x2c0
    [   86.051955]  raw_notifier_call_chain+0x8b/0xc0
    [   86.051955]  unregister_netdevice_many+0x299/0x1180
    [   86.051955]  unregister_netdevice_queue+0x210/0x2f0
    [   86.051955]  unregister_netdev+0x13/0x20
    [   86.051955]  mctp_serial_close+0x6d/0xa0
    [   86.051955]  tty_ldisc_kill+0x31/0xa0
    [   86.051955]  tty_ldisc_hangup+0x24f/0x560
    [   86.051955]  __tty_hangup.part.28+0x2ce/0x6b0
    [   86.051955]  tty_release+0x327/0xc70
    [   86.051955]  __fput+0x1df/0x8b0
    [   86.051955]  task_work_run+0xca/0x150
    [   86.051955]  exit_to_user_mode_prepare+0x114/0x120
    [   86.051955]  syscall_exit_to_user_mode+0x12/0x20
    [   86.051955]  do_syscall_64+0x46/0x80
    [   86.051955]  entry_SYSCALL_64_after_hwframe+0x44/0xae
    [   86.051955]
    [   86.051955] The buggy address belongs to the object at ffff888005f298c0
    [   86.051955]  which belongs to the cache kmalloc-8 of size 8
    [   86.051955] The buggy address is located 0 bytes inside of
    [   86.051955]  8-byte region [ffff888005f298c0, ffff888005f298c8)
    [   86.051955]
    [   86.051955] The buggy address belongs to the physical page:
    [   86.051955] flags: 0x100000000000200(slab|node=0|zone=1)
    [   86.051955] raw: 0100000000000200 dead000000000100 dead000000000122 ffff888005c42280
    [   86.051955] raw: 0000000000000000 0000000080660066 00000001ffffffff 0000000000000000
    [   86.051955] page dumped because: kasan: bad access detected
    [   86.051955]
    [   86.051955] Memory state around the buggy address:
    [   86.051955]  ffff888005f29780: 00 fc fc fc fc 00 fc fc fc fc 00 fc fc fc fc 00
    [   86.051955]  ffff888005f29800: fc fc fc fc 00 fc fc fc fc 00 fc fc fc fc 00 fc
    [   86.051955] >ffff888005f29880: fc fc fc fb fc fc fc fc fa fc fc fc fc fa fc fc
    [   86.051955]                                            ^
    [   86.051955]  ffff888005f29900: fc fc 00 fc fc fc fc 00 fc fc fc fc 00 fc fc fc
    [   86.051955]  ffff888005f29980: fc 00 fc fc fc fc 00 fc fc fc fc 00 fc fc fc fc
    [   86.051955] ==================================================================
    
    To this end, just like the commit e04480920d1e ("Bluetooth: defer
    cleanup of resources in hci_unregister_dev()")  this patch defers the
    destructive kfree(mdev->addrs) in mctp_unregister to the mctp_dev_put,
    where the refcount of mdev is zero and the entire device is reclaimed.
    This prevents the use-after-free because the sendmsg thread holds the
    reference of mdev in the mctp_route object.
    
    Fixes: 583be982d934 (mctp: Add device handling and netlink interface)
    Signed-off-by: Lin Ma <linma@zju.edu.cn>
    Acked-by: Jeremy Kerr <jk@codeconstruct.com.au>
    Link: https://lore.kernel.org/r/20220422114340.32346-1-linma@zju.edu.cn
    Signed-off-by: Paolo Abeni <pabeni@redhat.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 9ecfc16b14edac6b179d03986de449b63d3661e0
Author: Vladimir Zapolskiy <vladimir.zapolskiy@linaro.org>
Date:   Thu Apr 7 23:09:19 2022 +0300

    cpufreq: qcom-cpufreq-hw: Clear dcvs interrupts
    
    [ Upstream commit e4e6448638a01905faeda9bf96aa9df7c8ef463c ]
    
    It's noted that dcvs interrupts are not self-clearing, thus an interrupt
    handler runs constantly, which leads to a severe regression in runtime.
    To fix the problem an explicit write to clear interrupt register is
    required, note that on OSM platforms the register may not be present.
    
    Fixes: 275157b367f4 ("cpufreq: qcom-cpufreq-hw: Add dcvs interrupt support")
    Signed-off-by: Vladimir Zapolskiy <vladimir.zapolskiy@linaro.org>
    Signed-off-by: Viresh Kumar <viresh.kumar@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 23fdc92186e6ab6ed10b438c9fbdb76359522ef0
Author: Yang Yingliang <yangyingliang@huawei.com>
Date:   Thu Apr 21 21:43:08 2022 +0800

    clk: sunxi: sun9i-mmc: check return value after calling platform_get_resource()
    
    [ Upstream commit f58ca215cda1975f77b2b762903684a3c101bec9 ]
    
    It will cause null-ptr-deref if platform_get_resource() returns NULL,
    we need check the return value.
    
    Fixes: 7a6fca879f59 ("clk: sunxi: Add driver for A80 MMC config clocks/resets")
    Signed-off-by: Yang Yingliang <yangyingliang@huawei.com>
    Reviewed-by: Samuel Holland <samuel@sholland.org>
    Signed-off-by: Jernej Skrabec <jernej.skrabec@gmail.com>
    Link: https://lore.kernel.org/r/20220421134308.2885094-1-yangyingliang@huawei.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 0e165cc527f9c1618c1818ed89fe3f34ef680c81
Author: Christophe JAILLET <christophe.jaillet@wanadoo.fr>
Date:   Thu Apr 21 16:35:49 2022 +0200

    bus: sunxi-rsb: Fix the return value of sunxi_rsb_device_create()
    
    [ Upstream commit fff8c10368e64e7f8960f149375c12ca5f3b30af ]
    
    This code is really spurious.
    It always returns an ERR_PTR, even when err is known to be 0 and calls
    put_device() after a successful device_register() call.
    
    It is likely that the return statement in the normal path is missing.
    Add 'return rdev;' to fix it.
    
    Fixes: d787dcdb9c8f ("bus: sunxi-rsb: Add driver for Allwinner Reduced Serial Bus")
    Signed-off-by: Christophe JAILLET <christophe.jaillet@wanadoo.fr>
    Reviewed-by: Samuel Holland <samuel@sholland.org>
    Tested-by: Samuel Holland <samuel@sholland.org>
    Signed-off-by: Jernej Skrabec <jernej.skrabec@gmail.com>
    Link: https://lore.kernel.org/r/ef2b9576350bba4c8e05e669e9535e9e2a415763.1650551719.git.christophe.jaillet@wanadoo.fr
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 0dc770455611c56990e841f99be2d79446636c57
Author: Eric Dumazet <edumazet@google.com>
Date:   Sun Apr 24 13:35:09 2022 -0700

    tcp: make sure treq->af_specific is initialized
    
    [ Upstream commit ba5a4fdd63ae0c575707030db0b634b160baddd7 ]
    
    syzbot complained about a recent change in TCP stack,
    hitting a NULL pointer [1]
    
    tcp request sockets have an af_specific pointer, which
    was used before the blamed change only for SYNACK generation
    in non SYNCOOKIE mode.
    
    tcp requests sockets momentarily created when third packet
    coming from client in SYNCOOKIE mode were not using
    treq->af_specific.
    
    Make sure this field is populated, in the same way normal
    TCP requests sockets do in tcp_conn_request().
    
    [1]
    TCP: request_sock_TCPv6: Possible SYN flooding on port 20002. Sending cookies.  Check SNMP counters.
    general protection fault, probably for non-canonical address 0xdffffc0000000001: 0000 [#1] PREEMPT SMP KASAN
    KASAN: null-ptr-deref in range [0x0000000000000008-0x000000000000000f]
    CPU: 1 PID: 3695 Comm: syz-executor864 Not tainted 5.18.0-rc3-syzkaller-00224-g5fd1fe4807f9 #0
    Hardware name: Google Google Compute Engine/Google Compute Engine, BIOS Google 01/01/2011
    RIP: 0010:tcp_create_openreq_child+0xe16/0x16b0 net/ipv4/tcp_minisocks.c:534
    Code: 48 c1 ea 03 80 3c 02 00 0f 85 e5 07 00 00 4c 8b b3 28 01 00 00 48 b8 00 00 00 00 00 fc ff df 49 8d 7e 08 48 89 fa 48 c1 ea 03 <80> 3c 02 00 0f 85 c9 07 00 00 48 8b 3c 24 48 89 de 41 ff 56 08 48
    RSP: 0018:ffffc90000de0588 EFLAGS: 00010202
    RAX: dffffc0000000000 RBX: ffff888076490330 RCX: 0000000000000100
    RDX: 0000000000000001 RSI: ffffffff87d67ff0 RDI: 0000000000000008
    RBP: ffff88806ee1c7f8 R08: 0000000000000000 R09: 0000000000000000
    R10: ffffffff87d67f00 R11: 0000000000000000 R12: ffff88806ee1bfc0
    R13: ffff88801b0e0368 R14: 0000000000000000 R15: 0000000000000000
    FS:  00007f517fe58700(0000) GS:ffff8880b9d00000(0000) knlGS:0000000000000000
    CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
    CR2: 00007ffcead76960 CR3: 000000006f97b000 CR4: 00000000003506e0
    DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
    DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
    Call Trace:
     <IRQ>
     tcp_v6_syn_recv_sock+0x199/0x23b0 net/ipv6/tcp_ipv6.c:1267
     tcp_get_cookie_sock+0xc9/0x850 net/ipv4/syncookies.c:207
     cookie_v6_check+0x15c3/0x2340 net/ipv6/syncookies.c:258
     tcp_v6_cookie_check net/ipv6/tcp_ipv6.c:1131 [inline]
     tcp_v6_do_rcv+0x1148/0x13b0 net/ipv6/tcp_ipv6.c:1486
     tcp_v6_rcv+0x3305/0x3840 net/ipv6/tcp_ipv6.c:1725
     ip6_protocol_deliver_rcu+0x2e9/0x1900 net/ipv6/ip6_input.c:422
     ip6_input_finish+0x14c/0x2c0 net/ipv6/ip6_input.c:464
     NF_HOOK include/linux/netfilter.h:307 [inline]
     NF_HOOK include/linux/netfilter.h:301 [inline]
     ip6_input+0x9c/0xd0 net/ipv6/ip6_input.c:473
     dst_input include/net/dst.h:461 [inline]
     ip6_rcv_finish net/ipv6/ip6_input.c:76 [inline]
     NF_HOOK include/linux/netfilter.h:307 [inline]
     NF_HOOK include/linux/netfilter.h:301 [inline]
     ipv6_rcv+0x27f/0x3b0 net/ipv6/ip6_input.c:297
     __netif_receive_skb_one_core+0x114/0x180 net/core/dev.c:5405
     __netif_receive_skb+0x24/0x1b0 net/core/dev.c:5519
     process_backlog+0x3a0/0x7c0 net/core/dev.c:5847
     __napi_poll+0xb3/0x6e0 net/core/dev.c:6413
     napi_poll net/core/dev.c:6480 [inline]
     net_rx_action+0x8ec/0xc60 net/core/dev.c:6567
     __do_softirq+0x29b/0x9c2 kernel/softirq.c:558
     invoke_softirq kernel/softirq.c:432 [inline]
     __irq_exit_rcu+0x123/0x180 kernel/softirq.c:637
     irq_exit_rcu+0x5/0x20 kernel/softirq.c:649
     sysvec_apic_timer_interrupt+0x93/0xc0 arch/x86/kernel/apic/apic.c:1097
    
    Fixes: 5b0b9e4c2c89 ("tcp: md5: incorrect tcp_header_len for incoming connections")
    Signed-off-by: Eric Dumazet <edumazet@google.com>
    Cc: Francesco Ruggeri <fruggeri@arista.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 0373f2fb5baeae10b17a9473f781541b26b86386
Author: Eric Dumazet <edumazet@google.com>
Date:   Sun Apr 24 17:34:07 2022 -0700

    tcp: fix potential xmit stalls caused by TCP_NOTSENT_LOWAT
    
    [ Upstream commit 4bfe744ff1644fbc0a991a2677dc874475dd6776 ]
    
    I had this bug sitting for too long in my pile, it is time to fix it.
    
    Thanks to Doug Porter for reminding me of it!
    
    We had various attempts in the past, including commit
    0cbe6a8f089e ("tcp: remove SOCK_QUEUE_SHRUNK"),
    but the issue is that TCP stack currently only generates
    EPOLLOUT from input path, when tp->snd_una has advanced
    and skb(s) cleaned from rtx queue.
    
    If a flow has a big RTT, and/or receives SACKs, it is possible
    that the notsent part (tp->write_seq - tp->snd_nxt) reaches 0
    and no more data can be sent until tp->snd_una finally advances.
    
    What is needed is to also check if POLLOUT needs to be generated
    whenever tp->snd_nxt is advanced, from output path.
    
    This bug triggers more often after an idle period, as
    we do not receive ACK for at least one RTT. tcp_notsent_lowat
    could be a fraction of what CWND and pacing rate would allow to
    send during this RTT.
    
    In a followup patch, I will remove the bogus call
    to tcp_chrono_stop(sk, TCP_CHRONO_SNDBUF_LIMITED)
    from tcp_check_space(). Fact that we have decided to generate
    an EPOLLOUT does not mean the application has immediately
    refilled the transmit queue. This optimistic call
    might have been the reason the bug seemed not too serious.
    
    Tested:
    
    200 ms rtt, 1% packet loss, 32 MB tcp_rmem[2] and tcp_wmem[2]
    
    $ echo 500000 >/proc/sys/net/ipv4/tcp_notsent_lowat
    $ cat bench_rr.sh
    SUM=0
    for i in {1..10}
    do
     V=`netperf -H remote_host -l30 -t TCP_RR -- -r 10000000,10000 -o LOCAL_BYTES_SENT | egrep -v "MIGRATED|Bytes"`
     echo $V
     SUM=$(($SUM + $V))
    done
    echo SUM=$SUM
    
    Before patch:
    $ bench_rr.sh
    130000000
    80000000
    140000000
    140000000
    140000000
    140000000
    130000000
    40000000
    90000000
    110000000
    SUM=1140000000
    
    After patch:
    $ bench_rr.sh
    430000000
    590000000
    530000000
    450000000
    450000000
    350000000
    450000000
    490000000
    480000000
    460000000
    SUM=4680000000  # This is 410 % of the value before patch.
    
    Fixes: c9bee3b7fdec ("tcp: TCP_NOTSENT_LOWAT socket option")
    Signed-off-by: Eric Dumazet <edumazet@google.com>
    Reported-by: Doug Porter <dsp@fb.com>
    Cc: Soheil Hassas Yeganeh <soheil@google.com>
    Cc: Neal Cardwell <ncardwell@google.com>
    Acked-by: Soheil Hassas Yeganeh <soheil@google.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit d2b0c2f47f1c572d9b611606de0e8ca1719ada3f
Author: Peilin Ye <peilin.ye@bytedance.com>
Date:   Thu Apr 21 15:09:02 2022 -0700

    ip_gre, ip6_gre: Fix race condition on o_seqno in collect_md mode
    
    [ Upstream commit 31c417c948d7f6909cb63f0ac3298f3c38f8ce20 ]
    
    As pointed out by Jakub Kicinski, currently using TUNNEL_SEQ in
    collect_md mode is racy for [IP6]GRE[TAP] devices.  Consider the
    following sequence of events:
    
    1. An [IP6]GRE[TAP] device is created in collect_md mode using "ip link
       add ... external".  "ip" ignores "[o]seq" if "external" is specified,
       so TUNNEL_SEQ is off, and the device is marked as NETIF_F_LLTX (i.e.
       it uses lockless TX);
    2. Someone sets TUNNEL_SEQ on outgoing skb's, using e.g.
       bpf_skb_set_tunnel_key() in an eBPF program attached to this device;
    3. gre_fb_xmit() or __gre6_xmit() processes these skb's:
    
            gre_build_header(skb, tun_hlen,
                             flags, protocol,
                             tunnel_id_to_key32(tun_info->key.tun_id),
                             (flags & TUNNEL_SEQ) ? htonl(tunnel->o_seqno++)
                                                  : 0);   ^^^^^^^^^^^^^^^^^
    
    Since we are not using the TX lock (&txq->_xmit_lock), multiple CPUs may
    try to do this tunnel->o_seqno++ in parallel, which is racy.  Fix it by
    making o_seqno atomic_t.
    
    As mentioned by Eric Dumazet in commit b790e01aee74 ("ip_gre: lockless
    xmit"), making o_seqno atomic_t increases "chance for packets being out
    of order at receiver" when NETIF_F_LLTX is on.
    
    Maybe a better fix would be:
    
    1. Do not ignore "oseq" in external mode.  Users MUST specify "oseq" if
       they want the kernel to allow sequencing of outgoing packets;
    2. Reject all outgoing TUNNEL_SEQ packets if the device was not created
       with "oseq".
    
    Unfortunately, that would break userspace.
    
    We could now make [IP6]GRE[TAP] devices always NETIF_F_LLTX, but let us
    do it in separate patches to keep this fix minimal.
    
    Suggested-by: Jakub Kicinski <kuba@kernel.org>
    Fixes: 77a5196a804e ("gre: add sequence number for collect md mode.")
    Signed-off-by: Peilin Ye <peilin.ye@bytedance.com>
    Acked-by: William Tu <u9012063@gmail.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 5ee141749454232ba96539a486733e75b0244d91
Author: Peilin Ye <peilin.ye@bytedance.com>
Date:   Thu Apr 21 15:08:38 2022 -0700

    ip6_gre: Make o_seqno start from 0 in native mode
    
    [ Upstream commit fde98ae91f79cab4e020f40c35ed23cbdc59661c ]
    
    For IP6GRE and IP6GRETAP devices, currently o_seqno starts from 1 in
    native mode.  According to RFC 2890 2.2., "The first datagram is sent
    with a sequence number of 0."  Fix it.
    
    It is worth mentioning that o_seqno already starts from 0 in collect_md
    mode, see the "if (tunnel->parms.collect_md)" clause in __gre6_xmit(),
    where tunnel->o_seqno is passed to gre_build_header() before getting
    incremented.
    
    Fixes: c12b395a4664 ("gre: Support GRE over IPv6")
    Signed-off-by: Peilin Ye <peilin.ye@bytedance.com>
    Acked-by: William Tu <u9012063@gmail.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 5ad8f5906a1580c095eebee4fcca244cf533f6f5
Author: Peilin Ye <peilin.ye@bytedance.com>
Date:   Thu Apr 21 15:07:57 2022 -0700

    ip_gre: Make o_seqno start from 0 in native mode
    
    [ Upstream commit ff827beb706ed719c766acf36449801ded0c17fc ]
    
    For GRE and GRETAP devices, currently o_seqno starts from 1 in native
    mode.  According to RFC 2890 2.2., "The first datagram is sent with a
    sequence number of 0."  Fix it.
    
    It is worth mentioning that o_seqno already starts from 0 in collect_md
    mode, see gre_fb_xmit(), where tunnel->o_seqno is passed to
    gre_build_header() before getting incremented.
    
    Fixes: 1da177e4c3f4 ("Linux-2.6.12-rc2")
    Signed-off-by: Peilin Ye <peilin.ye@bytedance.com>
    Acked-by: William Tu <u9012063@gmail.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit e6ca00c9306602c3029ef2e45376b49ec8a54703
Author: Dan Carpenter <dan.carpenter@oracle.com>
Date:   Thu Apr 21 18:46:13 2022 +0300

    net: lan966x: fix a couple off by one bugs
    
    [ Upstream commit 9810c58c7051ae83e7ac326fca3daa823da6b778 ]
    
    The lan966x->ports[] array has lan966x->num_phys_ports elements.  These
    are assigned in lan966x_probe().  That means the > comparison should be
    changed to >=.
    
    The first off by one check is harmless but the second one could lead to
    an out of bounds access and a crash.
    
    Fixes: 5ccd66e01cbe ("net: lan966x: add support for interrupts from analyzer")
    Signed-off-by: Dan Carpenter <dan.carpenter@oracle.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a87ab47bff2da694fd9f73dcd6bf170e88e183f3
Author: liuyacan <liuyacan@corp.netease.com>
Date:   Thu Apr 21 17:40:27 2022 +0800

    net/smc: sync err code when tcp connection was refused
    
    [ Upstream commit 4e2e65e2e56c6ceb4ea1719360080c0af083229e ]
    
    In the current implementation, when TCP initiates a connection
    to an unavailable [ip,port], ECONNREFUSED will be stored in the
    TCP socket, but SMC will not. However, some apps (like curl) use
    getsockopt(,,SO_ERROR,,) to get the error information, which makes
    them miss the error message and behave strangely.
    
    Fixes: 50717a37db03 ("net/smc: nonblocking connect rework")
    Signed-off-by: liuyacan <liuyacan@corp.netease.com>
    Reviewed-by: Tony Lu <tonylu@linux.alibaba.com>
    Acked-by: Karsten Graul <kgraul@linux.ibm.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 168c9e4db90718933a6ef550814a15cd45096253
Author: Jian Shen <shenjian15@huawei.com>
Date:   Sun Apr 24 20:57:25 2022 +0800

    net: hns3: add return value for mailbox handling in PF
    
    [ Upstream commit c59d606296842409a6e5a4828235b0bd46b12bc4 ]
    
    Currently, there are some querying mailboxes sent from VF to PF,
    and VF will wait the PF's handling result. For mailbox
    HCLGE_MBX_GET_QID_IN_PF and HCLGE_MBX_GET_RSS_KEY, it may fail
    when the input parameter is invalid, but the prototype of their
    handler function is void. In this case, PF always return success
    to VF, which may cause the VF get incorrect result.
    
    Fixes it by adding return value for these function.
    
    Fixes: 63b1279d9905 ("net: hns3: check queue id range before using")
    Fixes: 532cfc0df1e4 ("net: hns3: add a check for index in hclge_get_rss_key()")
    Signed-off-by: Jian Shen <shenjian15@huawei.com>
    Signed-off-by: Guangbin Huang <huangguangbin2@huawei.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit aaae4c8bd7990e3de633e23d21b7def4e3e4bf5b
Author: Jian Shen <shenjian15@huawei.com>
Date:   Sun Apr 24 20:57:24 2022 +0800

    net: hns3: add validity check for message data length
    
    [ Upstream commit 7d413735cb18ff73aaba3457b16b08332e8d3cc4 ]
    
    Add validity check for message data length in function
    hclge_send_mbx_msg(), avoid unexpected overflow.
    
    Fixes: dde1a86e93ca ("net: hns3: Add mailbox support to PF driver")
    Signed-off-by: Jian Shen <shenjian15@huawei.com>
    Signed-off-by: Guangbin Huang <huangguangbin2@huawei.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit e47b622344c96d6daddfee8a2c29b48aa5e3d5c5
Author: Jie Wang <wangjie125@huawei.com>
Date:   Sun Apr 24 20:57:23 2022 +0800

    net: hns3: modify the return code of hclge_get_ring_chain_from_mbx
    
    [ Upstream commit 48009e9972974c52a5f649f761862dd67bce3d13 ]
    
    Currently, function hclge_get_ring_chain_from_mbx will return -ENOMEM if
    ring_num is bigger than HCLGE_MBX_MAX_RING_CHAIN_PARAM_NUM. It is better to
    return -EINVAL for the invalid parameter case.
    
    So this patch fixes it by return -EINVAL in this abnormal branch.
    
    Fixes: 5d02a58dae60 ("net: hns3: fix for buffer overflow smatch warning")
    Signed-off-by: Jie Wang <wangjie125@huawei.com>
    Signed-off-by: Guangbin Huang <huangguangbin2@huawei.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 63c6372415dfe721c5a0c8cf87ff2ef2e84bf7f5
Author: Peng Li <lipeng321@huawei.com>
Date:   Sun Apr 24 20:57:22 2022 +0800

    net: hns3: fix error log of tx/rx tqps stats
    
    [ Upstream commit 123521b6b260d901937d3fb598ab88d260c857a6 ]
    
    The comments in function hclge_comm_tqps_update_stats is not right,
    so fix it.
    
    Fixes: 287db5c40d15 ("net: hns3: create new set of common tqp stats APIs for PF and VF reuse")
    Signed-off-by: Peng Li <lipeng321@huawei.com>
    Signed-off-by: Guangbin Huang <huangguangbin2@huawei.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit de00296f5163d0679addd8cf362bf7dca903bd9f
Author: Jian Shen <shenjian15@huawei.com>
Date:   Sun Apr 24 20:57:20 2022 +0800

    net: hns3: clear inited state and stop client after failed to register netdev
    
    [ Upstream commit e98365afc1e94ea1609268866a44112b3572c58b ]
    
    If failed to register netdev, it needs to clear INITED state and stop
    client in case of cause problem when concurrency with uninitialized
    process of driver.
    
    Fixes: a289a7e5c1d4 ("net: hns3: put off calling register_netdev() until client initialize complete")
    Signed-off-by: Jian Shen <shenjian15@huawei.com>
    Signed-off-by: Guangbin Huang <huangguangbin2@huawei.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 3272a75ded87c2982bd681dc93c1654d689de867
Author: Xiaobing Luo <luoxiaobing0926@gmail.com>
Date:   Sat Apr 23 15:12:04 2022 +0000

    cpufreq: fix memory leak in sun50i_cpufreq_nvmem_probe
    
    [ Upstream commit 1aa24a8f3b5133dae4bc1e57427e345445f3e902 ]
    
    --------------------------------------------
    unreferenced object 0xffff000010742a00 (size 128):
      comm "swapper/0", pid 1, jiffies 4294902015 (age 1187.652s)
      hex dump (first 32 bytes):
        00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00  ................
        00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00  ................
      backtrace:
        [<00000000b4dfebaa>] __kmalloc+0x338/0x474
        [<00000000d6e716db>] sun50i_cpufreq_nvmem_probe+0xc4/0x36c
        [<000000007d6082a0>] platform_probe+0x98/0x11c
        [<00000000c990f549>] really_probe+0x234/0x5a0
        [<000000002d9fecc6>] __driver_probe_device+0x194/0x224
        [<00000000cf0b94fa>] driver_probe_device+0x64/0x13c
        [<00000000f238e4cf>] __device_attach_driver+0xf8/0x180
        [<000000006720e418>] bus_for_each_drv+0xf8/0x160
        [<00000000df4f14f6>] __device_attach+0x174/0x29c
        [<00000000782002fb>] device_initial_probe+0x20/0x30
        [<00000000c2681b06>] bus_probe_device+0xfc/0x110
        [<00000000964cf3bd>] device_add+0x5f0/0xcd0
        [<000000004b9264e3>] platform_device_add+0x198/0x390
        [<00000000fa82a9d0>] platform_device_register_full+0x178/0x210
        [<000000009a5daf13>] sun50i_cpufreq_init+0xf8/0x168
        [<000000000377cc7c>] do_one_initcall+0xe4/0x570
    --------------------------------------------
    
    if sun50i_cpufreq_get_efuse failed, then opp_tables leak.
    
    Fixes: f328584f7bff ("cpufreq: Add sun50i nvmem based CPU scaling driver")
    Signed-off-by: Xiaobing Luo <luoxiaobing0926@gmail.com>
    Reviewed-by: Samuel Holland <samuel@sholland.org>
    Signed-off-by: Viresh Kumar <viresh.kumar@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 5b04d08199d1a7ec10a1e71467de7490882b2e06
Author: Lv Ruyi <lv.ruyi@zte.com.cn>
Date:   Sun Apr 24 03:14:30 2022 +0000

    pinctrl: pistachio: fix use of irq_of_parse_and_map()
    
    [ Upstream commit 0c9843a74a85224a89daa81fa66891dae2f930e1 ]
    
    The irq_of_parse_and_map() function returns 0 on failure, and does not
    return an negative value.
    
    Fixes: cefc03e5995e ("pinctrl: Add Pistachio SoC pin control driver")
    Reported-by: Zeal Robot <zealci@zte.com.cn>
    Signed-off-by: Lv Ruyi <lv.ruyi@zte.com.cn>
    Link: https://lore.kernel.org/r/20220424031430.3170759-1-lv.ruyi@zte.com.cn
    Signed-off-by: Linus Walleij <linus.walleij@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit def72f80554dea5d0313a38367e370de3d031de1
Author: Fabio Estevam <festevam@denx.de>
Date:   Mon Apr 18 14:47:31 2022 -0300

    arm64: dts: imx8mn-ddr4-evk: Describe the 32.768 kHz PMIC clock
    
    [ Upstream commit 0310b5aa0656a94102344f1e9ae2892e342a665d ]
    
    The ROHM BD71847 PMIC has a 32.768 kHz clock.
    
    Describe the PMIC clock to fix the following boot errors:
    
    bd718xx-clk bd71847-clk.1.auto: No parent clk found
    bd718xx-clk: probe of bd71847-clk.1.auto failed with error -22
    
    Based on the same fix done for imx8mm-evk as per commit
    a6a355ede574 ("arm64: dts: imx8mm-evk: Add 32.768 kHz clock to PMIC")
    
    Fixes: 3e44dd09736d ("arm64: dts: imx8mn-ddr4-evk: Add rohm,bd71847 PMIC support")
    Signed-off-by: Fabio Estevam <festevam@denx.de>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit f5143c7acc61e14be47c46b2da67edc50d9e8de0
Author: Max Krummenacher <max.krummenacher@toradex.com>
Date:   Thu Apr 14 10:50:54 2022 +0200

    ARM: dts: imx6ull-colibri: fix vqmmc regulator
    
    [ Upstream commit 45974e4276a8d6653394f66666fc57d8ffa6de9a ]
    
    The correct spelling for the property is gpios. Otherwise, the regulator
    will neither reserve nor control any GPIOs. Thus, any SD/MMC card which
    can use UHS-I modes will fail.
    
    Fixes: c2e4987e0e02 ("ARM: dts: imx6ull: add Toradex Colibri iMX6ULL support")
    Signed-off-by: Max Krummenacher <max.krummenacher@toradex.com>
    Signed-off-by: Denys Drozdov <denys.drozdov@toradex.com>
    Signed-off-by: Marcel Ziswiler <marcel.ziswiler@toradex.com>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit e85587ed9e6ea287fb47792f5bed47f74716efd2
Author: Xin Long <lucien.xin@gmail.com>
Date:   Wed Apr 20 16:52:41 2022 -0400

    sctp: check asoc strreset_chunk in sctp_generate_reconf_event
    
    [ Upstream commit 165e3e17fe8fe6a8aab319bc6e631a2e23b9a857 ]
    
    A null pointer reference issue can be triggered when the response of a
    stream reconf request arrives after the timer is triggered, such as:
    
      send Incoming SSN Reset Request --->
      CPU0:
       reconf timer is triggered,
       go to the handler code before hold sk lock
                                <--- reply with Outgoing SSN Reset Request
      CPU1:
       process Outgoing SSN Reset Request,
       and set asoc->strreset_chunk to NULL
      CPU0:
       continue the handler code, hold sk lock,
       and try to hold asoc->strreset_chunk, crash!
    
    In Ying Xu's testing, the call trace is:
    
      [ ] BUG: kernel NULL pointer dereference, address: 0000000000000010
      [ ] RIP: 0010:sctp_chunk_hold+0xe/0x40 [sctp]
      [ ] Call Trace:
      [ ]  <IRQ>
      [ ]  sctp_sf_send_reconf+0x2c/0x100 [sctp]
      [ ]  sctp_do_sm+0xa4/0x220 [sctp]
      [ ]  sctp_generate_reconf_event+0xbd/0xe0 [sctp]
      [ ]  call_timer_fn+0x26/0x130
    
    This patch is to fix it by returning from the timer handler if asoc
    strreset_chunk is already set to NULL.
    
    Fixes: 7b9438de0cd4 ("sctp: add stream reconf timer")
    Reported-by: Ying Xu <yinxu@redhat.com>
    Signed-off-by: Xin Long <lucien.xin@gmail.com>
    Acked-by: Marcelo Ricardo Leitner <marcelo.leitner@gmail.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a2de4c2b2bbae5b13a4a40e33d31dcd3b7f4e344
Author: Nikolay Aleksandrov <razor@blackwall.org>
Date:   Thu Apr 21 15:48:05 2022 +0200

    wireguard: device: check for metadata_dst with skb_valid_dst()
    
    [ Upstream commit 45ac774c33d834fe9d4de06ab5f1022fe8cd2071 ]
    
    When we try to transmit an skb with md_dst attached through wireguard
    we hit a null pointer dereference in wg_xmit() due to the use of
    dst_mtu() which calls into dst_blackhole_mtu() which in turn tries to
    dereference dst->dev.
    
    Since wireguard doesn't use md_dsts we should use skb_valid_dst(), which
    checks for DST_METADATA flag, and if it's set, then falls back to
    wireguard's device mtu. That gives us the best chance of transmitting
    the packet; otherwise if the blackhole netdev is used we'd get
    ETH_MIN_MTU.
    
     [  263.693506] BUG: kernel NULL pointer dereference, address: 00000000000000e0
     [  263.693908] #PF: supervisor read access in kernel mode
     [  263.694174] #PF: error_code(0x0000) - not-present page
     [  263.694424] PGD 0 P4D 0
     [  263.694653] Oops: 0000 [#1] PREEMPT SMP NOPTI
     [  263.694876] CPU: 5 PID: 951 Comm: mausezahn Kdump: loaded Not tainted 5.18.0-rc1+ #522
     [  263.695190] Hardware name: QEMU Standard PC (i440FX + PIIX, 1996), BIOS 1.15.0-1.fc35 04/01/2014
     [  263.695529] RIP: 0010:dst_blackhole_mtu+0x17/0x20
     [  263.695770] Code: 00 00 00 0f 1f 44 00 00 c3 66 2e 0f 1f 84 00 00 00 00 00 0f 1f 44 00 00 48 8b 47 10 48 83 e0 fc 8b 40 04 85 c0 75 09 48 8b 07 <8b> 80 e0 00 00 00 c3 66 90 0f 1f 44 00 00 48 89 d7 be 01 00 00 00
     [  263.696339] RSP: 0018:ffffa4a4422fbb28 EFLAGS: 00010246
     [  263.696600] RAX: 0000000000000000 RBX: ffff8ac9c3553000 RCX: 0000000000000000
     [  263.696891] RDX: 0000000000000401 RSI: 00000000fffffe01 RDI: ffffc4a43fb48900
     [  263.697178] RBP: ffffa4a4422fbb90 R08: ffffffff9622635e R09: 0000000000000002
     [  263.697469] R10: ffffffff9b69a6c0 R11: ffffa4a4422fbd0c R12: ffff8ac9d18b1a00
     [  263.697766] R13: ffff8ac9d0ce1840 R14: ffff8ac9d18b1a00 R15: ffff8ac9c3553000
     [  263.698054] FS:  00007f3704c337c0(0000) GS:ffff8acaebf40000(0000) knlGS:0000000000000000
     [  263.698470] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
     [  263.698826] CR2: 00000000000000e0 CR3: 0000000117a5c000 CR4: 00000000000006e0
     [  263.699214] Call Trace:
     [  263.699505]  <TASK>
     [  263.699759]  wg_xmit+0x411/0x450
     [  263.700059]  ? bpf_skb_set_tunnel_key+0x46/0x2d0
     [   263.700382]  ? dev_queue_xmit_nit+0x31/0x2b0
     [  263.700719]  dev_hard_start_xmit+0xd9/0x220
     [  263.701047]  __dev_queue_xmit+0x8b9/0xd30
     [  263.701344]  __bpf_redirect+0x1a4/0x380
     [  263.701664]  __dev_queue_xmit+0x83b/0xd30
     [  263.701961]  ? packet_parse_headers+0xb4/0xf0
     [  263.702275]  packet_sendmsg+0x9a8/0x16a0
     [  263.702596]  ? _raw_spin_unlock_irqrestore+0x23/0x40
     [  263.702933]  sock_sendmsg+0x5e/0x60
     [  263.703239]  __sys_sendto+0xf0/0x160
     [  263.703549]  __x64_sys_sendto+0x20/0x30
     [  263.703853]  do_syscall_64+0x3b/0x90
     [  263.704162]  entry_SYSCALL_64_after_hwframe+0x44/0xae
     [  263.704494] RIP: 0033:0x7f3704d50506
     [  263.704789] Code: 48 c7 c0 ff ff ff ff eb b7 66 2e 0f 1f 84 00 00 00 00 00 90 41 89 ca 64 8b 04 25 18 00 00 00 85 c0 75 11 b8 2c 00 00 00 0f 05 <48> 3d 00 f0 ff ff 77 72 c3 90 55 48 83 ec 30 44 89 4c 24 2c 4c 89
     [  263.705652] RSP: 002b:00007ffe954b0b88 EFLAGS: 00000246 ORIG_RAX: 000000000000002c
     [  263.706141] RAX: ffffffffffffffda RBX: 0000558bb259b490 RCX: 00007f3704d50506
     [  263.706544] RDX: 000000000000004a RSI: 0000558bb259b7b2 RDI: 0000000000000003
     [  263.706952] RBP: 0000000000000000 R08: 00007ffe954b0b90 R09: 0000000000000014
     [  263.707339] R10: 0000000000000000 R11: 0000000000000246 R12: 00007ffe954b0b90
     [  263.707735] R13: 000000000000004a R14: 0000558bb259b7b2 R15: 0000000000000001
     [  263.708132]  </TASK>
     [  263.708398] Modules linked in: bridge netconsole bonding [last unloaded: bridge]
     [  263.708942] CR2: 00000000000000e0
    
    Fixes: e7096c131e51 ("net: WireGuard secure network tunnel")
    Link: https://github.com/cilium/cilium/issues/19428
    Reported-by: Martynas Pumputis <m@lambda.lt>
    Signed-off-by: Nikolay Aleksandrov <razor@blackwall.org>
    Acked-by: Daniel Borkmann <daniel@iogearbox.net>
    Signed-off-by: Jason A. Donenfeld <Jason@zx2c4.com>
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 227621b4aa372a6a6745b41fdcb9e81244b921f3
Author: Pengcheng Yang <yangpc@wangsu.com>
Date:   Wed Apr 20 10:34:41 2022 +0800

    tcp: ensure to use the most recently sent skb when filling the rate sample
    
    [ Upstream commit b253a0680ceadc5d7b4acca7aa2d870326cad8ad ]
    
    If an ACK (s)acks multiple skbs, we favor the information
    from the most recently sent skb by choosing the skb with
    the highest prior_delivered count. But in the interval
    between receiving ACKs, we send multiple skbs with the same
    prior_delivered, because the tp->delivered only changes
    when we receive an ACK.
    
    We used RACK's solution, copying tcp_rack_sent_after() as
    tcp_skb_sent_after() helper to determine "which packet was
    sent last?". Later, we will use tcp_skb_sent_after() instead
    in RACK.
    
    Fixes: b9f64820fb22 ("tcp: track data delivery rate for a TCP connection")
    Signed-off-by: Pengcheng Yang <yangpc@wangsu.com>
    Cc: Paolo Abeni <pabeni@redhat.com>
    Acked-by: Neal Cardwell <ncardwell@google.com>
    Tested-by: Neal Cardwell <ncardwell@google.com>
    Reviewed-by: Eric Dumazet <edumazet@google.com>
    Link: https://lore.kernel.org/r/1650422081-22153-1-git-send-email-yangpc@wangsu.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 6ab6bf31432f38dfd13da0ac3528e4a4be2cf28c
Author: Marek Vasut <marex@denx.de>
Date:   Thu Apr 21 16:08:27 2022 +0200

    pinctrl: stm32: Keep pinctrl block clock enabled when LEVEL IRQ requested
    
    [ Upstream commit 05d8af449d93e04547b4c6b328e39c890bc803f4 ]
    
    The current EOI handler for LEVEL triggered interrupts calls clk_enable(),
    register IO, clk_disable(). The clock manipulation requires locking which
    happens with IRQs disabled in clk_enable_lock(). Instead of turning the
    clock on and off all the time, enable the clock in case LEVEL interrupt is
    requested and keep the clock enabled until all LEVEL interrupts are freed.
    The LEVEL interrupts are an exception on this platform and seldom used, so
    this does not affect the common case.
    
    This simplifies the LEVEL interrupt handling considerably and also fixes
    the following splat found when using preempt-rt:
     ------------[ cut here ]------------
     WARNING: CPU: 0 PID: 0 at kernel/locking/rtmutex.c:2040 __rt_mutex_trylock+0x37/0x62
     Modules linked in:
     CPU: 0 PID: 0 Comm: swapper/0 Not tainted 5.10.109-rt65-stable-standard-00068-g6a5afc4b1217 #85
     Hardware name: STM32 (Device Tree Support)
     [<c010a45d>] (unwind_backtrace) from [<c010766f>] (show_stack+0xb/0xc)
     [<c010766f>] (show_stack) from [<c06353ab>] (dump_stack+0x6f/0x84)
     [<c06353ab>] (dump_stack) from [<c01145e3>] (__warn+0x7f/0xa4)
     [<c01145e3>] (__warn) from [<c063386f>] (warn_slowpath_fmt+0x3b/0x74)
     [<c063386f>] (warn_slowpath_fmt) from [<c063b43d>] (__rt_mutex_trylock+0x37/0x62)
     [<c063b43d>] (__rt_mutex_trylock) from [<c063c053>] (rt_spin_trylock+0x7/0x16)
     [<c063c053>] (rt_spin_trylock) from [<c036a2f3>] (clk_enable_lock+0xb/0x80)
     [<c036a2f3>] (clk_enable_lock) from [<c036ba69>] (clk_core_enable_lock+0x9/0x18)
     [<c036ba69>] (clk_core_enable_lock) from [<c034e9f3>] (stm32_gpio_get+0x11/0x24)
     [<c034e9f3>] (stm32_gpio_get) from [<c034ef43>] (stm32_gpio_irq_trigger+0x1f/0x48)
     [<c034ef43>] (stm32_gpio_irq_trigger) from [<c014aa53>] (handle_fasteoi_irq+0x71/0xa8)
     [<c014aa53>] (handle_fasteoi_irq) from [<c0147111>] (generic_handle_irq+0x19/0x22)
     [<c0147111>] (generic_handle_irq) from [<c014752d>] (__handle_domain_irq+0x55/0x64)
     [<c014752d>] (__handle_domain_irq) from [<c0346f13>] (gic_handle_irq+0x53/0x64)
     [<c0346f13>] (gic_handle_irq) from [<c0100ba5>] (__irq_svc+0x65/0xc0)
     Exception stack(0xc0e01f18 to 0xc0e01f60)
     1f00:                                                       0000300c 00000000
     1f20: 0000300c c010ff01 00000000 00000000 c0e00000 c0e07714 00000001 c0e01f78
     1f40: c0e07758 00000000 ef7cd0ff c0e01f68 c010554b c0105542 40000033 ffffffff
     [<c0100ba5>] (__irq_svc) from [<c0105542>] (arch_cpu_idle+0xc/0x1e)
     [<c0105542>] (arch_cpu_idle) from [<c063be95>] (default_idle_call+0x21/0x3c)
     [<c063be95>] (default_idle_call) from [<c01324f7>] (do_idle+0xe3/0x1e4)
     [<c01324f7>] (do_idle) from [<c01327b3>] (cpu_startup_entry+0x13/0x14)
     [<c01327b3>] (cpu_startup_entry) from [<c0a00c13>] (start_kernel+0x397/0x3d4)
     [<c0a00c13>] (start_kernel) from [<00000000>] (0x0)
     ---[ end trace 0000000000000002 ]---
    
    Power consumption measured on STM32MP157C DHCOM SoM is not increased or
    is below noise threshold.
    
    Fixes: 47beed513a85b ("pinctrl: stm32: Add level interrupt support to gpio irq chip")
    Signed-off-by: Marek Vasut <marex@denx.de>
    Cc: Alexandre Torgue <alexandre.torgue@foss.st.com>
    Cc: Fabien Dessenne <fabien.dessenne@foss.st.com>
    Cc: Linus Walleij <linus.walleij@linaro.org>
    Cc: Marc Zyngier <maz@kernel.org>
    Cc: linux-stm32@st-md-mailman.stormreply.com
    Cc: linux-arm-kernel@lists.infradead.org
    To: linux-gpio@vger.kernel.org
    Reviewed-by: Fabien Dessenne <fabien.dessenne@foss.st.com>
    Link: https://lore.kernel.org/r/20220421140827.214088-1-marex@denx.de
    Signed-off-by: Linus Walleij <linus.walleij@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 87e91494cc2089bb092f3f7ff17c2b4699dbc4fb
Author: Francesco Ruggeri <fruggeri@arista.com>
Date:   Wed Apr 20 17:50:26 2022 -0700

    tcp: md5: incorrect tcp_header_len for incoming connections
    
    [ Upstream commit 5b0b9e4c2c895227c8852488b3f09839233bba54 ]
    
    In tcp_create_openreq_child we adjust tcp_header_len for md5 using the
    remote address in newsk. But that address is still 0 in newsk at this
    point, and it is only set later by the callers (tcp_v[46]_syn_recv_sock).
    Use the address from the request socket instead.
    
    Fixes: cfb6eeb4c860 ("[TCP]: MD5 Signature Option (RFC2385) support.")
    Signed-off-by: Francesco Ruggeri <fruggeri@arista.com>
    Reviewed-by: Eric Dumazet <edumazet@google.com>
    Link: https://lore.kernel.org/r/20220421005026.686A45EC01F2@us226.sjc.aristanetworks.com
    Signed-off-by: Jakub Kicinski <kuba@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit b7ee26d8ed8bc193169304b7c3af34e6dfe4c9fa
Author: Luca Ceresoli <luca.ceresoli@bootlin.com>
Date:   Wed Apr 20 16:24:31 2022 +0200

    pinctrl: rockchip: fix RK3308 pinmux bits
    
    [ Upstream commit 1f3e25a068832f8892a5ff71467622d012f5bc9f ]
    
    Some of the pinmuxing bits described in rk3308_mux_recalced_data are wrong,
    pointing to non-existing registers.
    
    Fix the entire table.
    
    Also add a comment in front of each entry with the same string that appears
    in the datasheet to make the table easier to compare with the docs.
    
    This fix has been tested on real hardware for the gpio3b3_sel entry.
    
    Fixes: 7825aeb7b208 ("pinctrl: rockchip: add rk3308 SoC support")
    Signed-off-by: Luca Ceresoli <luca.ceresoli@bootlin.com>
    Reviewed-by: Heiko Stuebner <heiko@sntech.de>
    Link: https://lore.kernel.org/r/20220420142432.248565-1-luca.ceresoli@bootlin.com
    Signed-off-by: Linus Walleij <linus.walleij@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 13360ad7a9282bc31939935ac2f50178d2795ec8
Author: Eyal Birger <eyal.birger@gmail.com>
Date:   Wed Apr 20 19:52:19 2022 +0300

    bpf, lwt: Fix crash when using bpf_skb_set_tunnel_key() from bpf_xmit lwt hook
    
    [ Upstream commit b02d196c44ead1a5949729be9ff08fe781c3e48a ]
    
    xmit_check_hhlen() observes the dst for getting the device hard header
    length to make sure a modified packet can fit. When a helper which changes
    the dst - such as bpf_skb_set_tunnel_key() - is called as part of the
    xmit program the accessed dst is no longer valid.
    
    This leads to the following splat:
    
     BUG: kernel NULL pointer dereference, address: 00000000000000de
     #PF: supervisor read access in kernel mode
     #PF: error_code(0x0000) - not-present page
     PGD 0 P4D 0
     Oops: 0000 [#1] PREEMPT SMP PTI
     CPU: 0 PID: 798 Comm: ping Not tainted 5.18.0-rc2+ #103
     Hardware name: QEMU Standard PC (i440FX + PIIX, 1996), BIOS 1.14.0-2 04/01/2014
     RIP: 0010:bpf_xmit+0xfb/0x17f
     Code: c6 c0 4d cd 8e 48 c7 c7 7d 33 f0 8e e8 42 09 fb ff 48 8b 45 58 48 8b 95 c8 00 00 00 48 2b 95 c0 00 00 00 48 83 e0 fe 48 8b 00 <0f> b7 80 de 00 00 00 39 c2 73 22 29 d0 b9 20 0a 00 00 31 d2 48 89
     RSP: 0018:ffffb148c0bc7b98 EFLAGS: 00010282
     RAX: 0000000000000000 RBX: 0000000000240008 RCX: 0000000000000000
     RDX: 0000000000000010 RSI: 00000000ffffffea RDI: 00000000ffffffff
     RBP: ffff922a828a4e00 R08: ffffffff8f1350e8 R09: 00000000ffffdfff
     R10: ffffffff8f055100 R11: ffffffff8f105100 R12: 0000000000000000
     R13: ffff922a828a4e00 R14: 0000000000000040 R15: 0000000000000000
     FS:  00007f414e8f0080(0000) GS:ffff922afdc00000(0000) knlGS:0000000000000000
     CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
     CR2: 00000000000000de CR3: 0000000002d80006 CR4: 0000000000370ef0
     Call Trace:
      <TASK>
      lwtunnel_xmit.cold+0x71/0xc8
      ip_finish_output2+0x279/0x520
      ? __ip_finish_output.part.0+0x21/0x130
    
    Fix by fetching the device hard header length before running the BPF code.
    
    Fixes: 3a0af8fd61f9 ("bpf: BPF for lightweight tunnel infrastructure")
    Signed-off-by: Eyal Birger <eyal.birger@gmail.com>
    Signed-off-by: Daniel Borkmann <daniel@iogearbox.net>
    Link: https://lore.kernel.org/bpf/20220420165219.1755407-1-eyal.birger@gmail.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 0a449195f143acb0ec7472692047f854d2fcd7f6
Author: Pablo Neira Ayuso <pablo@netfilter.org>
Date:   Mon Apr 18 12:21:05 2022 +0200

    netfilter: nft_set_rbtree: overlap detection with element re-addition after deletion
    
    [ Upstream commit babc3dc9524f0bcb5a0ec61f3c3639b11508fad6 ]
    
    This patch fixes spurious EEXIST errors.
    
    Extend d2df92e98a34 ("netfilter: nft_set_rbtree: handle element
    re-addition after deletion") to deal with elements with same end flags
    in the same transation.
    
    Reset the overlap flag as described by 7c84d41416d8 ("netfilter:
    nft_set_rbtree: Detect partial overlaps on insertion").
    
    Fixes: 7c84d41416d8 ("netfilter: nft_set_rbtree: Detect partial overlaps on insertion")
    Fixes: d2df92e98a34 ("netfilter: nft_set_rbtree: handle element re-addition after deletion")
    Signed-off-by: Pablo Neira Ayuso <pablo@netfilter.org>
    Reviewed-by: Stefano Brivio <sbrivio@redhat.com>
    Signed-off-by: Pablo Neira Ayuso <pablo@netfilter.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit c4b929f233832b3835c214455ef990686126651a
Author: Miaoqian Lin <linmq006@gmail.com>
Date:   Wed Apr 20 19:04:08 2022 +0800

    net: dsa: Add missing of_node_put() in dsa_port_link_register_of
    
    [ Upstream commit fc06b2867f4cea543505acfb194c2be4ebf0c7d3 ]
    
    The device_node pointer is returned by of_parse_phandle()  with refcount
    incremented. We should use of_node_put() on it when done.
    of_node_put() will check for NULL value.
    
    Fixes: a20f997010c4 ("net: dsa: Don't instantiate phylink for CPU/DSA ports unless needed")
    Signed-off-by: Miaoqian Lin <linmq006@gmail.com>
    Signed-off-by: David S. Miller <davem@davemloft.net>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 76ef3220d29185fc9cbc396a6d26538cd69de932
Author: Geert Uytterhoeven <geert+renesas@glider.be>
Date:   Wed Apr 20 09:05:26 2022 +0200

    memory: renesas-rpc-if: Fix HF/OSPI data transfer in Manual Mode
    
    [ Upstream commit 7e842d70fe599bc13594b650b2144c4b6e6d6bf1 ]
    
    HyperFlash devices fail to probe:
    
        rpc-if-hyperflash rpc-if-hyperflash: probing of hyperbus device failed
    
    In HyperFlash or Octal-SPI Flash mode, the Transfer Data Enable bits
    (SPIDE) in the Manual Mode Enable Setting Register (SMENR) are derived
    from half of the transfer size, cfr. the rpcif_bits_set() helper
    function.  However, rpcif_reg_{read,write}() does not take the bus size
    into account, and does not double all Manual Mode Data Register access
    sizes when communicating with a HyperFlash or Octal-SPI Flash device.
    
    Fix this, and avoid the back-and-forth conversion between transfer size
    and Transfer Data Enable bits, by explicitly storing the transfer size
    in struct rpcif, and using that value to determine access size in
    rpcif_reg_{read,write}().
    
    Enforce that the "high" Manual Mode Read/Write Data Registers
    (SM[RW]DR1) are only used for 8-byte data accesses.
    While at it, forbid writing to the Manual Mode Read Data Registers,
    as they are read-only.
    
    Fixes: fff53a551db50f5e ("memory: renesas-rpc-if: Correct QSPI data transfer in Manual mode")
    Signed-off-by: Geert Uytterhoeven <geert+renesas@glider.be>
    Signed-off-by: Krzysztof Kozlowski <krzysztof.kozlowski@linaro.org>
    Tested-by: Lad Prabhakar <prabhakar.mahadev-lad.rj@bp.renesas.com>
    Tested-by: Wolfram Sang <wsa+renesas@sang-engineering.com>
    Reviewed-by: Wolfram Sang <wsa+renesas@sang-engineering.com>
    Link: https://lore.kernel.org/r/cde9bfacf704c81865f57b15d1b48a4793da4286.1649681476.git.geert+renesas@glider.be
    Link: https://lore.kernel.org/r/20220420070526.9367-1-krzysztof.kozlowski@linaro.org'
    Signed-off-by: Arnd Bergmann <arnd@arndb.de>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a561b88c1c685574e05fc8057e56ab151ab51a68
Author: Marek Vasut <marex@denx.de>
Date:   Fri Apr 15 23:54:10 2022 +0200

    pinctrl: stm32: Do not call stm32_gpio_get() for edge triggered IRQs in EOI
    
    [ Upstream commit e74200ebf7c4f6a7a7d1be9f63833ddba251effa ]
    
    The stm32_gpio_get() should only be called for LEVEL triggered interrupts,
    skip calling it for EDGE triggered interrupts altogether to avoid wasting
    CPU cycles in EOI handler. On this platform, EDGE triggered interrupts are
    the majority and LEVEL triggered interrupts are the exception no less, and
    the CPU cycles are not abundant.
    
    Fixes: 47beed513a85b ("pinctrl: stm32: Add level interrupt support to gpio irq chip")
    Signed-off-by: Marek Vasut <marex@denx.de>
    Cc: Alexandre Torgue <alexandre.torgue@foss.st.com>
    Cc: Fabien Dessenne <fabien.dessenne@foss.st.com>
    Cc: Linus Walleij <linus.walleij@linaro.org>
    Cc: Marc Zyngier <maz@kernel.org>
    Cc: linux-stm32@st-md-mailman.stormreply.com
    Cc: linux-arm-kernel@lists.infradead.org
    To: linux-gpio@vger.kernel.org
    Link: https://lore.kernel.org/r/20220415215410.498349-1-marex@denx.de
    Signed-off-by: Linus Walleij <linus.walleij@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 807ee1a8dead55396430cd1af3716d30cc15f549
Author: Oleksandr Ocheretnyi <oocheret@cisco.com>
Date:   Sun Apr 17 11:46:47 2022 -0700

    mtd: fix 'part' field data corruption in mtd_info
    
    [ Upstream commit 37c5f9e80e015d0df17d0c377c18523002986851 ]
    
    Commit 46b5889cc2c5 ("mtd: implement proper partition handling")
    started using "mtd_get_master_ofs()" in mtd callbacks to determine
    memory offsets by means of 'part' field from mtd_info, what previously
    was smashed accessing 'master' field in the mtd_set_dev_defaults() method.
    That provides wrong offset what causes hardware access errors.
    
    Just make 'part', 'master' as separate fields, rather than using
    union type to avoid 'part' data corruption when mtd_set_dev_defaults()
    is called.
    
    Fixes: 46b5889cc2c5 ("mtd: implement proper partition handling")
    Signed-off-by: Oleksandr Ocheretnyi <oocheret@cisco.com>
    Signed-off-by: Miquel Raynal <miquel.raynal@bootlin.com>
    Link: https://lore.kernel.org/linux-mtd/20220417184649.449289-1-oocheret@cisco.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 663b1dfe056420035832d3ec109dd20271a6c506
Author: Miaoqian Lin <linmq006@gmail.com>
Date:   Tue Apr 12 08:34:31 2022 +0000

    mtd: rawnand: Fix return value check of wait_for_completion_timeout
    
    [ Upstream commit 084c16ab423a8890121b902b405823bfec5b4365 ]
    
    wait_for_completion_timeout() returns unsigned long not int.
    It returns 0 if timed out, and positive if completed.
    The check for <= 0 is ambiguous and should be == 0 here
    indicating timeout which is the only error case.
    
    Fixes: 83738d87e3a0 ("mtd: sh_flctl: Add DMA capabilty")
    Signed-off-by: Miaoqian Lin <linmq006@gmail.com>
    Signed-off-by: Miquel Raynal <miquel.raynal@bootlin.com>
    Link: https://lore.kernel.org/linux-mtd/20220412083435.29254-1-linmq006@gmail.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 436b712b6cd97ee974f3c18e7f55c2d90ba3dfdc
Author: YueHaibing <yuehaibing@huawei.com>
Date:   Sat Apr 9 18:59:58 2022 +0800

    pinctrl: mediatek: moore: Fix build error
    
    [ Upstream commit 87950929e2ff2236207bdbe14bff8230558b541b ]
    
    If EINT_MTK is m and PINCTRL_MTK_V2 is y, build fails:
    
    drivers/pinctrl/mediatek/pinctrl-moore.o: In function `mtk_gpio_set_config':
    pinctrl-moore.c:(.text+0xa6c): undefined reference to `mtk_eint_set_debounce'
    drivers/pinctrl/mediatek/pinctrl-moore.o: In function `mtk_gpio_to_irq':
    pinctrl-moore.c:(.text+0xacc): undefined reference to `mtk_eint_find_irq'
    
    Select EINT_MTK for PINCTRL_MTK_V2 to fix this.
    
    Fixes: 8174a8512e3e ("pinctrl: mediatek: make MediaTek pinctrl v2 driver ready for buidling loadable module")
    Signed-off-by: YueHaibing <yuehaibing@huawei.com>
    Link: https://lore.kernel.org/r/20220409105958.37412-1-yuehaibing@huawei.com
    Signed-off-by: Linus Walleij <linus.walleij@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 51428daf8579b786616120d12937bd68e4324ec4
Author: Heiner Kallweit <hkallweit1@gmail.com>
Date:   Fri Apr 15 16:03:10 2022 +0200

    phy: amlogic: fix error path in phy_g12a_usb3_pcie_probe()
    
    [ Upstream commit 2c8045d48dee703ad8eab2be7d6547765a89c069 ]
    
    If clk_prepare_enable() fails we call clk_disable_unprepare()
    in the error path what results in a warning that the clock
    is disabled and unprepared already.
    And if we fail later in phy_g12a_usb3_pcie_probe() then we
    bail out w/o calling clk_disable_unprepare().
    This patch fixes both errors.
    
    Fixes: 36077e16c050 ("phy: amlogic: Add Amlogic G12A USB3 + PCIE Combo PHY Driver")
    Signed-off-by: Heiner Kallweit <hkallweit1@gmail.com>
    Link: https://lore.kernel.org/r/8e416f95-1084-ee28-860e-7884f7fa2e32@gmail.com
    Signed-off-by: Vinod Koul <vkoul@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit b9ecd29a2543f93bec8463cc02194a8ac92857df
Author: Pengcheng Yang <yangpc@wangsu.com>
Date:   Tue Apr 12 19:05:45 2022 +0800

    ipvs: correctly print the memory size of ip_vs_conn_tab
    
    [ Upstream commit eba1a872cb73314280d5448d934935b23e30b7ca ]
    
    The memory size of ip_vs_conn_tab changed after we use hlist
    instead of list.
    
    Fixes: 731109e78415 ("ipvs: use hlist instead of list")
    Signed-off-by: Pengcheng Yang <yangpc@wangsu.com>
    Acked-by: Julian Anastasov <ja@ssi.bg>
    Acked-by: Simon Horman <horms@verge.net.au>
    Signed-off-by: Pablo Neira Ayuso <pablo@netfilter.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 06188662bc737cd7fafa72e7e139791578620abb
Author: Luca Weiss <luca.weiss@fairphone.com>
Date:   Fri Mar 18 19:30:02 2022 +0100

    pinctrl: qcom: sm6350: fix order of UFS & SDC pins
    
    [ Upstream commit ef0beba1a5fb0c693ddf7d31246bd96c925ffd00 ]
    
    In other places the SDC and UFS pins have been swapped but this was
    missed in the PINCTRL_PIN definitions. Fix that.
    
    Fixes: 7d74b55afd27 ("pinctrl: qcom: Add SM6350 pinctrl driver")
    Signed-off-by: Luca Weiss <luca.weiss@fairphone.com>
    Link: https://lore.kernel.org/r/20220318183004.858707-5-luca.weiss@fairphone.com
    Signed-off-by: Linus Walleij <linus.walleij@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit bf9643b7adbd0e5135e2d3367491edd6ff7496cd
Author: Adam Ford <aford173@gmail.com>
Date:   Thu Mar 3 11:18:17 2022 -0600

    ARM: dts: logicpd-som-lv: Fix wrong pinmuxing on OMAP35
    
    [ Upstream commit 46ff3df87215ff42c0cd2c4bdb7d74540384a69c ]
    
    The pinout of the OMAP35 and DM37 variants of the SOM-LV are the
    same, but the macros which define the pinmuxing are different
    between OMAP3530 and DM3730.  The pinmuxing was correct for
    for the DM3730, but wrong for the OMAP3530.  Since the boot loader
    was correctly pin-muxing the pins, this was not obvious. As the
    bootloader not guaranteed to pinmux all the pins any more, this
    causes an issue, so the pinmux needs to be moved from a common
    file to their respective board files.
    
    Fixes: f8a2e3ff7103 ("ARM: dts: Add minimal support for LogicPD OMAP35xx SOM-LV devkit")
    Signed-off-by: Adam Ford <aford173@gmail.com>
    Message-Id: <20220303171818.11060-1-aford173@gmail.com>
    Signed-off-by: Tony Lindgren <tony@atomide.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 95eb0712fdad24bfc0dc9dd3b002484871d6a51c
Author: Adam Ford <aford173@gmail.com>
Date:   Sat Feb 26 15:48:19 2022 -0600

    ARM: dts: am3517-evm: Fix misc pinmuxing
    
    [ Upstream commit 942da3af32b2288e674736eb159d1fc676261691 ]
    
    The bootloader for the AM3517 has previously done much of the pin
    muxing, but as the bootloader is moving more and more to a model
    based on the device tree, it may no longer automatically mux the
    pins, so it is necessary to add the pinmuxing to the Linux device
    trees so the respective peripherals can remain functional.
    
    Fixes: 6ed1d7997561 ("ARM: dts: am3517-evm: Add support for UI board and Audio")
    Signed-off-by: Adam Ford <aford173@gmail.com>
    Message-Id: <20220226214820.747847-1-aford173@gmail.com>
    Signed-off-by: Tony Lindgren <tony@atomide.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 3fafae378f928afe47ff911ed9193d6c2d35fcc5
Author: Miquel Raynal <miquel.raynal@bootlin.com>
Date:   Mon Mar 14 17:34:45 2022 +0100

    ARM: dts: am33xx-l4: Add missing touchscreen clock properties
    
    [ Upstream commit c21a7434d6cc216a910dd35632617850f1751f4c ]
    
    When adding support for TI magadc (Magnetic Stripe Reader and ADC), the
    MFD driver common to the touchscreen and the ADC got updated to ease the
    insertion of a new DT node for the ADC, with its own compatible, clocks,
    etc. Commit 235a96e92c16 ("mfd: ti_am335x_tscadc: Don't search the tree
    for our clock") removed one compatible specific information which was
    the clock name, because the clock was looked up from scratch in the DT
    while this hardware block was only fed by a single clock, already
    defined and properly filled in the DT.
    
    Problem is, this change was only validated with an am437x-based board,
    where the clocks are effectively correctly defined and referenced. But
    on am33xx, the ADC clock is also correctly defined but is not referenced
    with a clock phandle as it ought to be.
    
    The touchscreen bindings clearly state that the clocks/clock-names
    properties are mandatory, but they have been forgotten in one DTSI. This
    was probably not noticed in the first place because of the clock
    actually existing and the clk_get() call going through all the tree
    anyway.
    
    Add the missing clock phandles in the am33xx touchscreen description.
    
    Reported-by: H. Nikolaus Schaller <hns@goldelico.com>
    Fixes: 235a96e92c16 ("mfd: ti_am335x_tscadc: Don't search the tree for our clock")
    Signed-off-by: Miquel Raynal <miquel.raynal@bootlin.com>
    Tested-by: H. Nikolaus Schaller <hns@goldelico.com>
    Message-Id: <20220314163445.79807-1-miquel.raynal@bootlin.com>
    Signed-off-by: Tony Lindgren <tony@atomide.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit f284066c79696a04576818985b714d74caee48c1
Author: H. Nikolaus Schaller <hns@goldelico.com>
Date:   Tue Mar 8 14:00:20 2022 +0100

    ARM: dts: Fix mmc order for omap3-gta04
    
    [ Upstream commit 09269dd050094593fc747f2a5853d189fefcb6b5 ]
    
    Commit a1ebdb374199 ("ARM: dts: Fix swapped mmc order for omap3")
    introduces general mmc aliases. Let's tailor them to the need
    of the GTA04 board which does not make use of mmc2 and mmc3 interfaces.
    
    Fixes: a1ebdb374199 ("ARM: dts: Fix swapped mmc order for omap3")
    Signed-off-by: H. Nikolaus Schaller <hns@goldelico.com>
    Message-Id: <dc9173ee3d391d9e92b7ab8ed4f84b29f0a21c83.1646744420.git.hns@goldelico.com>
    Signed-off-by: Tony Lindgren <tony@atomide.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 8e95bc12bf7240497919428b97ccf240558d3c31
Author: Stephen Boyd <swboyd@chromium.org>
Date:   Tue Apr 12 15:00:33 2022 -0700

    interconnect: qcom: sdx55: Drop IP0 interconnects
    
    [ Upstream commit 2fb251c265608636fc961b7d38e1a03937e57371 ]
    
    Similar to the sc7180 commit, let's drop the IP0 interconnects here
    because the IP0 resource is also used in the clk-rpmh driver on sdx55.
    It's bad to have the clk framework and interconnect framework control
    the same RPMh resource without any coordination. The rpmh driver in the
    kernel doesn't aggregate resources between clients either, so leaving
    control to clk-rpmh avoids any issues with unused interconnects turning
    off IP0 behind the back of the clk framework.
    
    Cc: Alex Elder <elder@linaro.org>
    Cc: Manivannan Sadhasivam <manivannan.sadhasivam@linaro.org>
    Cc: Bjorn Andersson <bjorn.andersson@linaro.org>
    Cc: Taniya Das <quic_tdas@quicinc.com>
    Cc: Mike Tipton <quic_mdtipton@quicinc.com>
    Fixes: b2150cab9a97 ("clk: qcom: rpmh: add support for SDX55 rpmh IPA clock")
    Signed-off-by: Stephen Boyd <swboyd@chromium.org>
    Reviewed-by: Alex Elder <elder@linaro.org>
    Acked-by: Manivannan Sadhasivam <manivannan.sadhasivam@linaro.org>
    Reviewed-by: Bjorn Andersson <bjorn.andersson@linaro.org>
    Link: https://lore.kernel.org/r/20220412220033.1273607-3-swboyd@chromium.org
    Signed-off-by: Georgi Djakov <djakov@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 746bfae70e6ab8207ec975d51c2b7e8ae5825b82
Author: Stephen Boyd <swboyd@chromium.org>
Date:   Tue Apr 12 15:00:32 2022 -0700

    interconnect: qcom: sc7180: Drop IP0 interconnects
    
    [ Upstream commit 2f3724930eb4bba74f7d10bc3bef5bb22dd323df ]
    
    The IPA BCM resource ("IP0") on sc7180 was moved to the clk-rpmh driver
    in commit bcd63d222b60 ("clk: qcom: rpmh: Add IPA clock for SC7180") and
    modeled as a clk, but this interconnect driver still had it modeled as
    an interconnect. This was mostly OK because nobody used the interconnect
    definition, until the interconnect framework started dropping bandwidth
    requests on interconnects that aren't used via the sync_state callback
    in commit 7d3b0b0d8184 ("interconnect: qcom: Use icc_sync_state"). Once
    that patch was applied the IP0 resource was going to be controlled from
    two places, the clk framework and the interconnect framework.
    
    Even then, things were probably going to be OK, because commit
    b95b668eaaa2 ("interconnect: qcom: icc-rpmh: Add BCMs to commit list in
    pre_aggregate") was needed to actually drop bandwidth requests on unused
    interconnects, of which the IPA was one of the interconnect that wasn't
    getting dropped to zero. Combining the three commits together leads to
    bad behavior where the interconnect framework is disabling the IP0
    resource because it has no users while the clk framework thinks the IP0
    resource is on because the only user, the IPA driver, has turned it on
    via clk_prepare_enable(). Depending on when sync_state is called, we can
    get into a situation like below:
    
      IPA driver probes
      IPA driver gets notified modem started
       runtime PM get()
        IPA clk enabled -> IP0 resource is ON
      sync_state runs
       interconnect zeroes out the IP0 resource -> IP0 resource is off
      IPA driver tries to access a register and blows up
    
    The crash is an unclocked access that manifest as an SError.
    
     SError Interrupt on CPU0, code 0xbe000011 -- SError
     CPU: 0 PID: 3595 Comm: mmdata_mgr Not tainted 5.17.1+ #166
     Hardware name: Google Lazor (rev1 - 2) with LTE (DT)
     pstate: 60400009 (nZCv daif +PAN -UAO -TCO -DIT -SSBS BTYPE=--)
     pc : mutex_lock+0x4c/0x80
     lr : mutex_lock+0x30/0x80
     sp : ffffffc00da9b9c0
     x29: ffffffc00da9b9c0 x28: 0000000000000000 x27: 0000000000000000
     x26: ffffffc00da9bc90 x25: ffffff80c2024010 x24: ffffff80c2024000
     x23: ffffff8083100000 x22: ffffff80831000d0 x21: ffffff80831000a8
     x20: ffffff80831000a8 x19: ffffff8083100070 x18: 00000000ffff0a00
     x17: 000000002f7254f1 x16: 0000000000000100 x15: 0000000000000000
     x14: 0000000000000000 x13: 0000000000000000 x12: 0000000000000000
     x11: 000000000001f0b8 x10: ffffffc00931f0b8 x9 : 0000000000000000
     x8 : 0000000000000000 x7 : fefefefefeff2f60 x6 : 0000808080808080
     x5 : 0000000000000000 x4 : 8080808080800000 x3 : ffffff80d2d4ee28
     x2 : ffffff808c1d6e40 x1 : 0000000000000000 x0 : ffffff8083100070
     Kernel panic - not syncing: Asynchronous SError Interrupt
     CPU: 0 PID: 3595 Comm: mmdata_mgr Not tainted 5.17.1+ #166
     Hardware name: Google Lazor (rev1 - 2) with LTE (DT)
     Call trace:
      dump_backtrace+0xf4/0x114
      show_stack+0x24/0x30
      dump_stack_lvl+0x64/0x7c
      dump_stack+0x18/0x38
      panic+0x150/0x38c
      nmi_panic+0x88/0xa0
      arm64_serror_panic+0x74/0x80
      do_serror+0x0/0x80
      do_serror+0x58/0x80
      el1h_64_error_handler+0x34/0x4c
      el1h_64_error+0x78/0x7c
      mutex_lock+0x4c/0x80
      __gsi_channel_start+0x50/0x17c
      gsi_channel_start+0x54/0x90
      ipa_endpoint_enable_one+0x34/0xc0
      ipa_open+0x4c/0x120
    
    Remove all IP0 resource management from the interconnect driver so that
    clk-rpmh is the sole owner. This fixes the issue by preventing the
    interconnect driver from overwriting the IP0 resource data that the
    clk-rpmh driver wrote.
    
    Cc: Alex Elder <elder@linaro.org>
    Cc: Bjorn Andersson <bjorn.andersson@linaro.org>
    Cc: Taniya Das <quic_tdas@quicinc.com>
    Cc: Mike Tipton <quic_mdtipton@quicinc.com>
    Fixes: b95b668eaaa2 ("interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate")
    Fixes: bcd63d222b60 ("clk: qcom: rpmh: Add IPA clock for SC7180")
    Fixes: 7d3b0b0d8184 ("interconnect: qcom: Use icc_sync_state")
    Signed-off-by: Stephen Boyd <swboyd@chromium.org>
    Tested-by: Alex Elder <elder@linaro.org>
    Reviewed-by: Alex Elder <elder@linaro.org>
    Reviewed-by: Bjorn Andersson <bjorn.andersson@linaro.org>
    Link: https://lore.kernel.org/r/20220412220033.1273607-2-swboyd@chromium.org
    Signed-off-by: Georgi Djakov <djakov@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 24210a4f4e440878b596a2182369edb81c9acec3
Author: Miaoqian Lin <linmq006@gmail.com>
Date:   Tue Mar 1 02:58:49 2022 +0000

    phy: ti: Add missing pm_runtime_disable() in serdes_am654_probe
    
    [ Upstream commit ce88613e5bd579478653a028291098143f2a5bdf ]
    
    The pm_runtime_enable() will increase power disable depth.
    If the probe fails, we should use pm_runtime_disable() to balance
    pm_runtime_enable().
    Add missing pm_runtime_disable() for serdes_am654_probe().
    
    Fixes: 71e2f5c5c224 ("phy: ti: Add a new SERDES driver for TI's AM654x SoC")
    Signed-off-by: Miaoqian Lin <linmq006@gmail.com>
    Link: https://lore.kernel.org/r/20220301025853.1911-1-linmq006@gmail.com
    Signed-off-by: Vinod Koul <vkoul@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 92fb2971da4095fede0c4e01c00fb72a61a98950
Author: Miaoqian Lin <linmq006@gmail.com>
Date:   Tue Mar 1 02:46:11 2022 +0000

    phy: mapphone-mdm6600: Fix PM error handling in phy_mdm6600_probe
    
    [ Upstream commit d644e0d79829b1b9a14beedbdb0dc1256fc3677d ]
    
    The pm_runtime_enable will increase power disable depth.
    If the probe fails, we should use pm_runtime_disable() to balance
    pm_runtime_enable(). And use pm_runtime_dont_use_autosuspend() to
    undo pm_runtime_use_autosuspend()
    In the PM Runtime docs:
        Drivers in ->remove() callback should undo the runtime PM changes done
        in ->probe(). Usually this means calling pm_runtime_disable(),
        pm_runtime_dont_use_autosuspend() etc.
    
    We should do this in error handling.
    
    Fixes: f7f50b2a7b05 ("phy: mapphone-mdm6600: Add runtime PM support for n_gsm on USB suspend")
    Signed-off-by: Miaoqian Lin <linmq006@gmail.com>
    Link: https://lore.kernel.org/r/20220301024615.31899-1-linmq006@gmail.com
    Signed-off-by: Vinod Koul <vkoul@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit e448e0519b6525167f4f558ce705d8034ac04f41
Author: Claudiu Beznea <claudiu.beznea@microchip.com>
Date:   Thu Mar 31 17:13:23 2022 +0300

    ARM: dts: at91: fix pinctrl phandles
    
    [ Upstream commit 0c640d9544d0109da3889d71ae77301e556db977 ]
    
    Commit bf781869e5cf ("ARM: dts: at91: add pinctrl-{names, 0} for all
    gpios") introduces pinctrl phandles for pins used by individual
    controllers to avoid failures due to commit 2ab73c6d8323 ("gpio:
    Support GPIO controllers without pin-ranges"). For SPI controllers
    available on SAMA5D4 and SAMA5D3 some of the pins are defined in
    SoC specific dtsi on behalf of pinctrl-0. Adding extra pinctrl phandles
    on board specific dts also on behalf of pinctrl-0 overwrite the pinctrl-0
    phandle specified in SoC specific dtsi. Thus add the board specific
    pinctrl to pinctrl-1.
    
    Fixes: bf781869e5cf ("ARM: dts: at91: add pinctrl-{names, 0} for all gpios")
    Depends-on: 5c8b49852910 ("ARM: dts: at91: sama5d4_xplained: fix pinctrl phandle name")
    Reported-by: Ajay Kathat <ajay.kathat@microchip.com>
    Co-developed-by: Ajay Kathat <ajay.kathat@microchip.com>
    Signed-off-by: Ajay Kathat <ajay.kathat@microchip.com>
    Tested-by: Ajay Kathat <ajay.kathat@microchip.com>
    Signed-off-by: Claudiu Beznea <claudiu.beznea@microchip.com>
    Signed-off-by: Nicolas Ferre <nicolas.ferre@microchip.com>
    Link: https://lore.kernel.org/r/20220331141323.194355-2-claudiu.beznea@microchip.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 764d7e238bc54ed9914b4d63c1909cdbcb0be276
Author: Claudiu Beznea <claudiu.beznea@microchip.com>
Date:   Thu Mar 31 17:13:22 2022 +0300

    ARM: dts: at91: sama5d4_xplained: fix pinctrl phandle name
    
    [ Upstream commit 5c8b49852910caffeebb1ce541fdd264ffc691b8 ]
    
    Pinctrl phandle is for spi1 so rename it to reflect this.
    
    Signed-off-by: Claudiu Beznea <claudiu.beznea@microchip.com>
    Signed-off-by: Nicolas Ferre <nicolas.ferre@microchip.com>
    Link: https://lore.kernel.org/r/20220331141323.194355-1-claudiu.beznea@microchip.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 0fac0d14f5a06218938c470a1eccfb320e33b322
Author: Mark Brown <broonie@kernel.org>
Date:   Mon Apr 4 11:28:05 2022 +0100

    ARM: dts: at91: Map MCLK for wm8731 on at91sam9g20ek
    
    [ Upstream commit 0e486fe341fabd8e583f3d601a874cd394979c45 ]
    
    The MCLK of the WM8731 on the AT91SAM9G20-EK board is connected to the
    PCK0 output of the SoC and is expected to be set to 12MHz. Previously
    this was mapped using pre-common clock API calls in the audio machine
    driver but the conversion to the common clock framework broke that so
    describe things in the DT instead.
    
    Fixes: ff78a189b0ae55f ("ARM: at91: remove old at91-specific clock driver")
    Signed-off-by: Mark Brown <broonie@kernel.org>
    Reviewed-by: Claudiu Beznea <claudiu.beznea@microchip.com>
    Signed-off-by: Nicolas Ferre <nicolas.ferre@microchip.com>
    Link: https://lore.kernel.org/r/20220404102806.581374-2-broonie@kernel.org
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit b8e068aba833d37ed287a85cafcb2dd63b95d78b
Author: Miaoqian Lin <linmq006@gmail.com>
Date:   Fri Mar 18 10:57:46 2022 +0000

    phy: ti: omap-usb2: Fix error handling in omap_usb2_enable_clocks
    
    [ Upstream commit 3588060befff75ff39fab7122b94c6fb3148fcda ]
    
    The corresponding API for clk_prepare_enable is clk_disable_unprepare.
    Make sure that the clock is unprepared on exit by changing clk_disable
    to clk_disable_unprepare.
    
    Fixes: ed31ee7cf1fe ("phy: ti: usb2: Fix logic on -EPROBE_DEFER")
    Signed-off-by: Miaoqian Lin <linmq006@gmail.com>
    Link: https://lore.kernel.org/r/20220318105748.19532-1-linmq006@gmail.com
    Signed-off-by: Vinod Koul <vkoul@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 6eba3f285ee09222a8e260936ec1a9ea27a83f56
Author: Tony Lindgren <tony@atomide.com>
Date:   Tue Apr 12 12:26:51 2022 +0300

    ARM: dts: dra7: Fix suspend warning for vpe powerdomain
    
    [ Upstream commit 8d2453d9a307c2eafd21242dd73f35f05fb7ce74 ]
    
    We currently are getting the following warning after a system suspend:
    
    Powerdomain (vpe_pwrdm) didn't enter target state 0
    
    Looks like this is because the STANDBYMODE bit for SMART_IDLE should
    not be used. The TRM "Table 12-348. VPE_SYSCONFIG" says that the value
    for SMART_IDLE is "0x2: Same behavior as bit-field value of 0x1". But
    if the SMART_IDLE value is used, PM_VPE_PWRSTST LASTPOWERSTATEENTERED
    bits always show value of 3.
    
    Let's fix the issue by dropping SMART_IDLE for vpe. And let's also add
    the missing the powerdomain for vpe.
    
    Fixes: 1a2095160594 ("ARM: dts: dra7: Add ti-sysc node for VPE")
    Cc: Benoit Parrot <bparrot@ti.com>
    Reported-by: Kevin Hilman <khilman@baylibre.com>
    Reviewed-by: Kevin Hilman <khilman@baylibre.com>
    Tested-by: Kevin Hilman <khilman@baylibre.com>
    Signed-off-by: Tony Lindgren <tony@atomide.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 25bb9e3ea212f25287fb2943557006161bc864c0
Author: Tony Lindgren <tony@atomide.com>
Date:   Tue Apr 12 12:26:51 2022 +0300

    bus: ti-sysc: Make omap3 gpt12 quirk handling SoC specific
    
    [ Upstream commit a12315d6d27093392b6c634e1d35a59f1d1f7a59 ]
    
    On beagleboard revisions A to B4 we need to use gpt12 as the system timer.
    However, the quirk handling added for gpt12 caused a regression for system
    suspend for am335x as the PM coprocessor needs the timers idled for
    suspend.
    
    Let's make the gpt12 quirk specific to omap34xx, other SoCs don't need
    it. Beagleboard revisions C and later no longer need to use the gpt12
    related quirk. Then at some point, if we decide to drop support for the old
    beagleboard revisions A to B4, we can also drop the gpt12 related quirks
    completely.
    
    Fixes: 3ff340e24c9d ("bus: ti-sysc: Fix gpt12 system timer issue with reserved status")
    Reported-by: Kevin Hilman <khilman@baylibre.com>
    Suggested-by: Kevin Hilman <khilman@baylibre.com>
    Signed-off-by: Tony Lindgren <tony@atomide.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit b3401d401635bb2d1590cd79500a595e01c0ddcc
Author: Miaoqian Lin <linmq006@gmail.com>
Date:   Wed Mar 9 10:43:01 2022 +0000

    ARM: OMAP2+: Fix refcount leak in omap_gic_of_init
    
    [ Upstream commit 0f83e6b4161617014017a694888dd8743f46f071 ]
    
    The of_find_compatible_node() function returns a node pointer with
    refcount incremented, We should use of_node_put() on it when done
    Add the missing of_node_put() to release the refcount.
    
    Fixes: fd1c07861491 ("ARM: OMAP4: Fix the init code to have OMAP4460 errata available in DT build")
    Signed-off-by: Miaoqian Lin <linmq006@gmail.com>
    Message-Id: <20220309104302.18398-1-linmq006@gmail.com>
    Signed-off-by: Tony Lindgren <tony@atomide.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 294cc5226664bd311d341a00225dd7e94e5d8d5d
Author: Krzysztof Kozlowski <krzysztof.kozlowski@linaro.org>
Date:   Thu Apr 7 11:18:57 2022 +0200

    phy: samsung: exynos5250-sata: fix missing device put in probe error paths
    
    [ Upstream commit 5c8402c4db45dd55c2c93c8d730f5dfa7c78a702 ]
    
    The actions of of_find_i2c_device_by_node() in probe function should be
    reversed in error paths by putting the reference to obtained device.
    
    Fixes: bcff4cba41bc ("PHY: Exynos: Add Exynos5250 SATA PHY driver")
    Signed-off-by: Krzysztof Kozlowski <krzysztof.kozlowski@linaro.org>
    Reviewed-by: Alim Akhtar <alim.akhtar@samsung.com>
    Link: https://lore.kernel.org/r/20220407091857.230386-2-krzysztof.kozlowski@linaro.org
    Signed-off-by: Vinod Koul <vkoul@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 30345e94c8d8b0fa3117c13577225299f5947354
Author: Miaoqian Lin <linmq006@gmail.com>
Date:   Thu Apr 7 11:18:56 2022 +0200

    phy: samsung: Fix missing of_node_put() in exynos_sata_phy_probe
    
    [ Upstream commit 388ec8f079f2f20d5cd183c3bc6f33cbc3ffd3ef ]
    
    The device_node pointer is returned by of_parse_phandle() with refcount
    incremented. We should use of_node_put() on it when done.
    
    Fixes: bcff4cba41bc ("PHY: Exynos: Add Exynos5250 SATA PHY driver")
    Signed-off-by: Miaoqian Lin <linmq006@gmail.com>
    Reviewed-by: Krzysztof Kozlowski <krzysztof.kozlowski@linaro.org>
    Signed-off-by: Krzysztof Kozlowski <krzysztof.kozlowski@linaro.org>
    Link: https://lore.kernel.org/r/20220407091857.230386-1-krzysztof.kozlowski@linaro.org
    Signed-off-by: Vinod Koul <vkoul@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 73c9e9ade55097af2e47e401ca2b3271957c1304
Author: Guillaume Giraudon <ggiraudon@prism19.com>
Date:   Mon Apr 11 10:44:28 2022 -0400

    arm64: dts: meson-sm1-bananapi-m5: fix wrong GPIO pin labeling for CON1
    
    [ Upstream commit 962dd65e575dde950ef0844568edc37cfb39f302 ]
    
    The labels for lines 61 through 84 on the periphs-banks were offset by 2.
    2 lines are missing in the BOOT GPIO lines (contains 14, should be 16)
    Added 2 empty entries in BOOT to realigned the rest of GPIO labels
    to match the Banana Pi M5 schematics.
    
    (Thanks to Neil Armstrong for the heads up on the position of the missing pins)
    
    Fixes: 976e920183e4 ("arm64: dts: meson-sm1: add Banana PI BPI-M5 board dts")
    Signed-off-by: Guillaume Giraudon <ggiraudon@prism19.com>
    Reviewed-by: Neil Armstrong <narmstrong@baylibre.com>
    Signed-off-by: Neil Armstrong <narmstrong@baylibre.com>
    Link: https://lore.kernel.org/r/20220411144427.874-1-ggiraudon@prism19.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a573a3eac704029d1e5ca04559a929e753bee4ce
Author: Marek Vasut <marex@denx.de>
Date:   Mon Apr 4 01:42:05 2022 +0200

    arm64: dts: imx8mn: Fix SAI nodes
    
    [ Upstream commit 574518b7ccbaef74cb89eb1a1a0da88afa1e0113 ]
    
    The most specific compatible string element should be "fsl,imx8mn-sai"
    on i.MX8M Nano, fix it from current "fsl,imx8mm-sai" (two Ms, likely
    due to copy-paste error from i.MX8M Mini).
    
    Fixes: 9e9860069725f ("arm64: dts: imx8mn: Add SAI nodes")
    Signed-off-by: Marek Vasut <marex@denx.de>
    Cc: Adam Ford <aford173@gmail.com>
    Cc: Fabio Estevam <festevam@gmail.com>
    Cc: Peng Fan <peng.fan@nxp.com>
    Cc: Shawn Guo <shawnguo@kernel.org>
    Cc: NXP Linux Team <linux-imx@nxp.com>
    To: linux-arm-kernel@lists.infradead.org
    Reviewed-by: Adam Ford <aford173@gmail.com>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 800b4fa34383ded14dab7a725bb15111f11f041b
Author: Alexander Stein <alexander.stein@ew.tq-group.com>
Date:   Thu Mar 31 15:02:06 2022 +0200

    arm64: dts: imx8mq-tqma8mq: change the spi-nor tx
    
    [ Upstream commit c7b45c79fb279e539346919a5c196e417925719e ]
    
    This fixes the qspi read command by importing the changes from commit
    04aa946d57b2 ("arm64: dts: imx8: change the spi-nor tx").
    
    Fixes: b186b8b6e770 ("arm64: dts: freescale: add initial device tree for TQMa8Mx with i.MX8M")
    Signed-off-by: Alexander Stein <alexander.stein@ew.tq-group.com>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit a845674644a107a0bff2f036d97c21cacaa36fd7
Author: Dan Carpenter <dan.carpenter@oracle.com>
Date:   Mon Apr 4 14:42:44 2022 +0300

    iio:dac:ad3552r: Fix an IS_ERR() vs NULL check
    
    [ Upstream commit de3b9fe9609a05d3c354c6718ca657962d11d9fe ]
    
    The fwnode_get_named_child_node() function does not return error
    pointers.  It returns NULL.  Update the check accordingly.
    
    Fixes: 8f2b54824b28 ("drivers:iio:dac: Add AD3552R driver support")
    Signed-off-by: Dan Carpenter <dan.carpenter@oracle.com>
    Reviewed-by: Nuno Sá <nuno.sa@analog.com>
    Link: https://lore.kernel.org/r/20220404114244.GA19201@kili
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 80e98fabd0e2303a3875db78f132b36f3e55f52a
Author: Fabio Estevam <festevam@gmail.com>
Date:   Sat Mar 26 12:14:55 2022 -0300

    ARM: dts: imx6qdl-apalis: Fix sgtl5000 detection issue
    
    [ Upstream commit fa51e1dc4b91375bc18349663a52395ad585bd3c ]
    
    On a custom carrier board with a i.MX6Q Apalis SoM, the sgtl5000 codec
    on the SoM is often not detected and the following error message is
    seen when the sgtl5000 driver tries to read the ID register:
    
    sgtl5000 1-000a: Error reading chip id -6
    
    The reason for the error is that the MCLK clock is not provided
    early enough.
    
    Fix the problem by describing the MCLK pinctrl inside the codec
    node instead of placing it inside the audmux pinctrl group.
    
    With this change applied the sgtl5000 is always detected on every boot.
    
    Fixes: 693e3ffaae5a ("ARM: dts: imx6: Add support for Toradex Apalis iMX6Q/D SoM")
    Signed-off-by: Fabio Estevam <festevam@gmail.com>
    Reviewed-by: Tim Harvey <tharvey@gateworks.com>
    Acked-by: Max Krummenacher <max.krummenacher@toradex.com>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 0e005b85874b891c88951939a0870c2c9259fdae
Author: Adam Ford <aford173@gmail.com>
Date:   Sun Mar 20 15:52:12 2022 -0500

    soc: imx: imx8m-blk-ctrl: Fix IMX8MN_DISPBLK_PD_ISI hang
    
    [ Upstream commit e2aa165cd0163cef83cb295eb572aa9fb1604cf4 ]
    
    The imx8mn clock list for the ISI lists four clocks, but DOMAIN_MAX_CLKS
    was set to 3.  Because of this, attempts to enable the fourth clock failed,
    threw some splat, and ultimately hung.
    
    Fixes: 7f511d514e8c ("soc: imx: imx8m-blk-ctrl: add i.MX8MN DISP blk-ctrl")
    Signed-off-by: Adam Ford <aford173@gmail.com>
    Reviewed-by: Lucas Stach <l.stach@pengutronix.de>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 28d41484fcf8e6b4db99feed845de9fbc02b55d0
Author: Weitao Wang <WeitaoWang-oc@zhaoxin.com>
Date:   Fri Apr 8 16:48:21 2022 +0300

    USB: Fix xhci event ring dequeue pointer ERDP update issue
    
    [ Upstream commit e91ac20889d1a26d077cc511365cd7ff4346a6f3 ]
    
    In some situations software handles TRB events slower than adding TRBs.
    If the number of TRB events to be processed in a given interrupt is exactly
    the same as the event ring size 256, then the local variable
    "event_ring_deq" that holds the initial dequeue position is equal to
    software_dequeue after handling all 256 interrupts.
    
    It will cause driver to not update ERDP to hardware,
    
    Software dequeue pointer is out of sync with ERDP on interrupt exit.
    On the next interrupt, the event ring may full but driver will not
    update ERDP as software_dequeue is equal to ERDP.
    
    [  536.377115] xhci_hcd 0000:00:12.0: ERROR unknown event type 37
    [  566.933173] sd 8:0:0:0: [sdb] tag#27 uas_eh_abort_handler 0 uas-tag 7 inflight: CMD OUT
    [  566.933181] sd 8:0:0:0: [sdb] tag#27 CDB: Write(10) 2a 00 17 71 e6 78 00 00 08 00
    [  572.041186] xhci_hcd On some situataions,the0000:00:12.0: xHCI host not responding to stop endpoint command.
    [  572.057193] xhci_hcd 0000:00:12.0: Host halt failed, -110
    [  572.057196] xhci_hcd 0000:00:12.0: xHCI host controller not responding, assume dead
    [  572.057236] sd 8:0:0:0: [sdb] tag#26 uas_eh_abort_handler 0 uas-tag 6 inflight: CMD
    [  572.057240] sd 8:0:0:0: [sdb] tag#26 CDB: Write(10) 2a 00 38 eb cc d8 00 00 08 00
    [  572.057244] sd 8:0:0:0: [sdb] tag#25 uas_eh_abort_handler 0 uas-tag 5 inflight: CMD
    
    Hardware ERDP is updated mid event handling if there are more than 128
    events in an interrupt (half of ring size).
    Fix this by updating the software local variable at the same time as
    hardware ERDP.
    
    [commit message rewording -Mathias]
    
    Fixes: dc0ffbea5729 ("usb: host: xhci: update event ring dequeue pointer on purpose")
    Reviewed-by: Peter Chen <peter.chen@kernel.org>
    Signed-off-by: Weitao Wang <WeitaoWang-oc@zhaoxin.com>
    Signed-off-by: Mathias Nyman <mathias.nyman@linux.intel.com>
    Link: https://lore.kernel.org/r/20220408134823.2527272-2-mathias.nyman@linux.intel.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 05f71dbb5f4560f7a41e6de1d9c0bd6482fa6b2f
Author: Liu Ying <victor.liu@nxp.com>
Date:   Fri Mar 4 16:04:43 2022 +0800

    arm64: dts: imx8qm: Correct SCU clock controller's compatible property
    
    [ Upstream commit dd2737fab4a6ce9ba4eb84842bedbd87d55241a6 ]
    
    The fsl,scu.txt dt-binding documentation explicitly mentions
    that the compatible string should be either "fsl,imx8qm-clock"
    or "fsl,imx8qxp-clock", followed by "fsl,scu-clk".  Also, i.MX8qm
    SCU clocks and i.MX8qxp SCU clocks are really not the same, so
    we have to set the compatible property according to SoC name.
    Let's correct the i.MX8qm clock controller's compatible property
    from
    "fsl,imx8qxp-clk", "fsl,scu-clk"
    to
    "fsl,imx8qm-clk", "fsl,scu-clk" .
    
    Fixes: f2180be18a63 ("arm64: dts: imx: add imx8qm common dts file")
    Cc: Rob Herring <robh+dt@kernel.org>
    Cc: Shawn Guo <shawnguo@kernel.org>
    Cc: Sascha Hauer <s.hauer@pengutronix.de>
    Cc: Pengutronix Kernel Team <kernel@pengutronix.de>
    Cc: Fabio Estevam <festevam@gmail.com>
    Cc: NXP Linux Team <linux-imx@nxp.com>
    Signed-off-by: Liu Ying <victor.liu@nxp.com>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 3addcaaa33f7810dc53cf9c52a71f1b9baacc7e1
Author: Maciej Fijalkowski <maciej.fijalkowski@intel.com>
Date:   Wed Apr 6 17:58:04 2022 +0200

    xsk: Fix l2fwd for copy mode + busy poll combo
    
    [ Upstream commit 8de8b71b787f38983d414d2dba169a3bfefa668a ]
    
    While checking AF_XDP copy mode combined with busy poll, strange
    results were observed. rxdrop and txonly scenarios worked fine, but
    l2fwd broke immediately.
    
    After a deeper look, it turned out that for l2fwd, Tx side was exiting
    early due to xsk_no_wakeup() returning true and in the end
    xsk_generic_xmit() was never called. Note that AF_XDP Tx in copy mode
    is syscall steered, so the current behavior is broken.
    
    Txonly scenario only worked due to the fact that
    sk_mark_napi_id_once_xdp() was never called - since Rx side is not in
    the picture for this case and mentioned function is called in
    xsk_rcv_check(), sk::sk_napi_id was never set, which in turn meant that
    xsk_no_wakeup() was returning false (see the sk->sk_napi_id >=
    MIN_NAPI_ID check in there).
    
    To fix this, prefer busy poll in xsk_sendmsg() only when zero copy is
    enabled on a given AF_XDP socket. By doing so, busy poll in copy mode
    would not exit early on Tx side and eventually xsk_generic_xmit() will
    be called.
    
    Fixes: a0731952d9cd ("xsk: Add busy-poll support for {recv,send}msg()")
    Signed-off-by: Maciej Fijalkowski <maciej.fijalkowski@intel.com>
    Signed-off-by: Daniel Borkmann <daniel@iogearbox.net>
    Link: https://lore.kernel.org/bpf/20220406155804.434493-1-maciej.fijalkowski@intel.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 7102dd0a92ddd4974f8f2cbb0fa97a327358bf57
Author: Dongliang Mu <mudongliangabcd@gmail.com>
Date:   Wed Mar 16 21:50:47 2022 +0800

    tee: optee: add missing mutext_destroy in optee_ffa_probe
    
    [ Upstream commit b5e22886839ae466fcf03295150094516c0fd8eb ]
    
    The error handling code of optee_ffa_probe misses the mutex_destroy of
    ffa.mutex when mutext_init succeeds.
    
    Fix this by adding mutex_destory of ffa.mutex at the error handling part
    
    Fixes: aceeafefff73 ("optee: use driver internal tee_context for some rpc")
    Signed-off-by: Dongliang Mu <mudongliangabcd@gmail.com>
    Signed-off-by: Jens Wiklander <jens.wiklander@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 1e90d37497e3149d8c7cf006fd2e1e1b855b94e8
Author: Chuanhong Guo <gch981213@gmail.com>
Date:   Sun Apr 3 00:03:13 2022 +0800

    mtd: rawnand: fix ecc parameters for mt7622
    
    [ Upstream commit 9fe4e0d3cbfe90152137963cc024ecb63db6e8e6 ]
    
    According to the datasheet, mt7622 only has 5 ECC capabilities instead
    of 7, and the decoding error register is arranged  as follows:
    +------+---------+---------+---------+---------+
    | Bits |  19:15  |  14:10  |   9:5   |   4:0   |
    +------+---------+---------+---------+---------+
    | Name | ERRNUM3 | ERRNUM2 | ERRNUM1 | ERRNUM0 |
    +------+---------+---------+---------+---------+
    This means err_mask should be 0x1f instead of 0x3f and the number of
    bits shifted in mtk_ecc_get_stats should be 5 instead of 8.
    
    This commit introduces err_shift for the difference in this register
    and fix other existing parameters.
    
    Public MT7622 reference manual can be found on [0] and the info this
    commit is based on is from page 656 and page 660.
    
    [0]: https://wiki.banana-pi.org/Banana_Pi_BPI-R64#Documents
    
    Fixes: 98dea8d71931 ("mtd: nand: mtk: Support MT7622 NAND flash controller.")
    Signed-off-by: Chuanhong Guo <gch981213@gmail.com>
    Signed-off-by: Miquel Raynal <miquel.raynal@bootlin.com>
    Link: https://lore.kernel.org/linux-mtd/20220402160315.919094-1-gch981213@gmail.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 1c544b897bbd3eed8a5b79c820e2a5afc08e1e70
Author: Wang ShaoBo <bobo.shaobowang@huawei.com>
Date:   Sun Mar 20 13:54:57 2022 +0800

    iio:filter:admv8818: select REGMAP_SPI for ADMV8818
    
    [ Upstream commit d85cce86a86746354fffb688dd134609c8277adc ]
    
    admv8818 driver needs __devm_regmap_init_spi() which is defined
    when CONFIG_REGMAP_SPI is set and struct regmap_config when
    CONFIG_REGMAP is set, so automatically select CONFIG_REGMAP_SPI
    which also sets CONFIG_REGMAP.
    
    Fixes: f34fe888ad05 ("iio:filter:admv8818: add support for ADMV8818")
    Signed-off-by: Wang ShaoBo <bobo.shaobowang@huawei.com>
    Reviewed-by: Nuno Sá <nuno.sa@analog.com>
    Link: https://lore.kernel.org/r/20220320055457.254983-1-bobo.shaobowang@huawei.com
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit f4443ca0092d561040688eed13ad8658c2f2733c
Author: Tong Zhang <ztong0001@gmail.com>
Date:   Sun Mar 27 08:40:05 2022 -0700

    iio:imu:bmi160: disable regulator in error path
    
    [ Upstream commit d926054d5565d3cfa2c7c3f7a48e79bcc10453ed ]
    
    Regulator should be disabled in error path as mentioned in _regulator_put().
    Also disable accel if gyro cannot be enabled.
    
    [   16.233604] WARNING: CPU: 0 PID: 2177 at drivers/regulator/core.c:2257 _regulator_put
    [   16.240453] Call Trace:
    [   16.240572]  <TASK>
    [   16.240676]  regulator_put+0x26/0x40
    [   16.240853]  regulator_bulk_free+0x26/0x50
    [   16.241050]  release_nodes+0x3f/0x70
    [   16.241225]  devres_release_group+0x147/0x1c0
    [   16.241441]  ? bmi160_core_probe+0x175/0x3a0 [bmi160_core]
    
    Fixes: 5dea3fb066f0 ("iio: imu: bmi160: added regulator support")
    Reviewed-by: Andy Shevchenko <andriy.shevchenko@linux.intel.com>
    Signed-off-by: Tong Zhang <ztong0001@gmail.com>
    Link: https://lore.kernel.org/r/20220327154005.806049-1-ztong0001@gmail.com
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 69b0a0dfc1823506ca1f95c5ec609045b2484053
Author: Dan Carpenter <dan.carpenter@oracle.com>
Date:   Wed Mar 16 15:23:54 2022 +0300

    iio: dac: ad3552r: fix signedness bug in ad3552r_reset()
    
    [ Upstream commit 460bfa65b0de72f4d8a808bc7cfb1cb591a95b18 ]
    
    The "val" variable is used to store either negative error codes from
    ad3552r_read_reg_wrapper() or positive u16 values on success.  It needs
    to be signed for the error handling to work correctly.
    
    Fixes: 8f2b54824b28 ("drivers:iio:dac: Add AD3552R driver support")
    Signed-off-by: Dan Carpenter <dan.carpenter@oracle.com>
    Link: https://lore.kernel.org/r/20220316122354.GA16825@kili
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 86c344ab101425506461165dc53b4e094039ad17
Author: Christian Hewitt <christianshewitt@gmail.com>
Date:   Thu Feb 10 10:06:38 2022 +0000

    arm64: dts: meson: remove CPU opps below 1GHz for SM1 boards
    
    [ Upstream commit fd86d85401c2049f652293877c0f7e6e5afc3bbc ]
    
    Amlogic SM1 devices experience CPU stalls and random board wedges when
    the system idles and CPU cores clock down to lower opp points. Recent
    vendor kernels include a change to remove 100-250MHz and other distro
    sources also remove the 500/667MHz points. Unless all 100-667Mhz opps
    are removed or the CPU governor forced to performance stalls are still
    observed, so let's remove them to improve stability and uptime.
    
    Fixes: 3d9e76483049 ("arm64: dts: meson-sm1-sei610: enable DVFS")
    Signed-off-by: Christian Hewitt <christianshewitt@gmail.com>
    Reviewed-by: Neil Armstrong <narmstrong@baylibre.com>
    Signed-off-by: Neil Armstrong <narmstrong@baylibre.com>
    Link: https://lore.kernel.org/r/20220210100638.19130-3-christianshewitt@gmail.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 23c7529c6777cf9e00943ce02565eefba8086c9a
Author: Christian Hewitt <christianshewitt@gmail.com>
Date:   Thu Feb 10 10:06:37 2022 +0000

    arm64: dts: meson: remove CPU opps below 1GHz for G12B boards
    
    [ Upstream commit 6c4d636bc00dc17c63ffb2a73a0da850240e26e3 ]
    
    Amlogic G12B devices experience CPU stalls and random board wedges when
    the system idles and CPU cores clock down to lower opp points. Recent
    vendor kernels include a change to remove 100-250MHz and other distro
    sources also remove the 500/667MHz points. Unless all 100-667Mhz opps
    are removed or the CPU governor forced to performance stalls are still
    observed, so let's remove them to improve stability and uptime.
    
    Fixes: b96d4e92709b ("arm64: dts: meson-g12b: support a311d and s922x cpu operating points")
    Signed-off-by: Christian Hewitt <christianshewitt@gmail.com>
    Reviewed-by: Neil Armstrong <narmstrong@baylibre.com>
    Signed-off-by: Neil Armstrong <narmstrong@baylibre.com>
    Link: https://lore.kernel.org/r/20220210100638.19130-2-christianshewitt@gmail.com
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 895ea8a290ba87850bcaf2ecfcddef75a014fa54
Author: Pavel Skripkin <paskripkin@gmail.com>
Date:   Tue Mar 22 23:04:38 2022 +0300

    video: fbdev: udlfb: properly check endpoint type
    
    [ Upstream commit aaf7dbe07385e0b8deb7237eca2a79926bbc7091 ]
    
    syzbot reported warning in usb_submit_urb, which is caused by wrong
    endpoint type.
    
    This driver uses out bulk endpoint for communication, so
    let's check if this endpoint is present and bail out early if not.
    
    Fail log:
    
    usb 1-1: BOGUS urb xfer, pipe 3 != type 1
    WARNING: CPU: 0 PID: 4822 at drivers/usb/core/urb.c:493 usb_submit_urb+0xd27/0x1540 drivers/usb/core/urb.c:493
    Modules linked in:
    CPU: 0 PID: 4822 Comm: kworker/0:3 Tainted: G        W         5.13.0-syzkaller #0
    ...
    Workqueue: usb_hub_wq hub_event
    RIP: 0010:usb_submit_urb+0xd27/0x1540 drivers/usb/core/urb.c:493
    ...
    Call Trace:
     dlfb_submit_urb+0x89/0x160 drivers/video/fbdev/udlfb.c:1969
     dlfb_set_video_mode+0x21f0/0x2950 drivers/video/fbdev/udlfb.c:315
     dlfb_ops_set_par+0x2a3/0x840 drivers/video/fbdev/udlfb.c:1110
     dlfb_usb_probe.cold+0x113e/0x1f4a drivers/video/fbdev/udlfb.c:1732
     usb_probe_interface+0x315/0x7f0 drivers/usb/core/driver.c:396
    
    Fixes: 88e58b1a42f8 ("Staging: add udlfb driver")
    Reported-and-tested-by: syzbot+53ce4a4246d0fe0fee34@syzkaller.appspotmail.com
    Signed-off-by: Pavel Skripkin <paskripkin@gmail.com>
    Signed-off-by: Helge Deller <deller@gmx.de>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit badc604b78a6d9ac24ffe58b32fdd3c20127d859
Author: Vladimir Zapolskiy <vladimir.zapolskiy@linaro.org>
Date:   Fri Apr 1 10:14:24 2022 +0300

    cpufreq: qcom-cpufreq-hw: Fix throttle frequency value on EPSS platforms
    
    [ Upstream commit f84ccad5f5660f86a642a3d7e2bfdc4e7a8a2d49 ]
    
    On QCOM platforms with EPSS flavour of cpufreq IP a throttled frequency is
    obtained from another register REG_DOMAIN_STATE, thus the helper function
    qcom_lmh_get_throttle_freq() should be modified accordingly, as for now
    it returns gibberish since .reg_current_vote is unset for EPSS hardware.
    
    To exclude a hardcoded magic number 19200 it is replaced by "xo" clock rate
    in KHz.
    
    Fixes: 275157b367f4 ("cpufreq: qcom-cpufreq-hw: Add dcvs interrupt support")
    Reviewed-by: Bjorn Andersson <bjorn.andersson@linaro.org>
    Signed-off-by: Vladimir Zapolskiy <vladimir.zapolskiy@linaro.org>
    Signed-off-by: Viresh Kumar <viresh.kumar@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit dfef275b3eb9236e72754e9354f73723ca49d350
Author: Dmitry Baryshkov <dmitry.baryshkov@linaro.org>
Date:   Sat Mar 26 18:51:52 2022 +0300

    cpufreq: qcom-hw: fix the opp entries refcounting
    
    [ Upstream commit 6240aaad75e1a623872a830d13393d7aabf1052c ]
    
    The qcom_lmh_dcvs_notify() will get the dev_pm_opp instance for
    throttling, but will not put it, ending up with leaking a reference
    count and the following backtrace when putting the CPU offline.
    
    Correctly put the reference count of the returned opp instance.
    
    [   84.418025] ------------[ cut here ]------------
    [   84.422770] WARNING: CPU: 7 PID: 43 at drivers/opp/core.c:1396 _opp_table_kref_release+0x188/0x190
    [   84.431966] Modules linked in:
    [   84.435106] CPU: 7 PID: 43 Comm: cpuhp/7 Tainted: G S                5.17.0-rc6-00388-g7cf3c0d89c44-dirty #721
    [   84.451631] pstate: 82400005 (Nzcv daif +PAN -UAO +TCO -DIT -SSBS BTYPE=--)
    [   84.458781] pc : _opp_table_kref_release+0x188/0x190
    [   84.463878] lr : _opp_table_kref_release+0x78/0x190
    [   84.468885] sp : ffff80000841bc70
    [   84.472294] x29: ffff80000841bc70 x28: ffff6664afe3d000 x27: ffff1db6729e5908
    [   84.479621] x26: 0000000000000000 x25: 0000000000000000 x24: ffff1db6729e58e0
    [   84.486946] x23: ffff8000080a5000 x22: ffff1db40aad80e0 x21: ffff1db4002fec80
    [   84.494277] x20: ffff1db40aad8000 x19: ffffb751c3186300 x18: ffffffffffffffff
    [   84.501603] x17: 5300326563697665 x16: 645f676e696c6f6f x15: 00001186c1df5448
    [   84.508928] x14: 00000000000002e9 x13: 0000000000000000 x12: 0000000000000000
    [   84.516256] x11: ffffb751c3186368 x10: ffffb751c39a2a70 x9 : 0000000000000000
    [   84.523585] x8 : ffff1db4008edf00 x7 : ffffb751c328c000 x6 : 0000000000000001
    [   84.530916] x5 : 0000000000040000 x4 : 0000000000000001 x3 : ffff1db4008edf00
    [   84.538247] x2 : 0000000000000000 x1 : ffff1db400aa6100 x0 : ffff1db40aad80d0
    [   84.545579] Call trace:
    [   84.548101]  _opp_table_kref_release+0x188/0x190
    [   84.552842]  dev_pm_opp_remove_all_dynamic+0x8c/0xc0
    [   84.557949]  qcom_cpufreq_hw_cpu_exit+0x30/0xdc
    [   84.562608]  cpufreq_offline.isra.0+0x1b4/0x1d8
    [   84.567270]  cpuhp_cpufreq_offline+0x10/0x6c
    [   84.571663]  cpuhp_invoke_callback+0x16c/0x2b0
    [   84.576231]  cpuhp_thread_fun+0x190/0x250
    [   84.580353]  smpboot_thread_fn+0x12c/0x230
    [   84.584568]  kthread+0xfc/0x100
    [   84.587810]  ret_from_fork+0x10/0x20
    [   84.591490] irq event stamp: 3482
    [   84.594901] hardirqs last  enabled at (3481): [<ffffb751c13c3db0>] call_rcu+0x39c/0x50c
    [   84.603119] hardirqs last disabled at (3482): [<ffffb751c236b518>] el1_dbg+0x24/0x8c
    [   84.611074] softirqs last  enabled at (310): [<ffffb751c1290410>] _stext+0x410/0x588
    [   84.619028] softirqs last disabled at (305): [<ffffb751c131bf68>] __irq_exit_rcu+0x158/0x174
    [   84.627691] ---[ end trace 0000000000000000 ]---
    
    Fixes: 275157b367f4 ("cpufreq: qcom-cpufreq-hw: Add dcvs interrupt support")
    Reported-by: kernel test robot <lkp@intel.com>
    Tested-by: Vladimir Zapolskiy <vladimir.zapolskiy@linaro.org>
    Reviewed-by: Vladimir Zapolskiy <vladimir.zapolskiy@linaro.org>
    Reviewed-by: Bjorn Andersson <bjorn.andersson@linaro.org>
    Signed-off-by: Dmitry Baryshkov <dmitry.baryshkov@linaro.org>
    Signed-off-by: Viresh Kumar <viresh.kumar@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit ac23e145396fcadc0e8478c6f93bfd18886b7919
Author: Dmitry Baryshkov <dmitry.baryshkov@linaro.org>
Date:   Sat Mar 26 18:51:51 2022 +0300

    cpufreq: qcom-hw: fix the race between LMH worker and cpuhp
    
    [ Upstream commit 5e4f009da6be563984ba4db4ef4f32529e9aeb90 ]
    
    The driver would disable the worker when cpu is being put offline, but
    it happens closer to the end of cpufreq_offline(). The function
    qcom_lmh_dcvs_poll() can be running in parallel with this, when
    policy->cpus already has been updated. Read policy->related_cpus
    instead.
    
    [   37.122433] ------------[ cut here ]------------
    [   37.127225] WARNING: CPU: 0 PID: 187 at drivers/base/arch_topology.c:180 topology_update_thermal_pressure+0xec/0x100
    [   37.138098] Modules linked in:
    [   37.141279] CPU: 0 PID: 187 Comm: kworker/0:3 Tainted: G S                5.17.0-rc6-00389-g37c83d0b8710-dirty #713
    [   37.158306] Workqueue: events qcom_lmh_dcvs_poll
    [   37.163095] pstate: 60400005 (nZCv daif +PAN -UAO -TCO -DIT -SSBS BTYPE=--)
    [   37.170278] pc : topology_update_thermal_pressure+0xec/0x100
    [   37.176131] lr : topology_update_thermal_pressure+0x20/0x100
    [   37.181977] sp : ffff800009b6bce0
    [   37.185402] x29: ffff800009b6bce0 x28: ffffd87abe92b000 x27: ffff04bd7292e205
    [   37.192792] x26: ffffd87abe930af8 x25: ffffd87abe94e4c8 x24: 0000000000000000
    [   37.200180] x23: ffff04bb01177018 x22: ffff04bb011770c0 x21: ffff04bb01177000
    [   37.207567] x20: ffff04bb0a419000 x19: 00000000000c4e00 x18: 0000000000000000
    [   37.214954] x17: 000000040044ffff x16: 004000b2b5503510 x15: 0000006aaa1326d2
    [   37.222333] x14: 0000000000000232 x13: 0000000000000001 x12: 0000000000000040
    [   37.229718] x11: ffff04bb00400000 x10: 968f57bd39f701c8 x9 : ffff04bb0acc8674
    [   37.237095] x8 : fefefefefefefeff x7 : 0000000000000018 x6 : ffffd87abd90092c
    [   37.244478] x5 : 0000000000000016 x4 : 0000000000000000 x3 : 0000000000000100
    [   37.251852] x2 : ffff04bb0a419020 x1 : 0000000000000100 x0 : 0000000000000100
    [   37.259235] Call trace:
    [   37.261771]  topology_update_thermal_pressure+0xec/0x100
    [   37.267266]  qcom_lmh_dcvs_poll+0xbc/0x154
    [   37.271505]  process_one_work+0x288/0x69c
    [   37.275654]  worker_thread+0x74/0x470
    [   37.279450]  kthread+0xfc/0x100
    [   37.282712]  ret_from_fork+0x10/0x20
    [   37.286417] irq event stamp: 74
    [   37.289664] hardirqs last  enabled at (73): [<ffffd87abdd78af4>] _raw_spin_unlock_irq+0x44/0x80
    [   37.298632] hardirqs last disabled at (74): [<ffffd87abdd71fc0>] __schedule+0x710/0xa10
    [   37.306885] softirqs last  enabled at (58): [<ffffd87abcc90410>] _stext+0x410/0x588
    [   37.314778] softirqs last disabled at (51): [<ffffd87abcd1bf68>] __irq_exit_rcu+0x158/0x174
    [   37.323386] ---[ end trace 0000000000000000 ]---
    
    Fixes: 275157b367f4 ("cpufreq: qcom-cpufreq-hw: Add dcvs interrupt support")
    Signed-off-by: Dmitry Baryshkov <dmitry.baryshkov@linaro.org>
    Reviewed-by: Bjorn Andersson <bjorn.andersson@linaro.org>
    Signed-off-by: Viresh Kumar <viresh.kumar@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 822feb7f8b648602264f9a1b56afd5140af64e92
Author: Dmitry Baryshkov <dmitry.baryshkov@linaro.org>
Date:   Sat Mar 26 18:51:50 2022 +0300

    cpufreq: qcom-hw: drop affinity hint before freeing the IRQ
    
    [ Upstream commit be5985b3dbce5ba2af3c8b0f2b7df235c93907e6 ]
    
    Drop affinity hint before freeing the throttling IRQ to fix the
    following trace:
    
    [  185.114773] ------------[ cut here ]------------
    [  185.119517] WARNING: CPU: 7 PID: 43 at kernel/irq/manage.c:1887 free_irq+0x3a4/0x3dc
    [  185.127474] Modules linked in:
    [  185.130618] CPU: 7 PID: 43 Comm: cpuhp/7 Tainted: G S      W         5.17.0-rc6-00386-g67382a5b705d-dirty #690
    [  185.147125] pstate: 604000c5 (nZCv daIF +PAN -UAO -TCO -DIT -SSBS BTYPE=--)
    [  185.154269] pc : free_irq+0x3a4/0x3dc
    [  185.158031] lr : free_irq+0x33c/0x3dc
    [  185.161792] sp : ffff80000841bc90
    [  185.165195] x29: ffff80000841bc90 x28: ffffa6edc5c3d000 x27: ffff6d93729e5908
    [  185.172515] x26: 0000000000000000 x25: ffff6d910109fc00 x24: ffff6d91011490e0
    [  185.179838] x23: ffff6d9101149218 x22: 0000000000000080 x21: 0000000000000000
    [  185.187163] x20: ffff6d9101149000 x19: ffff6d910ab61500 x18: ffffffffffffffff
    [  185.194487] x17: 2e35202020202020 x16: 2020202020202020 x15: ffff80008841b9a7
    [  185.201805] x14: 00000000000003c9 x13: 0000000000000001 x12: 0000000000000040
    [  185.209135] x11: ffff6d91005aab58 x10: ffff6d91005aab5a x9 : ffffc6a5ad1c5408
    [  185.216455] x8 : ffff6d91005adb88 x7 : 0000000000000000 x6 : ffffc6a5ab5a91f4
    [  185.223776] x5 : 0000000000000000 x4 : ffff6d91011490a8 x3 : ffffc6a5ad266108
    [  185.231098] x2 : 0000000013033204 x1 : ffff6d9101149000 x0 : ffff6d910a9cc000
    [  185.238421] Call trace:
    [  185.240932]  free_irq+0x3a4/0x3dc
    [  185.244334]  qcom_cpufreq_hw_cpu_exit+0x78/0xcc
    [  185.248985]  cpufreq_offline.isra.0+0x228/0x270
    [  185.253639]  cpuhp_cpufreq_offline+0x10/0x20
    [  185.258027]  cpuhp_invoke_callback+0x16c/0x2b0
    [  185.262592]  cpuhp_thread_fun+0x190/0x250
    [  185.266710]  smpboot_thread_fn+0x12c/0x230
    [  185.270914]  kthread+0xfc/0x100
    [  185.274145]  ret_from_fork+0x10/0x20
    [  185.277820] irq event stamp: 212
    [  185.281136] hardirqs last  enabled at (211): [<ffffc6a5ac57973c>] _raw_spin_unlock_irqrestore+0x8c/0xa0
    [  185.290775] hardirqs last disabled at (212): [<ffffc6a5ac572100>] __schedule+0x710/0xa10
    [  185.299081] softirqs last  enabled at (0): [<ffffc6a5ab50f7b0>] copy_process+0x7d0/0x1a14
    [  185.307475] softirqs last disabled at (0): [<0000000000000000>] 0x0
    
    Fixes: 3ed6dfbd3bb98 ("cpufreq: qcom-hw: Set CPU affinity of dcvsh interrupts")
    Tested-by: Vladimir Zapolskiy <vladimir.zapolskiy@linaro.org>
    Reviewed-by: Vladimir Zapolskiy <vladimir.zapolskiy@linaro.org>
    Reviewed-by: Bjorn Andersson <bjorn.andersson@linaro.org>
    Signed-off-by: Dmitry Baryshkov <dmitry.baryshkov@linaro.org>
    Signed-off-by: Viresh Kumar <viresh.kumar@linaro.org>
    Signed-off-by: Sasha Levin <sashal@kernel.org>

commit 30f28ceed2f11c9d51549e1de8ecdbee1ded9469
Author: Nikolay Aleksandrov <razor@blackwall.org>
Date:   Mon Apr 25 13:37:03 2022 +0300

    virtio_net: fix wrong buf address calculation when using xdp
    
    commit acb16b395c3f3d7502443e0c799c2b42df645642 upstream.
    
    We received a report[1] of kernel crashes when Cilium is used in XDP
    mode with virtio_net after updating to newer kernels. After
    investigating the reason it turned out that when using mergeable bufs
    with an XDP program which adjusts xdp.data or xdp.data_meta page_to_buf()
    calculates the build_skb address wrong because the offset can become less
    than the headroom so it gets the address of the previous page (-X bytes
    depending on how lower offset is):
     page_to_skb: page addr ffff9eb2923e2000 buf ffff9eb2923e1ffc offset 252 headroom 256
    
    This is a pr_err() I added in the beginning of page_to_skb which clearly
    shows offset that is less than headroom by adding 4 bytes of metadata
    via an xdp prog. The calculations done are:
     receive_mergeable():
     headroom = VIRTIO_XDP_HEADROOM; // VIRTIO_XDP_HEADROOM == 256 bytes
     offset = xdp.data - page_address(xdp_page) -
              vi->hdr_len - metasize;
    
     page_to_skb():
     p = page_address(page) + offset;
     ...
     buf = p - headroom;
    
    Now buf goes -4 bytes from the page's starting address as can be seen
    above which is set as skb->head and skb->data by build_skb later. Depending
    on what's done with the skb (when it's freed most often) we get all kinds
    of corruptions and BUG_ON() triggers in mm[2]. We have to recalculate
    the new headroom after the xdp program has run, similar to how offset
    and len are recalculated. Headroom is directly related to
    data_hard_start, data and data_meta, so we use them to get the new size.
    The result is correct (similar pr_err() in page_to_skb, one case of
    xdp_page and one case of virtnet buf):
     a) Case with 4 bytes of metadata
     [  115.949641] page_to_skb: page addr ffff8b4dcfad2000 offset 252 headroom 252
     [  121.084105] page_to_skb: page addr ffff8b4dcf018000 offset 20732 headroom 252
     b) Case of pushing data +32 bytes
     [  153.181401] page_to_skb: page addr ffff8b4dd0c4d000 offset 288 headroom 288
     [  158.480421] page_to_skb: page addr ffff8b4dd00b0000 offset 24864 headroom 288
     c) Case of pushing data -33 bytes
     [  835.906830] page_to_skb: page addr ffff8b4dd3270000 offset 223 headroom 223
     [  840.839910] page_to_skb: page addr ffff8b4dcdd68000 offset 12511 headroom 223
    
    Offset and headroom are equal because offset points to the start of
    reserved bytes for the virtio_net header which are at buf start +
    headroom, while data points at buf start + vnet hdr size + headroom so
    when data or data_meta are adjusted by the xdp prog both the headroom size
    and the offset change equally. We can use data_hard_start to compute the
    new headroom after the xdp prog (linearized / page start case, the
    virtnet buf case is similar just with bigger base offset):
     xdp.data_hard_start = page_address + vnet_hdr
     xdp.data = page_address + vnet_hdr + headroom
     new headroom after xdp prog = xdp.data - xdp.data_hard_start - metasize
    
    An example reproducer xdp prog[3] is below.
    
    [1] https://github.com/cilium/cilium/issues/19453
    
    [2] Two of the many traces:
     [   40.437400] BUG: Bad page state in process swapper/0  pfn:14940
     [   40.916726] BUG: Bad page state in process systemd-resolve  pfn:053b7
     [   41.300891] kernel BUG at include/linux/mm.h:720!
     [   41.301801] invalid opcode: 0000 [#1] PREEMPT SMP NOPTI
     [   41.302784] CPU: 1 PID: 1181 Comm: kubelet Kdump: loaded Tainted: G    B   W         5.18.0-rc1+ #37
     [   41.304458] Hardware name: QEMU Standard PC (Q35 + ICH9, 2009), BIOS 1.15.0-1.fc35 04/01/2014
     [   41.306018] RIP: 0010:page_frag_free+0x79/0xe0
     [   41.306836] Code: 00 00 75 ea 48 8b 07 a9 00 00 01 00 74 e0 48 8b 47 48 48 8d 50 ff a8 01 48 0f 45 fa eb d0 48 c7 c6 18 b8 30 a6 e8 d7 f8 fc ff <0f> 0b 48 8d 78 ff eb bc 48 8b 07 a9 00 00 01 00 74 3a 66 90 0f b6
     [   41.310235] RSP: 0018:ffffac05c2a6bc78 EFLAGS: 00010292
     [   41.311201] RAX: 000000000000003e RBX: 0000000000000000 RCX: 0000000000000000
     [   41.312502] RDX: 0000000000000001 RSI: ffffffffa6423004 RDI: 00000000ffffffff
     [   41.313794] RBP: ffff993c98823600 R08: 0000000000000000 R09: 00000000ffffdfff
     [   41.315089] R10: ffffac05c2a6ba68 R11: ffffffffa698ca28 R12: ffff993c98823600
     [   41.316398] R13: ffff993c86311ebc R14: 0000000000000000 R15: 000000000000005c
     [   41.317700] FS:  00007fe13fc56740(0000) GS:ffff993cdd900000(0000) knlGS:0000000000000000
     [   41.319150] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
     [   41.320152] CR2: 000000c00008a000 CR3: 0000000014908000 CR4: 0000000000350ee0
     [   41.321387] Call Trace:
     [   41.321819]  <TASK>
     [   41.322193]  skb_release_data+0x13f/0x1c0
     [   41.322902]  __kfree_skb+0x20/0x30
     [   41.343870]  tcp_recvmsg_locked+0x671/0x880
     [   41.363764]  tcp_recvmsg+0x5e/0x1c0
     [   41.384102]  inet_recvmsg+0x42/0x100
     [   41.406783]  ? sock_recvmsg+0x1d/0x70
     [   41.428201]  sock_read_iter+0x84/0xd0
     [   41.445592]  ? 0xffffffffa3000000
     [   41.462442]  new_sync_read+0x148/0x160
     [   41.479314]  ? 0xffffffffa3000000
     [   41.496937]  vfs_read+0x138/0x190
     [   41.517198]  ksys_read+0x87/0xc0
     [   41.535336]  do_syscall_64+0x3b/0x90
     [   41.551637]  entry_SYSCALL_64_after_hwframe+0x44/0xae
     [   41.568050] RIP: 0033:0x48765b
     [   41.583955] Code: e8 4a 35 fe ff eb 88 cc cc cc cc cc cc cc cc e8 fb 7a fe ff 48 8b 7c 24 10 48 8b 74 24 18 48 8b 54 24 20 48 8b 44 24 08 0f 05 <48> 3d 01 f0 ff ff 76 20 48 c7 44 24 28 ff ff ff ff 48 c7 44 24 30
     [   41.632818] RSP: 002b:000000c000a2f5b8 EFLAGS: 00000212 ORIG_RAX: 0000000000000000
     [   41.664588] RAX: ffffffffffffffda RBX: 000000c000062000 RCX: 000000000048765b
     [   41.681205] RDX: 0000000000005e54 RSI: 000000c000e66000 RDI: 0000000000000016
     [   41.697164] RBP: 000000c000a2f608 R08: 0000000000000001 R09: 00000000000001b4
     [   41.713034] R10: 00000000000000b6 R11: 0000000000000212 R12: 00000000000000e9
     [   41.728755] R13: 0000000000000001 R14: 000000c000a92000 R15: ffffffffffffffff
     [   41.744254]  </TASK>
     [   41.758585] Modules linked in: br_netfilter bridge veth netconsole virtio_net
    
     and
    
     [   33.524802] BUG: Bad page state in process systemd-network  pfn:11e60
     [   33.528617] page ffffe05dc0147b00 ffffe05dc04e7a00 ffff8ae9851ec000 (1) len 82 offset 252 metasize 4 hroom 0 hdr_len 12 data ffff8ae9851ec10c data_meta ffff8ae9851ec108 data_end ffff8ae9851ec14e
     [   33.529764] page:000000003792b5ba refcount:0 mapcount:-512 mapping:0000000000000000 index:0x0 pfn:0x11e60
     [   33.532463] flags: 0xfffffc0000000(node=0|zone=1|lastcpupid=0x1fffff)
     [   33.532468] raw: 000fffffc0000000 0000000000000000 dead000000000122 0000000000000000
     [   33.532470] raw: 0000000000000000 0000000000000000 00000000fffffdff 0000000000000000
     [   33.532471] page dumped because: nonzero mapcount
     [   33.532472] Modules linked in: br_netfilter bridge veth netconsole virtio_net
     [   33.532479] CPU: 0 PID: 791 Comm: systemd-network Kdump: loaded Not tainted 5.18.0-rc1+ #37
     [   33.532482] Hardware name: QEMU Standard PC (Q35 + ICH9, 2009), BIOS 1.15.0-1.fc35 04/01/2014
     [   33.532484] Call Trace:
     [   33.532496]  <TASK>
     [   33.532500]  dump_stack_lvl+0x45/0x5a
     [   33.532506]  bad_page.cold+0x63/0x94
     [   33.532510]  free_pcp_prepare+0x290/0x420
     [   33.532515]  free_unref_page+0x1b/0x100
     [   33.532518]  skb_release_data+0x13f/0x1c0
     [   33.532524]  kfree_skb_reason+0x3e/0xc0
     [   33.532527]  ip6_mc_input+0x23c/0x2b0
     [   33.532531]  ip6_sublist_rcv_finish+0x83/0x90
     [   33.532534]  ip6_sublist_rcv+0x22b/0x2b0
    
    [3] XDP program to reproduce(xdp_pass.c):
     #include <linux/bpf.h>
     #include <bpf/bpf_helpers.h>
    
     SEC("xdp_pass")
     int xdp_pkt_pass(struct xdp_md *ctx)
     {
              bpf_xdp_adjust_head(ctx, -(int)32);
              return XDP_PASS;
     }
    
     char _license[] SEC("license") = "GPL";
    
     compile: clang -O2 -g -Wall -target bpf -c xdp_pass.c -o xdp_pass.o
     load on virtio_net: ip link set enp1s0 xdpdrv obj xdp_pass.o sec xdp_pass
    
    CC: stable@vger.kernel.org
    CC: Jason Wang <jasowang@redhat.com>
    CC: Xuan Zhuo <xuanzhuo@linux.alibaba.com>
    CC: Daniel Borkmann <daniel@iogearbox.net>
    CC: "Michael S. Tsirkin" <mst@redhat.com>
    CC: virtualization@lists.linux-foundation.org
    Fixes: 8fb7da9e9907 ("virtio_net: get build_skb() buf by data ptr")
    Signed-off-by: Nikolay Aleksandrov <razor@blackwall.org>
    Reviewed-by: Xuan Zhuo <xuanzhuo@linux.alibaba.com>
    Acked-by: Daniel Borkmann <daniel@iogearbox.net>
    Acked-by: Michael S. Tsirkin <mst@redhat.com>
    Acked-by: Jason Wang <jasowang@redhat.com>
    Link: https://lore.kernel.org/r/20220425103703.3067292-1-razor@blackwall.org
    Signed-off-by: Paolo Abeni <pabeni@redhat.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit f877ae5f83c95d5999f695bb81b24dc2925f006b
Author: Tejun Heo <tj@kernel.org>
Date:   Tue Apr 26 19:01:01 2022 -1000

    iocost: don't reset the inuse weight of under-weighted debtors
    
    commit 8c936f9ea11ec4e35e288810a7503b5c841a355f upstream.
    
    When an iocg is in debt, its inuse weight is owned by debt handling and
    should stay at 1. This invariant was broken when determining the amount of
    surpluses at the beginning of donation calculation - when an iocg's
    hierarchical weight is too low, the iocg is excluded from donation
    calculation and its inuse is reset to its active regardless of its
    indebtedness, triggering warnings like the following:
    
     WARNING: CPU: 5 PID: 0 at block/blk-iocost.c:1416 iocg_kick_waitq+0x392/0x3a0
     ...
     RIP: 0010:iocg_kick_waitq+0x392/0x3a0
     Code: 00 00 be ff ff ff ff 48 89 4d a8 e8 98 b2 70 00 48 8b 4d a8 85 c0 0f 85 4a fe ff ff 0f 0b e9 43 fe ff ff 0f 0b e9 4d fe ff ff <0f> 0b e9 50 fe ff ff e8 a2 ae 70 00 66 90 0f 1f 44 00 00 55 48 89
     RSP: 0018:ffffc90000200d08 EFLAGS: 00010016
     ...
      <IRQ>
      ioc_timer_fn+0x2e0/0x1470
      call_timer_fn+0xa1/0x2c0
     ...
    
    As this happens only when an iocg's hierarchical weight is negligible, its
    impact likely is limited to triggering the warnings. Fix it by skipping
    resetting inuse of under-weighted debtors.
    
    Signed-off-by: Tejun Heo <tj@kernel.org>
    Reported-by: Rik van Riel <riel@surriel.com>
    Fixes: c421a3eb2e27 ("blk-iocost: revamp debt handling")
    Cc: stable@vger.kernel.org # v5.10+
    Link: https://lore.kernel.org/r/YmjODd4aif9BzFuO@slm.duckdns.org
    Signed-off-by: Jens Axboe <axboe@kernel.dk>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 50cfd2ce12e05d8d5bae67f66d8d19de4122566a
Author: Thomas Gleixner <tglx@linutronix.de>
Date:   Thu Apr 28 15:50:54 2022 +0200

    x86/pci/xen: Disable PCI/MSI[-X] masking for XEN_HVM guests
    
    commit 7e0815b3e09986d2fe651199363e135b9358132a upstream.
    
    When a XEN_HVM guest uses the XEN PIRQ/Eventchannel mechanism, then
    PCI/MSI[-X] masking is solely controlled by the hypervisor, but contrary to
    XEN_PV guests this does not disable PCI/MSI[-X] masking in the PCI/MSI
    layer.
    
    This can lead to a situation where the PCI/MSI layer masks an MSI[-X]
    interrupt and the hypervisor grants the write despite the fact that it
    already requested the interrupt. As a consequence interrupt delivery on the
    affected device is not happening ever.
    
    Set pci_msi_ignore_mask to prevent that like it's done for XEN_PV guests
    already.
    
    Fixes: 809f9267bbab ("xen: map MSIs into pirqs")
    Reported-by: Jeremi Piotrowski <jpiotrowski@linux.microsoft.com>
    Reported-by: Dusty Mabe <dustymabe@redhat.com>
    Reported-by: Salvatore Bonaccorso <carnil@debian.org>
    Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
    Tested-by: Noah Meyerhans <noahm@debian.org>
    Cc: stable@vger.kernel.org
    Link: https://lore.kernel.org/r/87tuaduxj5.ffs@tglx
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit c56ab397a121804c337036cbbaf8f19ce587dc9c
Author: Borislav Petkov <bp@suse.de>
Date:   Tue Apr 19 09:52:41 2022 -0700

    x86/cpu: Load microcode during restore_processor_state()
    
    commit f9e14dbbd454581061c736bf70bf5cbb15ac927c upstream.
    
    When resuming from system sleep state, restore_processor_state()
    restores the boot CPU MSRs. These MSRs could be emulated by microcode.
    If microcode is not loaded yet, writing to emulated MSRs leads to
    unchecked MSR access error:
    
      ...
      PM: Calling lapic_suspend+0x0/0x210
      unchecked MSR access error: WRMSR to 0x10f (tried to write 0x0...0) at rIP: ... (native_write_msr)
      Call Trace:
        <TASK>
        ? restore_processor_state
        x86_acpi_suspend_lowlevel
        acpi_suspend_enter
        suspend_devices_and_enter
        pm_suspend.cold
        state_store
        kobj_attr_store
        sysfs_kf_write
        kernfs_fop_write_iter
        new_sync_write
        vfs_write
        ksys_write
        __x64_sys_write
        do_syscall_64
        entry_SYSCALL_64_after_hwframe
       RIP: 0033:0x7fda13c260a7
    
    To ensure microcode emulated MSRs are available for restoration, load
    the microcode on the boot CPU before restoring these MSRs.
    
      [ Pawan: write commit message and productize it. ]
    
    Fixes: e2a1256b17b1 ("x86/speculation: Restore speculation related MSRs during S3 resume")
    Reported-by: Kyle D. Pelton <kyle.d.pelton@intel.com>
    Signed-off-by: Borislav Petkov <bp@suse.de>
    Signed-off-by: Pawan Gupta <pawan.kumar.gupta@linux.intel.com>
    Tested-by: Kyle D. Pelton <kyle.d.pelton@intel.com>
    Cc: stable@vger.kernel.org
    Link: https://bugzilla.kernel.org/show_bug.cgi?id=215841
    Link: https://lore.kernel.org/r/4350dfbf785cd482d3fafa72b2b49c83102df3ce.1650386317.git.pawan.kumar.gupta@linux.intel.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 26b29404d15c40c8e519d0f192e014c157069418
Author: Guo Ren <guoren@kernel.org>
Date:   Wed Apr 6 22:16:49 2022 +0800

    riscv: patch_text: Fixup last cpu should be master
    
    commit 8ec1442953c66a1d8462cccd8c20b7ba561f5915 upstream.
    
    These patch_text implementations are using stop_machine_cpuslocked
    infrastructure with atomic cpu_count. The original idea: When the
    master CPU patch_text, the others should wait for it. But current
    implementation is using the first CPU as master, which couldn't
    guarantee the remaining CPUs are waiting. This patch changes the
    last CPU as the master to solve the potential risk.
    
    Signed-off-by: Guo Ren <guoren@linux.alibaba.com>
    Signed-off-by: Guo Ren <guoren@kernel.org>
    Acked-by: Palmer Dabbelt <palmer@rivosinc.com>
    Reviewed-by: Masami Hiramatsu <mhiramat@kernel.org>
    Fixes: 043cb41a85de ("riscv: introduce interfaces to patch kernel code")
    Cc: stable@vger.kernel.org
    Signed-off-by: Palmer Dabbelt <palmer@rivosinc.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit c3d50b356e4ae18bdd868e5a4d7beffa61bd5c78
Author: Shin'ichiro Kawasaki <shinichiro.kawasaki@wdc.com>
Date:   Tue Apr 12 16:56:36 2022 +0900

    bus: fsl-mc-msi: Fix MSI descriptor mutex lock for msi_first_desc()
    
    commit c7d2f89fea26c84d5accc55d9976dd7e5305e63a upstream.
    
    Commit e8604b1447b4 introduced a call to the helper function
    msi_first_desc(), which needs MSI descriptor mutex lock before
    call. However, the required mutex lock was not added. This results in
    lockdep assertion:
    
     WARNING: CPU: 4 PID: 119 at kernel/irq/msi.c:274 msi_first_desc+0xd0/0x10c
      msi_first_desc+0xd0/0x10c
      fsl_mc_msi_domain_alloc_irqs+0x7c/0xc0
      fsl_mc_populate_irq_pool+0x80/0x3cc
    
    Fix this by adding the mutex lock and unlock around the function call.
    
    Fixes: e8604b1447b4 ("bus: fsl-mc-msi: Simplify MSI descriptor handling")
    Signed-off-by: Shin'ichiro Kawasaki <shinichiro.kawasaki@wdc.com>
    Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
    Reviewed-by: Damien Le Moal <damien.lemoal@opensource.wdc.com>
    Cc: stable@vger.kernel.org
    Link: https://lore.kernel.org/r/20220412075636.755454-1-shinichiro.kawasaki@wdc.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 85f71394d8ded2df5bf06de040b6d9e9ac28b26e
Author: Mikulas Patocka <mpatocka@redhat.com>
Date:   Wed Apr 27 11:26:40 2022 -0400

    hex2bin: fix access beyond string end
    
    commit e4d8a29997731b3bb14059024b24df9f784288d0 upstream.
    
    If we pass too short string to "hex2bin" (and the string size without
    the terminating NUL character is even), "hex2bin" reads one byte after
    the terminating NUL character.  This patch fixes it.
    
    Note that hex_to_bin returns -1 on error and hex2bin return -EINVAL on
    error - so we can't just return the variable "hi" or "lo" on error.
    This inconsistency may be fixed in the next merge window, but for the
    purpose of fixing this bug, we just preserve the existing behavior and
    return -1 and -EINVAL.
    
    Signed-off-by: Mikulas Patocka <mpatocka@redhat.com>
    Reviewed-by: Andy Shevchenko <andy.shevchenko@gmail.com>
    Fixes: b78049831ffe ("lib: add error checking to hex2bin")
    Cc: stable@vger.kernel.org
    Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit a00f062555da3591291507e7c39559e82fcd202d
Author: Mikulas Patocka <mpatocka@redhat.com>
Date:   Mon Apr 25 08:07:48 2022 -0400

    hex2bin: make the function hex_to_bin constant-time
    
    commit e5be15767e7e284351853cbaba80cde8620341fb upstream.
    
    The function hex2bin is used to load cryptographic keys into device
    mapper targets dm-crypt and dm-integrity.  It should take constant time
    independent on the processed data, so that concurrently running
    unprivileged code can't infer any information about the keys via
    microarchitectural convert channels.
    
    This patch changes the function hex_to_bin so that it contains no
    branches and no memory accesses.
    
    Note that this shouldn't cause performance degradation because the size
    of the new function is the same as the size of the old function (on
    x86-64) - and the new function causes no branch misprediction penalties.
    
    I compile-tested this function with gcc on aarch64 alpha arm hppa hppa64
    i386 ia64 m68k mips32 mips64 powerpc powerpc64 riscv sh4 s390x sparc32
    sparc64 x86_64 and with clang on aarch64 arm hexagon i386 mips32 mips64
    powerpc powerpc64 s390x sparc32 sparc64 x86_64 to verify that there are
    no branches in the generated code.
    
    Signed-off-by: Mikulas Patocka <mpatocka@redhat.com>
    Cc: stable@vger.kernel.org
    Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 915a8a01ba787e27c1769b5d96c870168403ebba
Author: Jaegeuk Kim <jaegeuk@kernel.org>
Date:   Thu Apr 21 16:47:02 2022 -0700

    f2fs: should not truncate blocks during roll-forward recovery
    
    commit 4d8ec91208196e0e19195f1e7d6be9de5873f242 upstream.
    
    If the file preallocated blocks and fsync'ed, we should not truncate them during
    roll-forward recovery which will recover i_size correctly back.
    
    Fixes: d4dd19ec1ea0 ("f2fs: do not expose unwritten blocks to user by DIO")
    Cc: <stable@vger.kernel.org> # 5.17+
    Signed-off-by: Jaegeuk Kim <jaegeuk@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 5c3b407bd1f3f6ae77876775c109380bb701e1b1
Author: Krzysztof Kozlowski <krzysztof.kozlowski@linaro.org>
Date:   Wed Apr 20 16:14:07 2022 +0200

    pinctrl: samsung: fix missing GPIOLIB on ARM64 Exynos config
    
    commit ac875df4d854ab13d9c4af682a1837a1214fecec upstream.
    
    The Samsung pinctrl drivers depend on OF_GPIO, which is part of GPIOLIB.
    ARMv7 Exynos platform selects GPIOLIB and Samsung pinctrl drivers. ARMv8
    Exynos selects only the latter leading to possible wrong configuration
    on ARMv8 build:
    
      WARNING: unmet direct dependencies detected for PINCTRL_EXYNOS
        Depends on [n]: PINCTRL [=y] && OF_GPIO [=n] && (ARCH_EXYNOS [=y] || ARCH_S5PV210 || COMPILE_TEST [=y])
        Selected by [y]:
        - ARCH_EXYNOS [=y]
    
    Always select the GPIOLIB from the Samsung pinctrl drivers to fix the
    issue.  This requires removing of OF_GPIO dependency (to avoid recursive
    dependency), so add dependency on OF for COMPILE_TEST cases.
    
    Reported-by: Necip Fazil Yildiran <fazilyildiran@gmail.com>
    Fixes: eed6b3eb20b9 ("arm64: Split out platform options to separate Kconfig")
    Cc: <stable@vger.kernel.org>
    Signed-off-by: Krzysztof Kozlowski <krzysztof.kozlowski@linaro.org>
    Reviewed-by: Arnd Bergmann <arnd@arndb.de>
    Link: https://lore.kernel.org/r/20220420141407.470955-1-krzysztof.kozlowski@linaro.org
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 07672ac9c5b632533e99f94564abff851acd69dd
Author: Johan Hovold <johan@kernel.org>
Date:   Mon Feb 28 11:16:17 2022 +0100

    arm64: dts: imx8mm-venice: fix spi2 pin configuration
    
    commit dc900431337f5f861e3cc47ec5be5a69db40ee34 upstream.
    
    Due to what looks like a copy-paste error, the ECSPI2_MISO pad is not
    muxed for SPI mode and causes reads from a slave-device connected to the
    SPI header to always return zero.
    
    Configure the ECSPI2_MISO pad for SPI mode on the gw71xx, gw72xx and
    gw73xx families of boards that got this wrong.
    
    Fixes: 6f30b27c5ef5 ("arm64: dts: imx8mm: Add Gateworks i.MX 8M Mini Development Kits")
    Cc: stable@vger.kernel.org      # 5.12
    Cc: Tim Harvey <tharvey@gateworks.com>
    Signed-off-by: Johan Hovold <johan@kernel.org>
    Acked-by: Tim Harvey <tharvey@gateworks.com>
    Signed-off-by: Shawn Guo <shawnguo@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 38898b75fdd620d10858deecdc8e8983680ef6f0
Author: Manivannan Sadhasivam <mani@kernel.org>
Date:   Fri Apr 8 20:30:39 2022 +0530

    bus: mhi: host: pci_generic: Flush recovery worker during freeze
    
    commit c38f83bae4037023827c85e045841d0421f85034 upstream.
    
    It is possible that the recovery work might be running while the freeze
    gets executed (during hibernation etc.,). Currently, we don't powerdown
    the stack if it is not up but if the recovery work completes after freeze,
    then the device will be up afterwards. This will not be a sane situation.
    
    So let's flush the recovery worker before trying to powerdown the device.
    
    Cc: stable@vger.kernel.org
    Fixes: 5f0c2ee1fe8d ("bus: mhi: pci-generic: Fix hibernation")
    Reported-by: Bhaumik Vasav Bhatt <quic_bbhatt@quicinc.com>
    Reviewed-by: Bhaumik Vasav Bhatt <quic_bbhatt@quicinc.com>
    Link: https://lore.kernel.org/r/20220408150039.17297-1-manivannan.sadhasivam@linaro.org
    Signed-off-by: Manivannan Sadhasivam <manivannan.sadhasivam@linaro.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 8269211f2c65d8f710783d7f702ef5bac59d69ab
Author: Manivannan Sadhasivam <mani@kernel.org>
Date:   Tue Apr 5 18:29:07 2022 +0530

    bus: mhi: host: pci_generic: Add missing poweroff() PM callback
    
    commit e64d5fa5044f225ac87d96a7e4be11389999c4c6 upstream.
    
    During hibernation process, once thaw() stage completes, the MHI endpoint
    devices will be in M0 state post recovery. After that, the devices will be
    powered down so that the system can enter the target sleep state. During
    this stage, the PCI core will put the devices in D3hot. But this transition
    is allowed by the MHI spec. The devices can only enter D3hot when it is in
    M3 state.
    
    So for fixing this issue, let's add the poweroff() callback that will get
    executed before putting the system in target sleep state during
    hibernation. This callback will power down the device properly so that it
    could be restored during restore() or thaw() stage.
    
    Cc: stable@vger.kernel.org
    Fixes: 5f0c2ee1fe8d ("bus: mhi: pci-generic: Fix hibernation")
    Reported-by: Hemant Kumar <quic_hemantk@quicinc.com>
    Suggested-by: Hemant Kumar <quic_hemantk@quicinc.com>
    Link: https://lore.kernel.org/r/20220405125907.5644-1-manivannan.sadhasivam@linaro.org
    Signed-off-by: Manivannan Sadhasivam <manivannan.sadhasivam@linaro.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 1cb4f975eed9a48d6f12cc0bbf8f0cbe772f6ae3
Author: Xiubo Li <xiubli@redhat.com>
Date:   Thu Apr 14 09:07:21 2022 +0800

    ceph: fix possible NULL pointer dereference for req->r_session
    
    commit 7acae6183cf37c48b8da48bbbdb78820fb3913f3 upstream.
    
    The request will be inserted into the ci->i_unsafe_dirops before
    assigning the req->r_session, so it's possible that we will hit
    NULL pointer dereference bug here.
    
    Cc: stable@vger.kernel.org
    URL: https://tracker.ceph.com/issues/55327
    Signed-off-by: Xiubo Li <xiubli@redhat.com>
    Reviewed-by: Jeff Layton <jlayton@kernel.org>
    Tested-by: Aaron Tomlin <atomlin@redhat.com>
    Signed-off-by: Ilya Dryomov <idryomov@gmail.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit b1032e94a3c8a861dce875b6c468adf9e2622e9c
Author: Darren Hart <darren@os.amperecomputing.com>
Date:   Mon Apr 11 13:53:34 2022 -0700

    topology: make core_mask include at least cluster_siblings
    
    commit db1e59483dfd8d4e956575302520bb8f7e20c79b upstream.
    
    Ampere Altra defines CPU clusters in the ACPI PPTT. They share a Snoop
    Control Unit, but have no shared CPU-side last level cache.
    
    cpu_coregroup_mask() will return a cpumask with weight 1, while
    cpu_clustergroup_mask() will return a cpumask with weight 2.
    
    As a result, build_sched_domain() will BUG() once per CPU with:
    
    BUG: arch topology borken
    the CLS domain not a subset of the MC domain
    
    The MC level cpumask is then extended to that of the CLS child, and is
    later removed entirely as redundant. This sched domain topology is an
    improvement over previous topologies, or those built without
    SCHED_CLUSTER, particularly for certain latency sensitive workloads.
    With the current scheduler model and heuristics, this is a desirable
    default topology for Ampere Altra and Altra Max system.
    
    Rather than create a custom sched domains topology structure and
    introduce new logic in arch/arm64 to detect these systems, update the
    core_mask so coregroup is never a subset of clustergroup, extending it
    to cluster_siblings if necessary. Only do this if CONFIG_SCHED_CLUSTER
    is enabled to avoid also changing the topology (MC) when
    CONFIG_SCHED_CLUSTER is disabled.
    
    This has the added benefit over a custom topology of working for both
    symmetric and asymmetric topologies. It does not address systems where
    the CLUSTER topology is above a populated MC topology, but these are not
    considered today and can be addressed separately if and when they
    appear.
    
    The final sched domain topology for a 2 socket Ampere Altra system is
    unchanged with or without CONFIG_SCHED_CLUSTER, and the BUG is avoided:
    
    For CPU0:
    
    CONFIG_SCHED_CLUSTER=y
    CLS  [0-1]
    DIE  [0-79]
    NUMA [0-159]
    
    CONFIG_SCHED_CLUSTER is not set
    DIE  [0-79]
    NUMA [0-159]
    
    Cc: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
    Cc: "Rafael J. Wysocki" <rafael@kernel.org>
    Cc: Catalin Marinas <catalin.marinas@arm.com>
    Cc: Will Deacon <will@kernel.org>
    Cc: Peter Zijlstra <peterz@infradead.org>
    Cc: Vincent Guittot <vincent.guittot@linaro.org>
    Cc: D. Scott Phillips <scott@os.amperecomputing.com>
    Cc: Ilkka Koskinen <ilkka@os.amperecomputing.com>
    Cc: <stable@vger.kernel.org> # 5.16.x
    Suggested-by: Barry Song <song.bao.hua@hisilicon.com>
    Reviewed-by: Barry Song <song.bao.hua@hisilicon.com>
    Reviewed-by: Dietmar Eggemann <dietmar.eggemann@arm.com>
    Acked-by: Sudeep Holla <sudeep.holla@arm.com>
    Signed-off-by: Darren Hart <darren@os.amperecomputing.com>
    Link: https://lore.kernel.org/r/c8fe9fce7c86ed56b4c455b8c902982dc2303868.1649696956.git.darren@os.amperecomputing.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 075764eaddc3e750efeb1d9ad9393d031472258d
Author: Wang Qing <wangqing@vivo.com>
Date:   Sun Apr 10 19:36:19 2022 -0700

    arch_topology: Do not set llc_sibling if llc_id is invalid
    
    commit 1dc9f1a66e1718479e1c4f95514e1750602a3cb9 upstream.
    
    When ACPI is not enabled, cpuid_topo->llc_id = cpu_topo->llc_id = -1, which
    will set llc_sibling 0xff(...), this is misleading.
    
    Don't set llc_sibling(default 0) if we don't know the cache topology.
    
    Reviewed-by: Sudeep Holla <sudeep.holla@arm.com>
    Signed-off-by: Wang Qing <wangqing@vivo.com>
    Fixes: 37c3ec2d810f ("arm64: topology: divorce MC scheduling domain from core_siblings")
    Cc: stable <stable@vger.kernel.org>
    Link: https://lore.kernel.org/r/1649644580-54626-1-git-send-email-wangqing@vivo.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 9ee7148fa1c05aa4dc16f6d53a3e322700f293dd
Author: Christophe Leroy <christophe.leroy@csgroup.eu>
Date:   Wed Mar 23 11:51:55 2022 +0100

    eeprom: at25: Use DMA safe buffers
    
    commit 5b47b751b760ee1c74a51660fd096aa148a362cd upstream.
    
    Reading EEPROM fails with following warning:
    
    [   16.357496] ------------[ cut here ]------------
    [   16.357529] fsl_spi b01004c0.spi: rejecting DMA map of vmalloc memory
    [   16.357698] WARNING: CPU: 0 PID: 371 at include/linux/dma-mapping.h:326 fsl_spi_cpm_bufs+0x2a0/0x2d8
    [   16.357775] CPU: 0 PID: 371 Comm: od Not tainted 5.16.11-s3k-dev-01743-g19beecbfe9d6-dirty #109
    [   16.357806] NIP:  c03fbc9c LR: c03fbc9c CTR: 00000000
    [   16.357825] REGS: e68d9b20 TRAP: 0700   Not tainted  (5.16.11-s3k-dev-01743-g19beecbfe9d6-dirty)
    [   16.357849] MSR:  00029032 <EE,ME,IR,DR,RI>  CR: 24002282  XER: 00000000
    [   16.357931]
    [   16.357931] GPR00: c03fbc9c e68d9be0 c26d06a0 00000039 00000001 c0d36364 c0e96428 00000027
    [   16.357931] GPR08: 00000001 00000000 00000023 3fffc000 24002282 100d3dd6 100a2ffc 00000000
    [   16.357931] GPR16: 100cd280 100b0000 00000000 aff54f7e 100d0000 100d0000 00000001 100cf328
    [   16.357931] GPR24: 100cf328 00000000 00000003 e68d9e30 c156b410 e67ab4c0 e68d9d38 c24ab278
    [   16.358253] NIP [c03fbc9c] fsl_spi_cpm_bufs+0x2a0/0x2d8
    [   16.358292] LR [c03fbc9c] fsl_spi_cpm_bufs+0x2a0/0x2d8
    [   16.358325] Call Trace:
    [   16.358336] [e68d9be0] [c03fbc9c] fsl_spi_cpm_bufs+0x2a0/0x2d8 (unreliable)
    [   16.358388] [e68d9c00] [c03fcb44] fsl_spi_bufs.isra.0+0x94/0x1a0
    [   16.358436] [e68d9c20] [c03fd970] fsl_spi_do_one_msg+0x254/0x3dc
    [   16.358483] [e68d9cb0] [c03f7e50] __spi_pump_messages+0x274/0x8a4
    [   16.358529] [e68d9ce0] [c03f9d30] __spi_sync+0x344/0x378
    [   16.358573] [e68d9d20] [c03fb52c] spi_sync+0x34/0x60
    [   16.358616] [e68d9d30] [c03b4dec] at25_ee_read+0x138/0x1a8
    [   16.358667] [e68d9e50] [c04a8fb8] bin_attr_nvmem_read+0x98/0x110
    [   16.358725] [e68d9e60] [c0204b14] kernfs_fop_read_iter+0xc0/0x1fc
    [   16.358774] [e68d9e80] [c0168660] vfs_read+0x284/0x410
    [   16.358821] [e68d9f00] [c016925c] ksys_read+0x6c/0x11c
    [   16.358863] [e68d9f30] [c00160e0] ret_from_syscall+0x0/0x28
    ...
    [   16.359608] ---[ end trace a4ce3e34afef0cb5 ]---
    [   16.359638] fsl_spi b01004c0.spi: unable to map tx dma
    
    This is due to the AT25 driver using buffers on stack, which is not
    possible with CONFIG_VMAP_STACK.
    
    As mentionned in kernel Documentation (Documentation/spi/spi-summary.rst):
    
      - Follow standard kernel rules, and provide DMA-safe buffers in
        your messages.  That way controller drivers using DMA aren't forced
        to make extra copies unless the hardware requires it (e.g. working
        around hardware errata that force the use of bounce buffering).
    
    Modify the driver to use a buffer located in the at25 device structure
    which is allocated via kmalloc during probe.
    
    Protect writes in this new buffer with the driver's mutex.
    
    Fixes: b587b13a4f67 ("[PATCH] SPI eeprom driver")
    Cc: stable <stable@kernel.org>
    Signed-off-by: Christophe Leroy <christophe.leroy@csgroup.eu>
    Link: https://lore.kernel.org/r/230a9486fc68ea0182df46255e42a51099403642.1648032613.git.christophe.leroy@csgroup.eu
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 8634eeba1b0c1ee0ecdd91f8962385fd9d5f6d86
Author: Maciej W. Rozycki <macro@orcam.me.uk>
Date:   Mon Apr 18 16:27:16 2022 +0100

    serial: 8250: Correct the clock for EndRun PTP/1588 PCIe device
    
    commit 637674fa40059cddcc3ad2212728965072f62ea3 upstream.
    
    The EndRun PTP/1588 dual serial port device is based on the Oxford
    Semiconductor OXPCIe952 UART device with the PCI vendor:device ID set
    for EndRun Technologies and is therefore driven by a fixed 62.5MHz clock
    input derived from the 100MHz PCI Express clock.  The clock rate is
    divided by the oversampling rate of 16 as it is supplied to the baud
    rate generator, yielding the baud base of 3906250.
    
    Replace the incorrect baud base of 4000000 with the right value of
    3906250 then, complementing commit 6cbe45d8ac93 ("serial: 8250: Correct
    the clock for OxSemi PCIe devices").
    
    Signed-off-by: Maciej W. Rozycki <macro@orcam.me.uk>
    Cc: stable <stable@kernel.org>
    Fixes: 1bc8cde46a159 ("8250_pci: Added driver for Endrun Technologies PTP PCIe card.")
    Reviewed-by: Andy Shevchenko <andy.shevchenko@gmail.com>
    Link: https://lore.kernel.org/r/alpine.DEB.2.21.2204181515270.9383@angie.orcam.me.uk
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 3ea414d55be4568e530ab5ad1e3ea81d1d62d92e
Author: Maciej W. Rozycki <macro@orcam.me.uk>
Date:   Mon Apr 18 16:27:10 2022 +0100

    serial: 8250: Also set sticky MCR bits in console restoration
    
    commit 6e6eebdf5e2455f089ccd000754a0deaeb79af82 upstream.
    
    Sticky MCR bits are lost in console restoration if console suspending
    has been disabled.  This currently affects the AFE bit, which works in
    combination with RTS which we set, so we want to make sure the UART
    retains control of its FIFO where previously requested.  Also specific
    drivers may need other bits in the future.
    
    Signed-off-by: Maciej W. Rozycki <macro@orcam.me.uk>
    Fixes: 4516d50aabed ("serial: 8250: Use canary to restart console after suspend")
    Cc: stable@vger.kernel.org # v4.0+
    Reviewed-by: Andy Shevchenko <andy.shevchenko@gmail.com>
    Link: https://lore.kernel.org/r/alpine.DEB.2.21.2204181518490.9383@angie.orcam.me.uk
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 9f0908837b82de197bae70c13c5cf2aba0642f8b
Author: Lino Sanfilippo <LinoSanfilippo@gmx.de>
Date:   Sat Apr 9 01:35:02 2022 +0200

    serial: amba-pl011: do not time out prematurely when draining tx fifo
    
    commit 0e4deb56b0c625efdb70c94f150429e2f2a16fa1 upstream.
    
    The current timeout for draining the tx fifo in RS485 mode is calculated by
    multiplying the time it takes to transmit one character (with the given
    baud rate) with the maximal number of characters in the tx queue.
    
    This timeout is too short for two reasons:
    First when calculating the time to transmit one character integer division
    is used which may round down the result in case of a remainder of the
    division.
    
    Fix this by rounding up the division result.
    
    Second the hardware may need additional time (e.g for first putting the
    characters from the fifo into the shift register) before the characters are
    actually put onto the wire.
    
    To be on the safe side double the current maximum number of iterations
    that are used to wait for the queue draining.
    
    Fixes: 8d479237727c ("serial: amba-pl011: add RS485 support")
    Cc: stable@vger.kernel.org
    Signed-off-by: Lino Sanfilippo <LinoSanfilippo@gmx.de>
    Link: https://lore.kernel.org/r/20220408233503.7251-1-LinoSanfilippo@gmx.de
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 46c4ce3a52384041b3175c4ab19352985cf675b6
Author: Johan Hovold <johan@kernel.org>
Date:   Mon Apr 11 10:19:57 2022 +0200

    serial: imx: fix overrun interrupts in DMA mode
    
    commit 3ee82c6e41f3d2212647ce0bc5a05a0f69097824 upstream.
    
    Commit 76821e222c18 ("serial: imx: ensure that RX irqs are off if RX is
    off") accidentally enabled overrun interrupts unconditionally when
    deferring DMA enable until after the receiver has been enabled during
    startup.
    
    Fix this by using the DMA-initialised instead of DMA-enabled flag to
    determine whether overrun interrupts should be enabled.
    
    Note that overrun interrupts are already accounted for in
    imx_uart_clear_rx_errors() when using DMA since commit 41d98b5da92f
    ("serial: imx-serial - update RX error counters when DMA is used").
    
    Fixes: 76821e222c18 ("serial: imx: ensure that RX irqs are off if RX is off")
    Cc: stable@vger.kernel.org      # 4.17
    Cc: Uwe Kleine-König <u.kleine-koenig@pengutronix.de>
    Signed-off-by: Johan Hovold <johan@kernel.org>
    Link: https://lore.kernel.org/r/20220411081957.7846-1-johan@kernel.org
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 62f8c07d84064940020c7b8a41cc8d26b68e8262
Author: Alessandro Astone <ales.astone@gmail.com>
Date:   Fri Apr 15 14:00:15 2022 +0200

    binder: Address corner cases in deferred copy and fixup
    
    commit 2d1746e3fda0c3612143d7c06f8e1d1830c13e23 upstream.
    
    When handling BINDER_TYPE_FDA object we are pushing a parent fixup
    with a certain skip_size but no scatter-gather copy object, since
    the copy is handled standalone.
    If BINDER_TYPE_FDA is the last children the scatter-gather copy
    loop will never stop to skip it, thus we are left with an item in
    the parent fixup list. This will trigger the BUG_ON().
    
    This is reproducible in android when playing a video.
    We receive a transaction that looks like this:
        obj[0] BINDER_TYPE_PTR, parent
        obj[1] BINDER_TYPE_PTR, child
        obj[2] BINDER_TYPE_PTR, child
        obj[3] BINDER_TYPE_FDA, child
    
    Fixes: 09184ae9b575 ("binder: defer copies of pre-patched txn data")
    Acked-by: Todd Kjos <tkjos@google.com>
    Cc: stable <stable@kernel.org>
    Signed-off-by: Alessandro Astone <ales.astone@gmail.com>
    Link: https://lore.kernel.org/r/20220415120015.52684-2-ales.astone@gmail.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 3bf989a7be204470c84534a5b75a8928a7ebe60d
Author: Alessandro Astone <ales.astone@gmail.com>
Date:   Fri Apr 15 14:00:14 2022 +0200

    binder: Gracefully handle BINDER_TYPE_FDA objects with num_fds=0
    
    commit ef38de9217a04c9077629a24652689d8fdb4c6c6 upstream.
    
    Some android userspace is sending BINDER_TYPE_FDA objects with
    num_fds=0. Like the previous patch, this is reproducible when
    playing a video.
    
    Before commit 09184ae9b575 BINDER_TYPE_FDA objects with num_fds=0
    were 'correctly handled', as in no fixup was performed.
    
    After commit 09184ae9b575 we aggregate fixup and skip regions in
    binder_ptr_fixup structs and distinguish between the two by using
    the skip_size field: if it's 0, then it's a fixup, otherwise skip.
    When processing BINDER_TYPE_FDA objects with num_fds=0 we add a
    skip region of skip_size=0, and this causes issues because now
    binder_do_deferred_txn_copies will think this was a fixup region.
    
    To address that, return early from binder_translate_fd_array to
    avoid adding an empty skip region.
    
    Fixes: 09184ae9b575 ("binder: defer copies of pre-patched txn data")
    Acked-by: Todd Kjos <tkjos@google.com>
    Cc: stable <stable@kernel.org>
    Signed-off-by: Alessandro Astone <ales.astone@gmail.com>
    Link: https://lore.kernel.org/r/20220415120015.52684-1-ales.astone@gmail.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 1ffcaff445b663d1967ff0005f5613c02de7b16a
Author: Minchan Kim <minchan@kernel.org>
Date:   Wed Apr 27 10:21:51 2022 -0700

    kernfs: fix NULL dereferencing in kernfs_remove
    
    commit ad8d869343ae4a07a2038a4ca923f699308c8323 upstream.
    
    kernfs_remove supported NULL kernfs_node param to bail out but revent
    per-fs lock change introduced regression that dereferencing the
    param without NULL check so kernel goes crash.
    
    This patch checks the NULL kernfs_node in kernfs_remove and if so,
    just return.
    
    Quote from bug report by Jirka
    
    ```
    The bug is triggered by running NAS Parallel benchmark suite on
    SuperMicro servers with 2x Xeon(R) Gold 6126 CPU. Here is the error
    log:
    
    [  247.035564] BUG: kernel NULL pointer dereference, address: 0000000000000008
    [  247.036009] #PF: supervisor read access in kernel mode
    [  247.036009] #PF: error_code(0x0000) - not-present page
    [  247.036009] PGD 0 P4D 0
    [  247.036009] Oops: 0000 [#1] PREEMPT SMP PTI
    [  247.058060] CPU: 1 PID: 6546 Comm: umount Not tainted
    5.16.0393c3714081a53795bbff0e985d24146def6f57f+ #16
    [  247.058060] Hardware name: Supermicro Super Server/X11DDW-L, BIOS
    2.0b 03/07/2018
    [  247.058060] RIP: 0010:kernfs_remove+0x8/0x50
    [  247.058060] Code: 4c 89 e0 5b 5d 41 5c 41 5d 41 5e c3 49 c7 c4 f4
    ff ff ff eb b2 66 66 2e 0f 1f 84 00 00 00 00 00 66 90 0f 1f 44 00 00
    41 54 55 <48> 8b 47 08 48 89 fd 48 85 c0 48 0f 44 c7 4c 8b 60 50 49 83
    c4 60
    [  247.058060] RSP: 0018:ffffbbfa48a27e48 EFLAGS: 00010246
    [  247.058060] RAX: 0000000000000001 RBX: ffffffff89e31f98 RCX: 0000000080200018
    [  247.058060] RDX: 0000000080200019 RSI: fffff6760786c900 RDI: 0000000000000000
    [  247.058060] RBP: ffffffff89e31f98 R08: ffff926b61b24d00 R09: 0000000080200018
    [  247.122048] R10: ffff926b61b24d00 R11: ffff926a8040c000 R12: ffff927bd09a2000
    [  247.122048] R13: ffffffff89e31fa0 R14: dead000000000122 R15: dead000000000100
    [  247.122048] FS:  00007f01be0a8c40(0000) GS:ffff926fa8e40000(0000)
    knlGS:0000000000000000
    [  247.122048] CS:  0010 DS: 0000 ES: 0000 CR0: 0000000080050033
    [  247.122048] CR2: 0000000000000008 CR3: 00000001145c6003 CR4: 00000000007706e0
    [  247.122048] DR0: 0000000000000000 DR1: 0000000000000000 DR2: 0000000000000000
    [  247.122048] DR3: 0000000000000000 DR6: 00000000fffe0ff0 DR7: 0000000000000400
    [  247.122048] PKRU: 55555554
    [  247.122048] Call Trace:
    [  247.122048]  <TASK>
    [  247.122048]  rdt_kill_sb+0x29d/0x350
    [  247.122048]  deactivate_locked_super+0x36/0xa0
    [  247.122048]  cleanup_mnt+0x131/0x190
    [  247.122048]  task_work_run+0x5c/0x90
    [  247.122048]  exit_to_user_mode_prepare+0x229/0x230
    [  247.122048]  syscall_exit_to_user_mode+0x18/0x40
    [  247.122048]  do_syscall_64+0x48/0x90
    [  247.122048]  entry_SYSCALL_64_after_hwframe+0x44/0xae
    [  247.122048] RIP: 0033:0x7f01be2d735b
    ```
    
    Link: https://bugzilla.kernel.org/show_bug.cgi?id=215696
    Link: https://lore.kernel.org/lkml/CAE4VaGDZr_4wzRn2___eDYRtmdPaGGJdzu_LCSkJYuY9BEO3cw@mail.gmail.com/
    Fixes: 393c3714081a (kernfs: switch global kernfs_rwsem lock to per-fs lock)
    Cc: stable@vger.kernel.org
    Reported-by: Jirka Hladky <jhladky@redhat.com>
    Tested-by: Jirka Hladky <jhladky@redhat.com>
    Acked-by: Tejun Heo <tj@kernel.org>
    Signed-off-by: Minchan Kim <minchan@kernel.org>
    Link: https://lore.kernel.org/r/20220427172152.3505364-1-minchan@kernel.org
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit f564780d4c2035e9517c68ded4d4079acc8023dc
Author: Sean Anderson <sean.anderson@seco.com>
Date:   Mon Apr 25 13:14:09 2022 -0400

    usb: phy: generic: Get the vbus supply
    
    commit 03e607cbb2931374db1825f371e9c7f28526d3f4 upstream.
    
    While support for working with a vbus was added, the regulator was never
    actually gotten (despite what was documented). Fix this by actually
    getting the supply from the device tree.
    
    Fixes: 7acc9973e3c4 ("usb: phy: generic: add vbus support")
    Cc: stable <stable@kernel.org>
    Signed-off-by: Sean Anderson <sean.anderson@seco.com>
    Link: https://lore.kernel.org/r/20220425171412.1188485-3-sean.anderson@seco.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 685edaf177be54220c00884f9f723387de001cb4
Author: Pawel Laszczak <pawell@cadence.com>
Date:   Tue Mar 29 10:46:05 2022 +0200

    usb: cdns3: Fix issue for clear halt endpoint
    
    commit b3fa25de31fb7e9afebe9599b8ff32eda13d7c94 upstream.
    
    Path fixes bug which occurs during resetting endpoint in
    __cdns3_gadget_ep_clear_halt function. During resetting endpoint
    controller will change HW/DMA owned TRB. It set Abort flag in
    trb->control and will change trb->length field. If driver want
    to use the aborted trb it must update the changed field in
    TRB.
    
    Fixes: 7733f6c32e36 ("usb: cdns3: Add Cadence USB3 DRD Driver")
    cc: <stable@vger.kernel.org>
    Acked-by: Peter Chen <peter.chen@kernel.org>
    Signed-off-by: Pawel Laszczak <pawell@cadence.com>
    Link: https://lore.kernel.org/r/20220329084605.4022-1-pawell@cadence.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 2bc325ec2004aea87c568f6b98af53172115b0df
Author: Heikki Krogerus <heikki.krogerus@linux.intel.com>
Date:   Mon Apr 25 13:35:18 2022 +0300

    usb: dwc3: pci: add support for the Intel Meteor Lake-P
    
    commit 973e0f7a847ef13ade840d4c30729ce329a66895 upstream.
    
    This patch adds the necessary PCI IDs for Intel Meteor Lake-P
    devices.
    
    Signed-off-by: Heikki Krogerus <heikki.krogerus@linux.intel.com>
    Cc: stable <stable@kernel.org>
    Link: https://lore.kernel.org/r/20220425103518.44028-1-heikki.krogerus@linux.intel.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit ac4900d831ad23a07f9211701f7d8cc03783a3ce
Author: Thinh Nguyen <Thinh.Nguyen@synopsys.com>
Date:   Fri Apr 22 17:36:28 2022 -0700

    usb: dwc3: gadget: Return proper request status
    
    commit c7428dbddcf4ea1919e1c8e15f715b94ca359268 upstream.
    
    If the user sets the usb_request's no_interrupt, then there will be no
    completion event for the request. Currently the driver incorrectly uses
    the event status of a different request to report the status for a
    request with no_interrupt. The dwc3 driver needs to check the TRB status
    associated with the request when reporting its status.
    
    Note: this is only applicable to missed_isoc TRB completion status, but
    the other status are also listed for completeness/documentation.
    
    Fixes: 6d8a019614f3 ("usb: dwc3: gadget: check for Missed Isoc from event status")
    Cc: <stable@vger.kernel.org>
    Signed-off-by: Thinh Nguyen <Thinh.Nguyen@synopsys.com>
    Link: https://lore.kernel.org/r/db2c80108286cfd108adb05bad52138b78d7c3a7.1650673655.git.Thinh.Nguyen@synopsys.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 9915ce17c420d594f99dd870a621949e5c9a6791
Author: Thinh Nguyen <Thinh.Nguyen@synopsys.com>
Date:   Thu Apr 21 19:33:56 2022 -0700

    usb: dwc3: core: Only handle soft-reset in DCTL
    
    commit f4fd84ae0765a80494b28c43b756a95100351a94 upstream.
    
    Make sure not to set run_stop bit or link state change request while
    initiating soft-reset. Register read-modify-write operation may
    unintentionally start the controller before the initialization completes
    with its previous DCTL value, which can cause initialization failure.
    
    Fixes: f59dcab17629 ("usb: dwc3: core: improve reset sequence")
    Cc: <stable@vger.kernel.org>
    Signed-off-by: Thinh Nguyen <Thinh.Nguyen@synopsys.com>
    Link: https://lore.kernel.org/r/6aecbd78328f102003d40ccf18ceeebd411d3703.1650594792.git.Thinh.Nguyen@synopsys.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 4377eddfcc07eecce9b04130e8eb47daaafa688a
Author: Thinh Nguyen <Thinh.Nguyen@synopsys.com>
Date:   Mon Apr 11 18:33:47 2022 -0700

    usb: dwc3: core: Fix tx/rx threshold settings
    
    commit f28ad9069363dec7deb88032b70612755eed9ee6 upstream.
    
    The current driver logic checks against 0 to determine whether the
    periodic tx/rx threshold settings are set, but we may get bogus values
    from uninitialized variables if no device property is set. Properly
    default these variables to 0.
    
    Fixes: 938a5ad1d305 ("usb: dwc3: Check for ESS TX/RX threshold config")
    Cc: <stable@vger.kernel.org>
    Signed-off-by: Thinh Nguyen <Thinh.Nguyen@synopsys.com>
    Link: https://lore.kernel.org/r/cccfce990b11b730b0dae42f9d217dc6fb988c90.1649727139.git.Thinh.Nguyen@synopsys.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit d61d85e89b1cc3aa09a9691eb655dd3a366bbe21
Author: Sven Peter <sven@svenpeter.dev>
Date:   Mon Apr 11 17:53:00 2022 +0200

    usb: dwc3: Try usb-role-switch first in dwc3_drd_init
    
    commit ab7aa2866d295438dc60522f85c5421c6b4f1507 upstream.
    
    If the PHY controller node has a "port" dwc3 tries to find an
    extcon device even when "usb-role-switch" is present. This happens
    because dwc3_get_extcon() sees that "port" node and then calls
    extcon_find_edev_by_node() which will always return EPROBE_DEFER
    in that case.
    
    On the other hand, even if an extcon was present and dwc3_get_extcon()
    was successful it would still be ignored in favor of "usb-role-switch".
    
    Let's just first check if "usb-role-switch" is configured in the device
    tree and directly use it instead and only try to look for an extcon
    device otherwise.
    
    Fixes: 8a0a13799744 ("usb: dwc3: Registering a role switch in the DRD code.")
    Cc: stable <stable@kernel.org>
    Signed-off-by: Sven Peter <sven@svenpeter.dev>
    Link: https://lore.kernel.org/r/20220411155300.9766-1-sven@svenpeter.dev
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 6e4aebe3439b52de9433f5d2fe70e035d1f50642
Author: Vijayavardhan Vennapusa <vvreddy@codeaurora.org>
Date:   Wed Apr 13 16:10:38 2022 -0500

    usb: gadget: configfs: clear deactivation flag in configfs_composite_unbind()
    
    commit bf95c4d4630c7a2c16e7b424fdea5177d9ce0864 upstream.
    
    If any function like UVC is deactivating gadget as part of composition
    switch which results in not calling pullup enablement, it is not getting
    enabled after switch to new composition due to this deactivation flag
    not cleared. This results in USB enumeration not happening after switch
    to new USB composition. Hence clear deactivation flag inside gadget
    structure in configfs_composite_unbind() before switch to new USB
    composition.
    
    Signed-off-by: Vijayavardhan Vennapusa <vvreddy@codeaurora.org>
    Signed-off-by: Dan Vacura <w36195@motorola.com>
    Cc: stable <stable@kernel.org>
    Link: https://lore.kernel.org/r/20220413211038.72797-1-w36195@motorola.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit e4e56ad1650798e14cf49cf4a799bd6f5e6fac0a
Author: Dan Vacura <w36195@motorola.com>
Date:   Thu Mar 31 13:40:23 2022 -0500

    usb: gadget: uvc: Fix crash when encoding data for usb request
    
    commit 71d471e3faf90c9674cadc7605ac719e82cb7fac upstream.
    
    During the uvcg_video_pump() process, if an error occurs and
    uvcg_queue_cancel() is called, the buffer queue will be cleared out, but
    the current marker (queue->buf_used) of the active buffer (no longer
    active) is not reset. On the next iteration of uvcg_video_pump() the
    stale buf_used count will be used and the logic of min((unsigned
    int)len, buf->bytesused - queue->buf_used) may incorrectly calculate a
    nbytes size, causing an invalid memory access.
    
    [80802.185460][  T315] configfs-gadget gadget: uvc: VS request completed
    with status -18.
    [80802.185519][  T315] configfs-gadget gadget: uvc: VS request completed
    with status -18.
    ...
    uvcg_queue_cancel() is called and the queue is cleared out, but the
    marker queue->buf_used is not reset.
    ...
    [80802.262328][ T8682] Unable to handle kernel paging request at virtual
    address ffffffc03af9f000
    ...
    ...
    [80802.263138][ T8682] Call trace:
    [80802.263146][ T8682]  __memcpy+0x12c/0x180
    [80802.263155][ T8682]  uvcg_video_pump+0xcc/0x1e0
    [80802.263165][ T8682]  process_one_work+0x2cc/0x568
    [80802.263173][ T8682]  worker_thread+0x28c/0x518
    [80802.263181][ T8682]  kthread+0x160/0x170
    [80802.263188][ T8682]  ret_from_fork+0x10/0x18
    [80802.263198][ T8682] Code: a8c12829 a88130cb a8c130
    
    Fixes: d692522577c0 ("usb: gadget/uvc: Port UVC webcam gadget to use videobuf2 framework")
    Cc: <stable@vger.kernel.org>
    Signed-off-by: Dan Vacura <w36195@motorola.com>
    Link: https://lore.kernel.org/r/20220331184024.23918-1-w36195@motorola.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit c2a5bd413aa5e519f14bd73b916c4cd03c1f6f95
Author: Heikki Krogerus <heikki.krogerus@linux.intel.com>
Date:   Tue Apr 5 16:48:24 2022 +0300

    usb: typec: ucsi: Fix role swapping
    
    commit eb5d7ff3cf0d55093c619b5ad107cd5c05ce8134 upstream.
    
    All attempts to swap the roles timed out because the
    completion was done without releasing the port lock. Fixing
    that by releasing the lock before starting to wait for the
    completion.
    
    Link: https://lore.kernel.org/linux-usb/037de7ac-e210-bdf5-ec7a-8c0c88a0be20@gmail.com/
    Fixes: ad74b8649bea ("usb: typec: ucsi: Preliminary support for alternate modes")
    Cc: stable@vger.kernel.org
    Reported-and-tested-by: Jia-Ju Bai <baijiaju1990@gmail.com>
    Signed-off-by: Heikki Krogerus <heikki.krogerus@linux.intel.com>
    Link: https://lore.kernel.org/r/20220405134824.68067-3-heikki.krogerus@linux.intel.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 1555917c042962d8360349ad3655fa7784aba6d1
Author: Heikki Krogerus <heikki.krogerus@linux.intel.com>
Date:   Tue Apr 5 16:48:23 2022 +0300

    usb: typec: ucsi: Fix reuse of completion structure
    
    commit e25adcca917d7e4cdc1dc6444d0692ffda7594bf upstream.
    
    The role swapping completion variable is reused, so it needs
    to be reinitialised every time. Otherwise it will be marked
    as done after the first time it's used and completing
    immediately.
    
    Link: https://lore.kernel.org/linux-usb/20220325203959.GA19752@jackp-linux.qualcomm.com/
    Fixes: 6df475f804e6 ("usb: typec: ucsi: Start using struct typec_operations")
    Cc: stable@vger.kernel.org
    Reported-and-suggested-by: Jack Pham <quic_jackp@quicinc.com>
    Signed-off-by: Heikki Krogerus <heikki.krogerus@linux.intel.com>
    Link: https://lore.kernel.org/r/20220405134824.68067-2-heikki.krogerus@linux.intel.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 66d4e795422d40ae66f4485539281da64fc80c5e
Author: Tasos Sahanidis <tasos@tasossah.com>
Date:   Fri Apr 1 00:47:00 2022 +0300

    usb: core: Don't hold the device lock while sleeping in do_proc_control()
    
    commit 0543e4e8852ef5ff1809ae62f1ea963e2ab23b66 upstream.
    
    Since commit ae8709b296d8 ("USB: core: Make do_proc_control() and
    do_proc_bulk() killable") if a device has the USB_QUIRK_DELAY_CTRL_MSG
    quirk set, it will temporarily block all other URBs (e.g. interrupts)
    while sleeping due to a control.
    
    This results in noticeable delays when, for example, a userspace usbfs
    application is sending URB interrupts at a high rate to a keyboard and
    simultaneously updates the lock indicators using controls. Interrupts
    with direction set to IN are also affected by this, meaning that
    delivery of HID reports (containing scancodes) to the usbfs application
    is delayed as well.
    
    This patch fixes the regression by calling msleep() while the device
    mutex is unlocked, as was the case originally with usb_control_msg().
    
    Fixes: ae8709b296d8 ("USB: core: Make do_proc_control() and do_proc_bulk() killable")
    Cc: stable <stable@kernel.org>
    Acked-by: Alan Stern <stern@rowland.harvard.edu>
    Signed-off-by: Tasos Sahanidis <tasos@tasossah.com>
    Link: https://lore.kernel.org/r/3e299e2a-13b9-ddff-7fee-6845e868bc06@tasossah.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 55e2013a2220641e970f28ef7390667d729340b3
Author: Hangyu Hua <hbh25y@gmail.com>
Date:   Thu Apr 7 10:40:01 2022 +0800

    usb: misc: fix improper handling of refcount in uss720_probe()
    
    commit 0a96fa640dc928da9eaa46a22c46521b037b78ad upstream.
    
    usb_put_dev shouldn't be called when uss720_probe succeeds because of
    priv->usbdev. At the same time, priv->usbdev shouldn't be set to NULL
    before destroy_priv in uss720_disconnect because usb_put_dev is in
    destroy_priv.
    
    Fix this by moving priv->usbdev = NULL after usb_put_dev.
    
    Fixes: dcb4b8ad6a44 ("misc/uss720: fix memory leak in uss720_probe")
    Cc: stable <stable@kernel.org>
    Reviewed-by: Dongliang Mu <mudongliangabcd@gmail.com>
    Signed-off-by: Hangyu Hua <hbh25y@gmail.com>
    Link: https://lore.kernel.org/r/20220407024001.11761-1-hbh25y@gmail.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit b691d719136de93bf8e039920acb95581868eb8e
Author: Fawzi Khaber <fawzi.khaber@tdk.com>
Date:   Mon Apr 11 13:15:33 2022 +0200

    iio: imu: inv_icm42600: Fix I2C init possible nack
    
    commit b5d6ba09b10d2ccb865ed9bc45941db0a41c6756 upstream.
    
    This register write to REG_INTF_CONFIG6 enables a spike filter that
    is impacting the line and can prevent the I2C ACK to be seen by the
    controller. So we don't test the return value.
    
    Fixes: 7297ef1e261672b8 ("iio: imu: inv_icm42600: add I2C driver")
    Signed-off-by: Fawzi Khaber <fawzi.khaber@tdk.com>
    Signed-off-by: Jean-Baptiste Maneyrol <jean-baptiste.maneyrol@tdk.com>
    Link: https://lore.kernel.org/r/20220411111533.5826-1-jmaneyrol@invensense.com
    Cc: <Stable@vger.kernel.org>
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 8f30d7f279c4a13f874320d22305e608a66adf4f
Author: Zheyu Ma <zheyuma97@gmail.com>
Date:   Sat Apr 9 11:48:49 2022 +0800

    iio: magnetometer: ak8975: Fix the error handling in ak8975_power_on()
    
    commit 3a26787dacf04257a68b16315c984eb2c340bc5e upstream.
    
    When the driver fails to enable the regulator 'vid', we will get the
    following splat:
    
    [   79.955610] WARNING: CPU: 5 PID: 441 at drivers/regulator/core.c:2257 _regulator_put+0x3ec/0x4e0
    [   79.959641] RIP: 0010:_regulator_put+0x3ec/0x4e0
    [   79.967570] Call Trace:
    [   79.967773]  <TASK>
    [   79.967951]  regulator_put+0x1f/0x30
    [   79.968254]  devres_release_group+0x319/0x3d0
    [   79.968608]  i2c_device_probe+0x766/0x940
    
    Fix this by disabling the 'vdd' regulator when failing to enable 'vid'
    regulator.
    
    Signed-off-by: Zheyu Ma <zheyuma97@gmail.com>
    Link: https://lore.kernel.org/r/20220409034849.3717231-2-zheyuma97@gmail.com
    Cc: <Stable@vger.kernel.org>
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit debe4b635f2d1de004b78deb69bdaeabf2ec1fc7
Author: Michael Hennerich <michael.hennerich@analog.com>
Date:   Wed Apr 6 12:56:20 2022 +0200

    iio: dac: ad5446: Fix read_raw not returning set value
    
    commit 89a01cd688d3c0ac983ef0b0e5f40018ab768317 upstream.
    
    read_raw should return the un-scaled value.
    
    Fixes: 5e06bdfb46e8b ("staging:iio:dac:ad5446: Return cached value for 'raw' attribute")
    Signed-off-by: Michael Hennerich <michael.hennerich@analog.com>
    Reviewed-by: Nuno Sá <nuno.sa@analog.com>
    Link: https://lore.kernel.org/r/20220406105620.1171340-1-michael.hennerich@analog.com
    Cc: <Stable@vger.kernel.org>
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 3ea6c6cc9811c864e2a353b69b4ed25807acee2f
Author: Tom Rix <trix@redhat.com>
Date:   Mon Feb 28 18:52:23 2022 -0800

    iio: scd4x: check return of scd4x_write_and_fetch
    
    commit f50232193e61cf89a73130b5e843fef30763c428 upstream.
    
    Clang static analysis reports this problem
    scd4x.c:474:10: warning: The left operand of '==' is a
      garbage value
      if (val == 0xff) {
          ~~~ ^
    val is only set from a successful call to scd4x_write_and_fetch()
    So check it's return.
    
    Fixes: 49d22b695cbb ("drivers: iio: chemical: Add support for Sensirion SCD4x CO2 sensor")
    Signed-off-by: Tom Rix <trix@redhat.com>
    Link: https://lore.kernel.org/r/20220301025223.223223-1-trix@redhat.com
    Cc: <Stable@vger.kernel.org>
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 7462f0c79762d60ea26c9aabdb600c797f81c10b
Author: Zizhuang Deng <sunsetdzz@gmail.com>
Date:   Thu Mar 10 20:54:50 2022 +0800

    iio: dac: ad5592r: Fix the missing return value.
    
    commit b55b38f7cc12da3b9ef36e7a3b7f8f96737df4d5 upstream.
    
    The third call to `fwnode_property_read_u32` did not record
    the return value, resulting in `channel_offstate` possibly
    being assigned the wrong value.
    
    Fixes: 56ca9db862bf ("iio: dac: Add support for the AD5592R/AD5593R ADCs/DACs")
    Signed-off-by: Zizhuang Deng <sunsetdzz@gmail.com>
    Link: https://lore.kernel.org/r/20220310125450.4164164-1-sunsetdzz@gmail.com
    Cc: <Stable@vger.kernel.org>
    Signed-off-by: Jonathan Cameron <Jonathan.Cameron@huawei.com>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 2fd128ba95abda702efb84d186582a08903bc9d2
Author: Mathias Nyman <mathias.nyman@linux.intel.com>
Date:   Fri Apr 8 16:48:23 2022 +0300

    xhci: increase usb U3 -> U0 link resume timeout from 100ms to 500ms
    
    commit 33597f0c48be0836854d43c577e35c8f8a765a7d upstream.
    
    The first U3 wake signal by the host may be lost if the USB 3 connection is
    tunneled over USB4, with a runtime suspended USB4 host, and firmware
    implemented connection manager.
    
    Specs state the host must wait 100ms (tU3WakeupRetryDelay) before
    resending a U3 wake signal if device doesn't respond, leading to U3 -> U0
    link transition times around 270ms in the tunneled case.
    
    Fixes: 0200b9f790b0 ("xhci: Wait until link state trainsits to U0 after setting USB_SS_PORT_LS_U0")
    Cc: stable@vger.kernel.org
    Signed-off-by: Mathias Nyman <mathias.nyman@linux.intel.com>
    Link: https://lore.kernel.org/r/20220408134823.2527272-4-mathias.nyman@linux.intel.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 2b6c734b867fc012cb0b6d344b8b250e7c13deae
Author: Henry Lin <henryl@nvidia.com>
Date:   Fri Apr 8 16:48:22 2022 +0300

    xhci: stop polling roothubs after shutdown
    
    commit dc92944a014cd6a6f6c94299aaa36164dd2c238a upstream.
    
    While rebooting, XHCI controller and its bus device will be shut down
    in order by .shutdown callback. Stopping roothubs polling in
    xhci_shutdown() can prevent XHCI driver from accessing port status
    after its bus device shutdown.
    
    Take PCIe XHCI controller as example, if XHCI driver doesn't stop roothubs
    polling, XHCI driver may access PCIe BAR register for port status after
    parent PCIe root port driver is shutdown and cause PCIe bus error.
    
    [check shared hcd exist before stopping its roothub polling -Mathias]
    
    Cc: stable@vger.kernel.org
    Signed-off-by: Henry Lin <henryl@nvidia.com>
    Signed-off-by: Mathias Nyman <mathias.nyman@linux.intel.com>
    Link: https://lore.kernel.org/r/20220408134823.2527272-3-mathias.nyman@linux.intel.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 8495132fad9e6538d8c8713c93705010f05f2e74
Author: Evan Green <evgreen@chromium.org>
Date:   Fri Apr 8 11:42:50 2022 -0700

    xhci: Enable runtime PM on second Alderlake controller
    
    commit d8bfe5091d6cc4b8b8395e4666979ae72a6069ca upstream.
    
    Alderlake has two XHCI controllers with PCI IDs 0x461e and 0x51ed. We
    had previously added the quirk to default enable runtime PM for 0x461e,
    now add it for 0x51ed as well.
    
    Signed-off-by: Evan Green <evgreen@chromium.org>
    Cc: stable <stable@kernel.org>
    Link: https://lore.kernel.org/r/20220408114225.1.Ibcff6b86ed4eacfe4c4bc89c90e18416f3900a3e@changeid
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 3d811779d46b006c37762a419432d1e786a38fc0
Author: zhangqilong <zhangqilong3@huawei.com>
Date:   Sat Mar 19 10:38:22 2022 +0800

    usb: xhci: tegra:Fix PM usage reference leak of tegra_xusb_unpowergate_partitions
    
    commit 8771039482d965bdc8cefd972bcabac2b76944a8 upstream.
    
    pm_runtime_get_sync will increment pm usage counter
    even it failed. Forgetting to putting operation will
    result in reference leak here. We fix it by replacing
    it with pm_runtime_resume_and_get to keep usage counter
    balanced.
    
    Fixes: 41a7426d25fa ("usb: xhci: tegra: Unlink power domain devices")
    Cc: stable <stable@vger.kernel.org>
    Signed-off-by: Zhang Qilong <zhangqilong3@huawei.com>
    Link: https://lore.kernel.org/r/20220319023822.145641-1-zhangqilong3@huawei.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 2be1493bf7c705e4257e577835ff2f671e569b28
Author: Daniele Palmas <dnlplm@gmail.com>
Date:   Wed Apr 6 16:14:08 2022 +0200

    USB: serial: option: add Telit 0x1057, 0x1058, 0x1075 compositions
    
    commit f32c5a0423400e01f4d7c607949fa3a1f006e8fa upstream.
    
    Add support for the following Telit FN980 and FN990 compositions:
    
    0x1057: tty, adb, rmnet, tty, tty, tty, tty, tty
    0x1058: tty, adb, tty, tty, tty, tty, tty
    0x1075: adb, tty
    
    Signed-off-by: Daniele Palmas <dnlplm@gmail.com>
    Link: https://lore.kernel.org/r/20220406141408.580669-1-dnlplm@gmail.com
    Cc: stable@vger.kernel.org
    Signed-off-by: Johan Hovold <johan@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit cf0658bd3cd85c4087ad211f9337af8869074578
Author: Slark Xiao <slark_xiao@163.com>
Date:   Thu Apr 14 15:44:34 2022 +0800

    USB: serial: option: add support for Cinterion MV32-WA/MV32-WB
    
    commit b4a64ed6e7b857317070fcb9d87ff5d4a73be3e8 upstream.
    
    Add support for Cinterion device MV32-WA/MV32-WB. MV32-WA PID is
    0x00F1, and MV32-WB PID is 0x00F2.
    
    Test evidence as below:
    T:  Bus=04 Lev=01 Prnt=01 Port=01 Cnt=01 Dev#=  4 Spd=5000 MxCh= 0
    D:  Ver= 3.20 Cls=ef(misc ) Sub=02 Prot=01 MxPS= 9 #Cfgs=  1
    P:  Vendor=1e2d ProdID=00f1 Rev=05.04
    S:  Manufacturer=Cinterion
    S:  Product=Cinterion PID 0x00F1 USB Mobile Broadband
    S:  SerialNumber=78ada8c4
    C:  #Ifs= 6 Cfg#= 1 Atr=a0 MxPwr=896mA
    I:  If#=0x0 Alt= 0 #EPs= 1 Cls=02(commc) Sub=0e Prot=00 Driver=cdc_mbim
    I:  If#=0x1 Alt= 1 #EPs= 2 Cls=0a(data ) Sub=00 Prot=02 Driver=cdc_mbim
    I:  If#=0x2 Alt= 0 #EPs= 3 Cls=ff(vend.) Sub=ff Prot=40 Driver=option
    I:  If#=0x3 Alt= 0 #EPs= 1 Cls=ff(vend.) Sub=ff Prot=ff Driver=(none)
    I:  If#=0x4 Alt= 0 #EPs= 3 Cls=ff(vend.) Sub=ff Prot=60 Driver=option
    I:  If#=0x5 Alt= 0 #EPs= 2 Cls=ff(vend.) Sub=ff Prot=30 Driver=option
    
    T:  Bus=04 Lev=01 Prnt=01 Port=01 Cnt=01 Dev#=  3 Spd=5000 MxCh= 0
    D:  Ver= 3.20 Cls=ef(misc ) Sub=02 Prot=01 MxPS= 9 #Cfgs=  1
    P:  Vendor=1e2d ProdID=00f2 Rev=05.04
    S:  Manufacturer=Cinterion
    S:  Product=Cinterion PID 0x00F2 USB Mobile Broadband
    S:  SerialNumber=cdd06a78
    C:  #Ifs= 6 Cfg#= 1 Atr=a0 MxPwr=896mA
    I:  If#=0x0 Alt= 0 #EPs= 1 Cls=02(commc) Sub=0e Prot=00 Driver=cdc_mbim
    I:  If#=0x1 Alt= 1 #EPs= 2 Cls=0a(data ) Sub=00 Prot=02 Driver=cdc_mbim
    I:  If#=0x2 Alt= 0 #EPs= 3 Cls=ff(vend.) Sub=ff Prot=40 Driver=option
    I:  If#=0x3 Alt= 0 #EPs= 1 Cls=ff(vend.) Sub=ff Prot=ff Driver=(none)
    I:  If#=0x4 Alt= 0 #EPs= 3 Cls=ff(vend.) Sub=ff Prot=60 Driver=option
    I:  If#=0x5 Alt= 0 #EPs= 2 Cls=ff(vend.) Sub=ff Prot=30 Driver=option
    
    Interface 0&1: MBIM, 2:Modem, 3: GNSS, 4: NMEA, 5: Diag
    GNSS port don't use serial driver.
    
    Signed-off-by: Slark Xiao <slark_xiao@163.com>
    Link: https://lore.kernel.org/r/20220414074434.5699-1-slark_xiao@163.com
    Cc: stable@vger.kernel.org
    Signed-off-by: Johan Hovold <johan@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 45c7c5e3d5aa8e76af5cba50bd2b81fdfa2d750f
Author: Bruno Thomsen <bruno.thomsen@gmail.com>
Date:   Thu Apr 14 10:12:02 2022 +0200

    USB: serial: cp210x: add PIDs for Kamstrup USB Meter Reader
    
    commit 35a923a0b329c343e9e81d79518e2937eba06fcd upstream.
    
    Wireless reading of water and heat meters using 868 MHz wM-Bus mode C1.
    
    The two different product IDs allow detection of dongle antenna
    solution:
    - Internal antenna
    - External antenna using SMA connector
    
    https://www.kamstrup.com/en-en/water-solutions/water-meter-reading/usb-meter-reader
    
    Signed-off-by: Bruno Thomsen <bruno.thomsen@gmail.com>
    Link: https://lore.kernel.org/r/20220414081202.5591-1-bruno.thomsen@gmail.com
    Cc: stable@vger.kernel.org
    Signed-off-by: Johan Hovold <johan@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 7cbf3e69a51e62cd1a7c3196b6361216b4c1b4f3
Author: Kees Cook <keescook@chromium.org>
Date:   Wed Apr 20 17:12:34 2022 -0700

    USB: serial: whiteheat: fix heap overflow in WHITEHEAT_GET_DTR_RTS
    
    commit e23e50e7acc8d8f16498e9c129db33e6a00e80eb upstream.
    
    The sizeof(struct whitehat_dr_info) can be 4 bytes under CONFIG_AEABI=n
    due to "-mabi=apcs-gnu", even though it has a single u8:
    
    whiteheat_private {
            __u8                       mcr;                  /*     0     1 */
    
            /* size: 4, cachelines: 1, members: 1 */
            /* padding: 3 */
            /* last cacheline: 4 bytes */
    };
    
    The result is technically harmless, as both the source and the
    destinations are currently the same allocation size (4 bytes) and don't
    use their padding, but if anything were to ever be added after the
    "mcr" member in "struct whiteheat_private", it would be overwritten. The
    structs both have a single u8 "mcr" member, but are 4 bytes in padded
    size. The memcpy() destination was explicitly targeting the u8 member
    (size 1) with the length of the whole structure (size 4), triggering
    the memcpy buffer overflow warning:
    
    In file included from include/linux/string.h:253,
                     from include/linux/bitmap.h:11,
                     from include/linux/cpumask.h:12,
                     from include/linux/smp.h:13,
                     from include/linux/lockdep.h:14,
                     from include/linux/spinlock.h:62,
                     from include/linux/mmzone.h:8,
                     from include/linux/gfp.h:6,
                     from include/linux/slab.h:15,
                     from drivers/usb/serial/whiteheat.c:17:
    In function 'fortify_memcpy_chk',
        inlined from 'firm_send_command' at drivers/usb/serial/whiteheat.c:587:4:
    include/linux/fortify-string.h:328:25: warning: call to '__write_overflow_field' declared with attribute warning: detected write beyond size of field (1st parameter); maybe use struct_group()? [-Wattribute-warning]
      328 |                         __write_overflow_field(p_size_field, size);
          |                         ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    Instead, just assign the one byte directly.
    
    Reported-by: kernel test robot <lkp@intel.com>
    Link: https://lore.kernel.org/lkml/202204142318.vDqjjSFn-lkp@intel.com
    Cc: stable@vger.kernel.org
    Signed-off-by: Kees Cook <keescook@chromium.org>
    Link: https://lore.kernel.org/r/20220421001234.2421107-1-keescook@chromium.org
    Signed-off-by: Johan Hovold <johan@kernel.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit cead8a4c816b45e67b87e513fc89e70240e498c0
Author: Oliver Neukum <oneukum@suse.com>
Date:   Thu Apr 14 14:31:52 2022 +0200

    USB: quirks: add STRING quirk for VCOM device
    
    commit ec547af8a9ea6441864bad34172676b5652ceb96 upstream.
    
    This has been reported to stall if queried
    
    Cc: stable <stable@vger.kernel.org>
    Signed-off-by: Oliver Neukum <oneukum@suse.com>
    Link: https://lore.kernel.org/r/20220414123152.1700-1-oneukum@suse.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 1d6f00e7aee03a58e7fdeb819e69efcbd1c9c2d5
Author: Oliver Neukum <oneukum@suse.com>
Date:   Thu Apr 14 13:02:09 2022 +0200

    USB: quirks: add a Realtek card reader
    
    commit 2a7ccf6bb6f147f64c025ad68f4255d8e1e0ce6d upstream.
    
    This device is reported to stall when enummerated.
    
    Cc: stable <stable@vger.kernel.org>
    Signed-off-by: Oliver Neukum <oneukum@suse.com>
    Link: https://lore.kernel.org/r/20220414110209.30924-1-oneukum@suse.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit d91ca05d52fabf68c0376bcfeed1a52be68a8e1b
Author: Willy Tarreau <w@1wt.eu>
Date:   Tue Apr 26 23:41:05 2022 +0300

    floppy: disable FDRAWCMD by default
    
    commit 233087ca063686964a53c829d547c7571e3f67bf upstream.
    
    Minh Yuan reported a concurrency use-after-free issue in the floppy code
    between raw_cmd_ioctl and seek_interrupt.
    
    [ It turns out this has been around, and that others have reported the
      KASAN splats over the years, but Minh Yuan had a reproducer for it and
      so gets primary credit for reporting it for this fix   - Linus ]
    
    The problem is, this driver tends to break very easily and nowadays,
    nobody is expected to use FDRAWCMD anyway since it was used to
    manipulate non-standard formats.  The risk of breaking the driver is
    higher than the risk presented by this race, and accessing the device
    requires privileges anyway.
    
    Let's just add a config option to completely disable this ioctl and
    leave it disabled by default.  Distros shouldn't use it, and only those
    running on antique hardware might need to enable it.
    
    Link: https://lore.kernel.org/all/000000000000b71cdd05d703f6bf@google.com/
    Link: https://lore.kernel.org/lkml/CAKcFiNC=MfYVW-Jt9A3=FPJpTwCD2PL_ULNCpsCVE5s8ZeBQgQ@mail.gmail.com
    Link: https://lore.kernel.org/all/CAEAjamu1FRhz6StCe_55XY5s389ZP_xmCF69k987En+1z53=eg@mail.gmail.com
    Reported-by: Minh Yuan <yuanmingbuaa@gmail.com>
    Reported-by: syzbot+8e8958586909d62b6840@syzkaller.appspotmail.com
    Reported-by: cruise k <cruise4k@gmail.com>
    Reported-by: Kyungtae Kim <kt0755@gmail.com>
    Suggested-by: Linus Torvalds <torvalds@linuxfoundation.org>
    Tested-by: Denis Efremov <efremov@linux.com>
    Signed-off-by: Willy Tarreau <w@1wt.eu>
    Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

commit 22d6a3a7d4d4b4d105abab3ac154906385746721
Author: Macpaul Lin <macpaul.lin@mediatek.com>
Date:   Tue Apr 19 16:12:45 2022 +0800

    usb: mtu3: fix USB 3.0 dual-role-switch from device to host
    
    commit 456244aeecd54249096362a173dfe06b82a5cafa upstream.
    
    Issue description:
      When an OTG port has been switched to device role and then switch back
      to host role again, the USB 3.0 Host (XHCI) will not be able to detect
      "plug in event of a connected USB 2.0/1.0 ((Highspeed and Fullspeed)
      devices until system reboot.
    
    Root cause and Solution:
      There is a condition checking flag "ssusb->otg_switch.is_u3_drd" in
      toggle_opstate(). At the end of role switch procedure, toggle_opstate()
      will be called to set DC_SESSION and SOFT_CONN bit. If "is_u3_drd" was
      set and switched the role to USB host 3.0, bit DC_SESSION and SOFT_CONN
      will be skipped hence caused the port cannot detect connected USB 2.0
      (Highspeed and Fullspeed) devices. Simply remove the condition check to
      solve this issue.
    
    Fixes: d0ed062a8b75 ("usb: mtu3: dual-role mode support")
    Cc: stable@vger.kernel.org
    Tested-by: Fabien Parent <fparent@baylibre.com>
    Reviewed-by: Chunfeng Yun <chunfeng.yun@mediatek.com>
    Signed-off-by: Macpaul Lin <macpaul.lin@mediatek.com>
    Signed-off-by: Tainping Fang <tianping.fang@mediatek.com>
    Link: https://lore.kernel.org/r/20220419081245.21015-1-macpaul.lin@mediatek.com
    Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
